@@ -20,12 +20,12 @@ package org.apache.tools.ant;
 import java.io.ByteArrayOutputStream;
 import java.io.Closeable;
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.reflect.Constructor;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.nio.file.Files;
 import java.security.CodeSource;
 import java.security.ProtectionDomain;
 import java.security.cert.Certificate;
@@ -74,6 +74,10 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
 
     private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
 
+    static {
+        registerAsParallelCapable();
+    }
+
     /**
      * An enumeration of all resources of a given name found within the
      * classpath of this class loader. This enumeration is used by the
@@ -174,7 +178,7 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      * The components of the classpath that the classloader searches
      * for classes.
      */
-    private final Vector<File> pathComponents  = new VectorSet<File>();
+    private final Vector<File> pathComponents  = new VectorSet<>();
 
     /**
      * The project to which this class loader belongs.
@@ -192,14 +196,14 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      * loader regardless of whether the parent class loader is being searched
      * first or not.
      */
-    private final Vector<String> systemPackages = new Vector<String>();
+    private final Vector<String> systemPackages = new Vector<>();
 
     /**
      * These are the package roots that are to be loaded by this class loader
      * regardless of whether the parent class loader is being searched first
      * or not.
      */
-    private final Vector<String> loaderPackages = new Vector<String>();
+    private final Vector<String> loaderPackages = new Vector<>();
 
     /**
      * Whether or not this classloader will ignore the base
@@ -217,7 +221,7 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
     /**
      * A hashtable of zip files opened by the classloader (File to JarFile).
      */
-    private Hashtable<File, JarFile> jarFiles = new Hashtable<File, JarFile>();
+    private Hashtable<File, JarFile> jarFiles = new Hashtable<>();
 
     /** Static map of jar file/time to manifest class-path entries */
     private static Map<String, String> pathMap =
@@ -289,8 +293,8 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      *                    classloader should be consulted  before trying to
      *                    load the a class through this loader.
      */
-    public AntClassLoader(
-                          final ClassLoader parent, final Project project, final Path classpath, final boolean parentFirst) {
+    public AntClassLoader(final ClassLoader parent, final Project project,
+        final Path classpath, final boolean parentFirst) {
         this(project, classpath);
         if (parent != null) {
             setParent(parent);
@@ -311,7 +315,8 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      *                    classloader should be consulted before trying to
      *                    load the a class through this loader.
      */
-    public AntClassLoader(final Project project, final Path classpath, final boolean parentFirst) {
+    public AntClassLoader(final Project project, final Path classpath,
+        final boolean parentFirst) {
         this(null, project, classpath, parentFirst);
     }
 
@@ -493,19 +498,13 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
                 + pathComponent.lastModified() + "-" + pathComponent.length();
         String classpath = pathMap.get(absPathPlusTimeAndLength);
         if (classpath == null) {
-            JarFile jarFile = null;
-            try {
-                jarFile = new JarFile(pathComponent);
+            try (JarFile jarFile = new JarFile(pathComponent)) {
                 final Manifest manifest = jarFile.getManifest();
                 if (manifest == null) {
                     return;
                 }
                 classpath = manifest.getMainAttributes()
                     .getValue(Attributes.Name.CLASS_PATH);
-            } finally {
-                if (jarFile != null) {
-                    jarFile.close();
-                }
             }
             if (classpath == null) {
                 classpath = "";
@@ -789,7 +788,7 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
             if (jarFile == null && file.isDirectory()) {
                 final File resource = new File(file, resourceName);
                 if (resource.exists()) {
-                    return new FileInputStream(resource);
+                    return Files.newInputStream(resource.toPath());
                 }
             } else {
                 if (jarFile == null) {
@@ -928,8 +927,8 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      *
      * @param name name of the resource
      * @return possible URLs as enumeration
-     * @throws IOException
-     * @see {@link #findResources(String, boolean)}
+     * @throws IOException if something goes wrong
+     * @see #findResources(String, boolean)
      * @since Ant 1.8.0
      */
     public Enumeration<URL> getNamedResources(final String name)
@@ -1411,12 +1410,7 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
      */
     public synchronized void cleanup() {
         for (final Enumeration<JarFile> e = jarFiles.elements(); e.hasMoreElements();) {
-            final JarFile jarFile = e.nextElement();
-            try {
-                jarFile.close();
-            } catch (final IOException ioe) {
-                // ignore
-            }
+            FileUtils.close(e.nextElement());
         }
         jarFiles = new Hashtable<File, JarFile>();
         if (project != null) {
@@ -1561,6 +1555,12 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
 
     /**
      * Factory method
+     *
+     * @param parent ClassLoader
+     * @param project Project
+     * @param path Path
+     * @param parentFirst boolean
+     * @return AntClassLoader
      */
     public static AntClassLoader newAntClassLoader(final ClassLoader parent,
                                                    final Project project,
@@ -1586,8 +1586,7 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
     }
 
     private static boolean readFully(final File f, final byte[] b) throws IOException {
-        final FileInputStream fis = new FileInputStream(f);
-        try {
+        try (InputStream fis = Files.newInputStream(f.toPath())) {
             final int len = b.length;
             int count = 0, x = 0;
             while (count != len) {
@@ -1598,8 +1597,6 @@ public class AntClassLoader extends ClassLoader implements SubBuildListener, Clo
                 count += x;
             }
             return count == len;
-        } finally {
-            fis.close();
         }
     }
 
