@@ -31,7 +31,10 @@ public class UniqFilter extends TokenFilter.ChainableReaderFilter {
     private String lastLine = null;
 
     public String filter(String string) {
-        return lastLine == null || !lastLine.equals(string)
-            ? (lastLine = string) : null;
+        if (lastLine == null || !lastLine.equals(string)) {
+            lastLine = string;
+            return lastLine;
+        }
+        return null;
     }
 }
