@@ -18,10 +18,11 @@
 package org.apache.tools.ant.helper;
 
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
+import java.nio.file.Files;
 import java.util.Locale;
 
 import org.apache.tools.ant.BuildException;
@@ -110,7 +111,7 @@ public class ProjectHelperImpl extends ProjectHelper {
                 + "default plugin");
         }
         File bFile = (File) source;
-        FileInputStream inputStream = null;
+        InputStream inputStream = null;
         InputSource inputSource = null;
 
         this.project = project;
@@ -124,7 +125,7 @@ public class ProjectHelperImpl extends ProjectHelper {
                 parser = new XMLReaderAdapter(JAXPUtils.getXMLReader());
             }
             String uri = FILE_UTILS.toURI(bFile.getAbsolutePath());
-            inputStream = new FileInputStream(bFile);
+            inputStream = Files.newInputStream(bFile.toPath());
             inputSource = new InputSource(inputStream);
             inputSource.setSystemId(uri);
             project.log("parsing buildfile " + bFile + " with URI = " + uri, Project.MSG_VERBOSE);
@@ -187,8 +188,8 @@ public class ProjectHelperImpl extends ProjectHelper {
         protected DocumentHandler parentHandler;
 
         /** Helper impl. With non-static internal classes, the compiler will generate
-            this automatically - but this will fail with some compilers ( reporting
-            "Expecting to find object/array on stack" ). If we pass it
+            this automatically - but this will fail with some compilers (reporting
+            "Expecting to find object/array on stack"). If we pass it
             explicitly it'll work with more compilers.
         */
         ProjectHelperImpl helperImpl;
@@ -302,10 +303,10 @@ public class ProjectHelperImpl extends ProjectHelper {
                             + "' for compliance with other XML tools", Project.MSG_WARN);
                 }
                 try {
-                    InputSource inputSource = new InputSource(new FileInputStream(file));
+                    InputSource inputSource = new InputSource(Files.newInputStream(file.toPath()));
                     inputSource.setSystemId(FILE_UTILS.toURI(file.getAbsolutePath()));
                     return inputSource;
-                } catch (FileNotFoundException fne) {
+                } catch (IOException fne) {
                     helperImpl.project.log(file.getAbsolutePath() + " could not be found",
                             Project.MSG_WARN);
                 }
@@ -327,7 +328,7 @@ public class ProjectHelperImpl extends ProjectHelper {
          *                              <code>"project"</code>
          */
         public void startElement(String tag, AttributeList attrs) throws SAXParseException {
-            if (tag.equals("project")) {
+            if ("project".equals(tag)) {
                 new ProjectHandler(helperImpl, this).init(tag, attrs);
             } else {
                 throw new SAXParseException("Config file is not of expected " + "XML type",
@@ -388,13 +389,13 @@ public class ProjectHelperImpl extends ProjectHelper {
                 String key = attrs.getName(i);
                 String value = attrs.getValue(i);
 
-                if (key.equals("default")) {
+                if ("default".equals(key)) {
                     def = value;
-                } else if (key.equals("name")) {
+                } else if ("name".equals(key)) {
                     name = value;
-                } else if (key.equals("id")) {
+                } else if ("id".equals(key)) {
                     id = value;
-                } else if (key.equals("basedir")) {
+                } else if ("basedir".equals(key)) {
                     baseDir = value;
                 } else {
                     throw new SAXParseException(
@@ -403,7 +404,7 @@ public class ProjectHelperImpl extends ProjectHelper {
                 }
             }
 
-            if (def != null && !def.equals("")) {
+            if (def != null && !def.isEmpty()) {
                 helperImpl.project.setDefault(def);
             } else {
                 throw new BuildException("The default attribute is required");
@@ -454,7 +455,7 @@ public class ProjectHelperImpl extends ProjectHelper {
          *            or a data type definition
          */
         public void startElement(String name, AttributeList attrs) throws SAXParseException {
-            if (name.equals("target")) {
+            if ("target".equals(name)) {
                 handleTarget(name, attrs);
             } else {
                 handleElement(helperImpl, this, helperImpl.implicitTarget, name, attrs);
@@ -524,21 +525,21 @@ public class ProjectHelperImpl extends ProjectHelper {
                 String key = attrs.getName(i);
                 String value = attrs.getValue(i);
 
-                if (key.equals("name")) {
+                if ("name".equals(key)) {
                     name = value;
-                    if (name.equals("")) {
+                    if (name.isEmpty()) {
                         throw new BuildException("name attribute must not" + " be empty",
                                 new Location(helperImpl.locator));
                     }
-                } else if (key.equals("depends")) {
+                } else if ("depends".equals(key)) {
                     depends = value;
-                } else if (key.equals("if")) {
+                } else if ("if".equals(key)) {
                     ifCond = value;
-                } else if (key.equals("unless")) {
+                } else if ("unless".equals(key)) {
                     unlessCond = value;
-                } else if (key.equals("id")) {
+                } else if ("id".equals(key)) {
                     id = value;
-                } else if (key.equals("description")) {
+                } else if ("description".equals(key)) {
                     description = value;
                 } else {
                     throw new SAXParseException("Unexpected attribute \"" + key + "\"",
@@ -562,7 +563,7 @@ public class ProjectHelperImpl extends ProjectHelper {
             target.setDescription(description);
             helperImpl.project.addTarget(name, target);
 
-            if (id != null && !id.equals("")) {
+            if (id != null && !id.isEmpty()) {
                 helperImpl.project.addReference(id, target);
             }
 
@@ -599,7 +600,7 @@ public class ProjectHelperImpl extends ProjectHelper {
      */
     private static void handleElement(ProjectHelperImpl helperImpl, DocumentHandler parent,
             Target target, String elementName, AttributeList attrs) throws SAXParseException {
-        if (elementName.equals("description")) {
+        if ("description".equals(elementName)) {
             // created for side effect
             new DescriptionHandler(helperImpl, parent); //NOSONAR
         } else if (helperImpl.project.getDataTypeDefinitions().get(elementName) != null) {
