@@ -102,9 +102,9 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
     }
 
     /** {@inheritDoc}. */
+    @Override
     public void buildStarted(final BuildEvent event) {
-        final String categoryString = PROJECT_LOG;
-        final Log log = getLog(categoryString, null);
+        final Log log = getLog(PROJECT_LOG, null);
 
         if (initialized) {
             realLog(log, "Build started.", Project.MSG_INFO, null);
@@ -112,10 +112,10 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
     }
 
     /** {@inheritDoc}. */
+    @Override
     public void buildFinished(final BuildEvent event) {
         if (initialized) {
-            final String categoryString = PROJECT_LOG;
-            final Log log = getLog(categoryString, event.getProject().getName());
+            final Log log = getLog(PROJECT_LOG, event.getProject().getName());
 
             if (event.getException() == null) {
                 realLog(log, "Build finished.", Project.MSG_INFO, null);
@@ -128,8 +128,9 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#targetStarted
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
+    @Override
     public void targetStarted(final BuildEvent event) {
         if (initialized) {
             final Log log = getLog(TARGET_LOG,
@@ -143,8 +144,9 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#targetFinished
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
+    @Override
     public void targetFinished(final BuildEvent event) {
         if (initialized) {
             final String targetName = event.getTarget().getName();
@@ -162,8 +164,9 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#taskStarted
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
+    @Override
     public void taskStarted(final BuildEvent event) {
         if (initialized) {
             final Task task = event.getTask();
@@ -184,8 +187,9 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#taskFinished
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
+    @Override
     public void taskFinished(final BuildEvent event) {
         if (initialized) {
             final Task task = event.getTask();
@@ -213,18 +217,18 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
 
     /**
      * @see BuildListener#messageLogged
+     * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
+    @Override
     public void messageLogged(final BuildEvent event) {
         if (initialized) {
             Object categoryObject = event.getTask();
-            String categoryString = null;
+            String categoryString;
             String categoryDetail = null;
 
             if (categoryObject == null) {
                 categoryObject = event.getTarget();
                 if (categoryObject == null) {
-                    categoryObject = event.getProject();
                     categoryString = PROJECT_LOG;
                     categoryDetail = event.getProject().getName();
                 } else {
@@ -245,7 +249,7 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
             final Log log = getLog(categoryString, categoryDetail);
             final int priority = event.getPriority();
             final String message = event.getMessage();
-            realLog(log, message, priority , null);
+            realLog(log, message, priority, null);
         }
     }
 
@@ -300,6 +304,7 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
      * This is not used, the logger config is used instead.
      * @param level ignored
      */
+    @Override
     public void setMessageOutputLevel(final int level) {
         // Use the logger config
     }
@@ -308,6 +313,7 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
      * Set the output print stream.
      * @param output the output stream
      */
+    @Override
     public void setOutputPrintStream(final PrintStream output) {
         this.out = output;
     }
@@ -317,6 +323,7 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
      * This is ignored.
      * @param emacsMode ignored
      */
+    @Override
     public void setEmacsMode(final boolean emacsMode) {
         // Doesn't make sense for c-l. Use the logger config
     }
@@ -325,6 +332,7 @@ public class CommonsLoggingListener implements BuildListener, BuildLogger {
      * Set the error print stream.
      * @param err the error stream
      */
+    @Override
     public void setErrorPrintStream(final PrintStream err) {
         this.err = err;
     }
