@@ -51,6 +51,7 @@ public class Log4jListener implements BuildListener {
      * @see BuildListener#buildStarted
      * {@inheritDoc}.
      */
+    @Override
     public void buildStarted(final BuildEvent event) {
         final Logger log = Logger.getLogger(Project.class.getName());
         log.info("Build started.");
@@ -60,6 +61,7 @@ public class Log4jListener implements BuildListener {
      * @see BuildListener#buildFinished
      * {@inheritDoc}.
      */
+    @Override
     public void buildFinished(final BuildEvent event) {
         final Logger log = Logger.getLogger(Project.class.getName());
         if (event.getException() == null) {
@@ -73,6 +75,7 @@ public class Log4jListener implements BuildListener {
      * @see BuildListener#targetStarted
      * {@inheritDoc}.
      */
+    @Override
     public void targetStarted(final BuildEvent event) {
         final Logger log = Logger.getLogger(Target.class.getName());
         log.info("Target \"" + event.getTarget().getName() + "\" started.");
@@ -82,6 +85,7 @@ public class Log4jListener implements BuildListener {
      * @see BuildListener#targetFinished
      * {@inheritDoc}.
      */
+    @Override
     public void targetFinished(final BuildEvent event) {
         final String targetName = event.getTarget().getName();
         final Logger cat = Logger.getLogger(Target.class.getName());
@@ -97,6 +101,7 @@ public class Log4jListener implements BuildListener {
      * @see BuildListener#taskStarted
      * {@inheritDoc}.
      */
+    @Override
     public void taskStarted(final BuildEvent event) {
         final Task task = event.getTask();
         final Logger log = Logger.getLogger(task.getClass().getName());
@@ -107,6 +112,7 @@ public class Log4jListener implements BuildListener {
      * @see BuildListener#taskFinished
      * {@inheritDoc}.
      */
+    @Override
     public void taskFinished(final BuildEvent event) {
         final Task task = event.getTask();
         final Logger log = Logger.getLogger(task.getClass().getName());
@@ -122,7 +128,7 @@ public class Log4jListener implements BuildListener {
      * @see BuildListener#messageLogged
      * {@inheritDoc}.
      */
-    /** {@inheritDoc}. */
+    @Override
     public void messageLogged(final BuildEvent event) {
         Object categoryObject = event.getTask();
         if (categoryObject == null) {
