@@ -19,15 +19,22 @@
 package org.apache.tools.ant.taskdefs;
 
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.FileWriter;
 import java.io.IOException;
+import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
+import java.util.ArrayList;
+import java.nio.file.Files;
 import java.util.Enumeration;
 import java.util.Hashtable;
-import java.util.Vector;
+import java.util.List;
+import java.util.Set;
+import java.util.stream.Collector;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
+
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.IntrospectionHelper;
 import org.apache.tools.ant.Project;
@@ -35,6 +42,7 @@ import org.apache.tools.ant.Task;
 import org.apache.tools.ant.TaskContainer;
 import org.apache.tools.ant.types.EnumeratedAttribute;
 import org.apache.tools.ant.types.Reference;
+import org.apache.tools.ant.util.FileUtils;
 
 /**
  * Creates a partial DTD for Ant from the currently known tasks.
@@ -56,7 +64,7 @@ public class AntStructure extends Task {
      * The output file.
      * @param output the output file
      */
-    public void setOutput(File output) {
+    public void setOutput(final File output) {
         this.output = output;
     }
 
@@ -65,7 +73,7 @@ public class AntStructure extends Task {
      * @param p the printer to use.
      * @since Ant 1.7
      */
-    public void add(StructurePrinter p) {
+    public void add(final StructurePrinter p) {
         printer = p;
     }
 
@@ -74,6 +82,7 @@ public class AntStructure extends Task {
      *
      * @exception BuildException if the DTD cannot be written.
      */
+    @Override
     public void execute() throws BuildException {
 
         if (output == null) {
@@ -82,9 +91,12 @@ public class AntStructure extends Task {
 
         PrintWriter out = null;
         try {
+            OutputStream fos = null;
             try {
-                out = new PrintWriter(new OutputStreamWriter(new FileOutputStream(output), "UTF8"));
-            } catch (UnsupportedEncodingException ue) {
+                fos = Files.newOutputStream(output.toPath());
+                out = new PrintWriter(new OutputStreamWriter(fos, "UTF8"));
+            } catch (final UnsupportedEncodingException ue) {
+                FileUtils.close(fos);
                 /*
                  * Plain impossible with UTF8, see
                  * http://java.sun.com/j2se/1.5.0/docs/guide/intl/encoding.doc.html
@@ -100,14 +112,14 @@ public class AntStructure extends Task {
 
             printer.printTargetDecl(out);
 
-            for (String typeName : getProject().getCopyOfDataTypeDefinitions()
+            for (final String typeName : getProject().getCopyOfDataTypeDefinitions()
                 .keySet()) {
                 printer.printElementDecl(
                                      out, getProject(), typeName,
                                      getProject().getDataTypeDefinitions().get(typeName));
             }
 
-            for (String tName : getProject().getCopyOfTaskDefinitions().keySet()) {
+            for (final String tName : getProject().getCopyOfTaskDefinitions().keySet()) {
                 printer.printElementDecl(out, getProject(), tName,
                                          getProject().getTaskDefinitions().get(tName));
             }
@@ -115,10 +127,10 @@ public class AntStructure extends Task {
             printer.printTail(out);
 
             if (out.checkError()) {
-                throw new IOException("Encountered an error writing Ant"
-                                      + " structure");
+                throw new IOException(
+                    "Encountered an error writing Ant structure");
             }
-        } catch (IOException ioe) {
+        } catch (final IOException ioe) {
             throw new BuildException("Error writing "
                                      + output.getAbsolutePath(), ioe, getLocation());
         } finally {
@@ -135,7 +147,7 @@ public class AntStructure extends Task {
      * are called exactly once, {@link #printElementDecl} once for
      * each declared task and type.</p>
      */
-    public static interface StructurePrinter {
+    public interface StructurePrinter {
         /**
          * Prints the header of the generated output.
          *
@@ -178,15 +190,17 @@ public class AntStructure extends Task {
         private static final String TASKS = "%tasks;";
         private static final String TYPES = "%types;";
 
-        private Hashtable<String, String> visited = new Hashtable<String, String>();
+        private final Hashtable<String, String> visited = new Hashtable<String, String>();
 
-        public void printTail(PrintWriter out) {
+        @Override
+        public void printTail(final PrintWriter out) {
             visited.clear();
         }
 
-        public void printHead(PrintWriter out, Project p, Hashtable<String, Class<?>> tasks,
-                Hashtable<String, Class<?>> types) {
-            printHead(out, tasks.keys(), types.keys());
+        @Override
+        public void printHead(final PrintWriter out, final Project p, final Hashtable<String, Class<?>> tasks,
+                              final Hashtable<String, Class<?>> types) {
+            printHead(out, tasks.keySet(), types.keySet());
         }
 
 
@@ -196,36 +210,18 @@ public class AntStructure extends Task {
          * <p>Basically this prints the XML declaration, defines some
          * entities and the project element.</p>
          */
-        private void printHead(PrintWriter out, Enumeration<String> tasks,
-                               Enumeration<String> types) {
+        private void printHead(final PrintWriter out, final Set<String> tasks,
+                               final Set<String> types) {
             out.println("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>");
             out.println("<!ENTITY % boolean \"(true|false|on|off|yes|no)\">");
-            out.print("<!ENTITY % tasks \"");
-            boolean first = true;
-            while (tasks.hasMoreElements()) {
-                String tName = tasks.nextElement();
-                if (!first) {
-                    out.print(" | ");
-                } else {
-                    first = false;
-                }
-                out.print(tName);
-            }
-            out.println("\">");
-            out.print("<!ENTITY % types \"");
-            first = true;
-            while (types.hasMoreElements()) {
-                String typeName = types.nextElement();
-                if (!first) {
-                    out.print(" | ");
-                } else {
-                    first = false;
-                }
-                out.print(typeName);
-            }
-            out.println("\">");
 
-            out.println("");
+            out.println(tasks.stream().collect(
+                Collectors.joining(" | ", "<!ENTITY % tasks \"", "\">")));
+
+            out.println(types.stream().collect(
+                Collectors.joining(" | ", "<!ENTITY % types \"", "\">")));
+
+            out.println();
 
             out.print("<!ELEMENT project (target | extension-point | ");
             out.print(TASKS);
@@ -242,7 +238,8 @@ public class AntStructure extends Task {
         /**
          * Prints the definition for the target element.
          */
-        public void printTargetDecl(PrintWriter out) {
+        @Override
+        public void printTargetDecl(final PrintWriter out) {
             out.print("<!ELEMENT target (");
             out.print(TASKS);
             out.print(" | ");
@@ -258,7 +255,7 @@ public class AntStructure extends Task {
         /**
          * Prints the definition for the target element.
          */
-        private void printTargetAttrs(PrintWriter out, String tag) {
+        private void printTargetAttrs(final PrintWriter out, final String tag) {
             out.print("<!ATTLIST ");
             out.println(tag);
             out.println("          id                      ID    #IMPLIED");
@@ -275,18 +272,19 @@ public class AntStructure extends Task {
         /**
          * Print the definition for a given element.
          */
-        public void printElementDecl(PrintWriter out, Project p,
-                                     String name, Class<?> element) {
+        @Override
+        public void printElementDecl(final PrintWriter out, final Project p,
+                                     final String name, final Class<?> element) {
 
             if (visited.containsKey(name)) {
                 return;
             }
             visited.put(name, "");
 
-            IntrospectionHelper ih = null;
+            IntrospectionHelper ih;
             try {
                 ih = IntrospectionHelper.getHelper(p, element);
-            } catch (Throwable t) {
+            } catch (final Throwable t) {
                 /*
                  * TODO - failed to load the class properly.
                  *
@@ -295,10 +293,10 @@ public class AntStructure extends Task {
                 return;
             }
 
-            StringBuffer sb = new StringBuffer("<!ELEMENT ");
-            sb.append(name).append(" ");
+            StringBuilder sb =
+                new StringBuilder("<!ELEMENT ").append(name).append(" ");
 
-            if (org.apache.tools.ant.types.Reference.class.equals(element)) {
+            if (Reference.class.equals(element)) {
                 sb.append("EMPTY>").append(LINE_SEP);
                 sb.append("<!ATTLIST ").append(name);
                 sb.append(LINE_SEP).append("          id ID #IMPLIED");
@@ -308,101 +306,82 @@ public class AntStructure extends Task {
                 return;
             }
 
-            Vector<String> v = new Vector<String>();
+            final List<String> v = new ArrayList<>();
             if (ih.supportsCharacters()) {
-                v.addElement("#PCDATA");
+                v.add("#PCDATA");
             }
 
             if (TaskContainer.class.isAssignableFrom(element)) {
-                v.addElement(TASKS);
+                v.add(TASKS);
             }
 
             Enumeration<String> e = ih.getNestedElements();
             while (e.hasMoreElements()) {
-                v.addElement(e.nextElement());
+                v.add(e.nextElement());
             }
 
+            final Collector<CharSequence, ?, String> joinAlts =
+                Collectors.joining(" | ", "(", ")");
+
             if (v.isEmpty()) {
                 sb.append("EMPTY");
             } else {
-                sb.append("(");
-                final int count = v.size();
-                for (int i = 0; i < count; i++) {
-                    if (i != 0) {
-                        sb.append(" | ");
-                    }
-                    sb.append(v.elementAt(i));
-                }
-                sb.append(")");
-                if (count > 1 || !v.elementAt(0).equals("#PCDATA")) {
+                sb.append(v.stream().collect(joinAlts));
+                if (v.size() > 1 || !"#PCDATA".equals(v.get(0))) {
                     sb.append("*");
                 }
             }
             sb.append(">");
             out.println(sb);
 
-            sb = new StringBuffer("<!ATTLIST ");
+            sb = new StringBuilder("<!ATTLIST ");
             sb.append(name);
             sb.append(LINE_SEP).append("          id ID #IMPLIED");
 
             e = ih.getAttributes();
             while (e.hasMoreElements()) {
-                String attrName = (String) e.nextElement();
+                final String attrName = e.nextElement();
                 if ("id".equals(attrName)) {
                     continue;
                 }
 
                 sb.append(LINE_SEP).append("          ")
                     .append(attrName).append(" ");
-                Class<?> type = ih.getAttributeType(attrName);
-                if (type.equals(java.lang.Boolean.class)
-                    || type.equals(java.lang.Boolean.TYPE)) {
+                final Class<?> type = ih.getAttributeType(attrName);
+                if (type.equals(Boolean.class)
+                    || type.equals(Boolean.TYPE)) {
                     sb.append(BOOLEAN).append(" ");
                 } else if (Reference.class.isAssignableFrom(type)) {
                     sb.append("IDREF ");
                 } else if (EnumeratedAttribute.class.isAssignableFrom(type)) {
                     try {
-                        EnumeratedAttribute ea =
-                            (EnumeratedAttribute) type.newInstance();
-                        String[] values = ea.getValues();
+                        final EnumeratedAttribute ea =
+                            type.asSubclass(EnumeratedAttribute.class)
+                                .newInstance();
+                        final String[] values = ea.getValues();
                         if (values == null
                             || values.length == 0
                             || !areNmtokens(values)) {
                             sb.append("CDATA ");
                         } else {
-                            sb.append("(");
-                            for (int i = 0; i < values.length; i++) {
-                                if (i != 0) {
-                                    sb.append(" | ");
-                                }
-                                sb.append(values[i]);
-                            }
-                            sb.append(") ");
+                            sb.append(Stream.of(values).collect(joinAlts));
                         }
-                    } catch (InstantiationException ie) {
+                    } catch (final InstantiationException ie) {
                         sb.append("CDATA ");
-                    } catch (IllegalAccessException ie) {
+                    } catch (final IllegalAccessException ie) {
                         sb.append("CDATA ");
                     }
-                } else if (type.getSuperclass() != null
-                           && type.getSuperclass().getName().equals("java.lang.Enum")) {
+                } else if (Enum.class.isAssignableFrom(type)) {
                     try {
-                        Object[] values = (Object[]) type.getMethod("values", (Class[])  null)
-                            .invoke(null, (Object[]) null);
+                        final Enum<?>[] values =
+                            (Enum<?>[]) type.getMethod("values").invoke(null);
                         if (values.length == 0) {
                             sb.append("CDATA ");
                         } else {
-                            sb.append('(');
-                            for (int i = 0; i < values.length; i++) {
-                                if (i != 0) {
-                                    sb.append(" | ");
-                                }
-                                sb.append(type.getMethod("name", (Class[]) null)
-                                          .invoke(values[i], (Object[]) null));
-                            }
-                            sb.append(") ");
+                            sb.append(Stream.of(values).map(Enum::name)
+                                .collect(joinAlts));
                         }
-                    } catch (Exception x) {
+                    } catch (final Exception x) {
                         sb.append("CDATA ");
                     }
                 } else {
@@ -413,9 +392,7 @@ public class AntStructure extends Task {
             sb.append(">").append(LINE_SEP);
             out.println(sb);
 
-            final int count = v.size();
-            for (int i = 0; i < count; i++) {
-                String nestedName = (String) v.elementAt(i);
+            for (String nestedName : v) {
                 if (!"#PCDATA".equals(nestedName)
                     && !TASKS.equals(nestedName)
                     && !TYPES.equals(nestedName)) {
@@ -429,10 +406,10 @@ public class AntStructure extends Task {
          * @param s the string to test
          * @return true if the string matches the XML-NMTOKEN
          */
-        public static final boolean isNmtoken(String s) {
+        public static final boolean isNmtoken(final String s) {
             final int length = s.length();
             for (int i = 0; i < length; i++) {
-                char c = s.charAt(i);
+                final char c = s.charAt(i);
                 // TODO - we are committing CombiningChar and Extender here
                 if (!Character.isLetterOrDigit(c)
                     && c != '.' && c != '-' && c != '_' && c != ':') {
@@ -450,7 +427,7 @@ public class AntStructure extends Task {
          * @param s the array of string to test
          * @return true if all the strings in the array math XML-NMTOKEN
          */
-        public static final boolean areNmtokens(String[] s) {
+        public static final boolean areNmtokens(final String[] s) {
             for (int i = 0; i < s.length; i++) {
                 if (!isNmtoken(s[i])) {
                     return false;
@@ -465,7 +442,7 @@ public class AntStructure extends Task {
      * @param s the string to test
      * @return true if the string matches the XML-NMTOKEN
      */
-    protected boolean isNmtoken(String s) {
+    protected boolean isNmtoken(final String s) {
         return DTDPrinter.isNmtoken(s);
     }
 
@@ -477,7 +454,7 @@ public class AntStructure extends Task {
      * @param s the array of string to test
      * @return true if all the strings in the array math XML-NMTOKEN
      */
-    protected boolean areNmtokens(String[] s) {
+    protected boolean areNmtokens(final String[] s) {
         return DTDPrinter.areNmtokens(s);
     }
 }
