@@ -39,7 +39,7 @@ import org.apache.tools.ant.util.FileUtils;
  * obsoleted by ResourceCollection support in Copy available since Ant
  * 1.7.0.  Don't use it.
  */
-
+@Deprecated
 public class CopyPath extends Task {
 
     // Error messages
@@ -182,6 +182,9 @@ public class CopyPath extends Task {
             String sourceFileName = sourceFiles[sources];
             File sourceFile = new File(sourceFileName);
             String[] toFiles = (String[]) mapper.mapFileName(sourceFileName);
+            if (toFiles == null) {
+                continue;
+            }
 
             for (int i = 0; i < toFiles.length; i++) {
                 String destFileName = toFiles[i];
