@@ -20,13 +20,15 @@ package org.apache.tools.ant.taskdefs;
 
 import java.io.File;
 import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.io.OutputStream;
+import java.nio.file.Files;
 import java.util.Date;
 import java.util.Enumeration;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Set;
 import java.util.Vector;
 
@@ -58,26 +60,26 @@ import org.apache.tools.zip.ZipFile;
  *           name="unwar"
  */
 public class Expand extends Task {
+    public static final String NATIVE_ENCODING = "native-encoding";
+
+    /** Error message when more that one mapper is defined */
+    public static final String ERROR_MULTIPLE_MAPPERS = "Cannot define more than one mapper";
+
+    private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
+
     private static final int BUFFER_SIZE = 1024;
     private File dest; //req
     private File source; // req
     private boolean overwrite = true;
     private Mapper mapperElement = null;
-    private Vector<PatternSet> patternsets = new Vector<PatternSet>();
+    private List<PatternSet> patternsets = new Vector<>();
     private Union resources = new Union();
     private boolean resourcesSpecified = false;
     private boolean failOnEmptyArchive = false;
-    private boolean stripAbsolutePathSpec = true;
+    private boolean stripAbsolutePathSpec = false;
     private boolean scanForUnicodeExtraFields = true;
-    private Boolean allowFilesToEscapeDest = null;
-
-    public static final String NATIVE_ENCODING = "native-encoding";
 
     private String encoding;
-    /** Error message when more that one mapper is defined */
-    public static final String ERROR_MULTIPLE_MAPPERS = "Cannot define more than one mapper";
-
-    private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
 
     /**
      * Creates an Expand instance and sets encoding to UTF-8.
@@ -121,14 +123,15 @@ public class Expand extends Task {
      *
      * @exception BuildException Thrown in unrecoverable error.
      */
+    @Override
     public void execute() throws BuildException {
         if ("expand".equals(getTaskType())) {
             log("!! expand is deprecated. Use unzip instead. !!");
         }
 
         if (source == null && !resourcesSpecified) {
-            throw new BuildException("src attribute and/or resources must be "
-                                     + "specified");
+            throw new BuildException(
+                "src attribute and/or resources must be specified");
         }
 
         if (dest == null) {
@@ -144,13 +147,14 @@ public class Expand extends Task {
             if (source.isDirectory()) {
                 throw new BuildException("Src must not be a directory."
                     + " Use nested filesets instead.", getLocation());
-            } else if (!source.exists()) {
-                throw new BuildException("src '" + source + "' doesn't exist.");
-            } else if (!source.canRead()) {
-                throw new BuildException("src '" + source + "' cannot be read.");
-            } else {
-                expandFile(FILE_UTILS, source, dest);
             }
+            if (!source.exists()) {
+                throw new BuildException("src '" + source + "' doesn't exist.");
+            }
+            if (!source.canRead()) {
+                throw new BuildException("src '" + source + "' cannot be read.");
+            }
+            expandFile(FILE_UTILS, source, dest);
         }
         for (Resource r : resources) {
             if (!r.isExists()) {
@@ -176,7 +180,6 @@ public class Expand extends Task {
      */
     protected void expandFile(FileUtils fileUtils, File srcF, File dir) {
         log("Expanding: " + srcF + " into " + dir, Project.MSG_INFO);
-        ZipFile zf = null;
         FileNameMapper mapper = getMapper();
         if (!srcF.exists()) {
             throw new BuildException("Unable to expand "
@@ -184,8 +187,9 @@ public class Expand extends Task {
                     + " as the file does not exist",
                     getLocation());
         }
-        try {
-            zf = new ZipFile(srcF, encoding, scanForUnicodeExtraFields);
+        try (
+            ZipFile
+            zf = new ZipFile(srcF, encoding, scanForUnicodeExtraFields)){
             boolean empty = true;
             Enumeration<ZipEntry> e = zf.getEntries();
             while (e.hasMoreElements()) {
@@ -203,7 +207,7 @@ public class Expand extends Task {
                 }
             }
             if (empty && getFailOnEmptyArchive()) {
-                throw new BuildException("archive '" + srcF + "' is empty");
+                throw new BuildException("archive '%s' is empty", srcF);
             }
             log("expand complete", Project.MSG_VERBOSE);
         } catch (IOException ioe) {
@@ -211,8 +215,6 @@ public class Expand extends Task {
                 "Error while expanding " + srcF.getPath()
                 + "\n" + ioe.toString(),
                 ioe);
-        } finally {
-            ZipFile.closeQuietly(zf);
         }
     }
 
@@ -223,8 +225,8 @@ public class Expand extends Task {
      * @param dir       the destination directory
      */
     protected void expandResource(Resource srcR, File dir) {
-        throw new BuildException("only filesystem based resources are"
-                                 + " supported by this task.");
+        throw new BuildException(
+            "only filesystem based resources are supported by this task.");
     }
 
     /**
@@ -232,13 +234,10 @@ public class Expand extends Task {
      * @return a filenamemapper for a file
      */
     protected FileNameMapper getMapper() {
-        FileNameMapper mapper = null;
         if (mapperElement != null) {
-            mapper = mapperElement.getImplementation();
-        } else {
-            mapper = new IdentityMapper();
+            return mapperElement.getImplementation();
         }
-        return mapper;
+        return new IdentityMapper();
     }
 
     // CheckStyle:ParameterNumberCheck OFF - bc
@@ -260,35 +259,34 @@ public class Expand extends Task {
                                boolean isDirectory, FileNameMapper mapper)
                                throws IOException {
 
-        final boolean entryNameStartsWithPathSpec = entryName.length() > 0
+        if (stripAbsolutePathSpec && !entryName.isEmpty()
             && (entryName.charAt(0) == File.separatorChar
                 || entryName.charAt(0) == '/'
-                || entryName.charAt(0) == '\\');
-        if (stripAbsolutePathSpec && entryNameStartsWithPathSpec) {
+                || entryName.charAt(0) == '\\')) {
             log("stripped absolute path spec from " + entryName,
                 Project.MSG_VERBOSE);
             entryName = entryName.substring(1);
         }
-        boolean allowedOutsideOfDest = Boolean.TRUE == getAllowFilesToEscapeDest()
-            || null == getAllowFilesToEscapeDest() && !stripAbsolutePathSpec && entryNameStartsWithPathSpec;
 
-        if (patternsets != null && patternsets.size() > 0) {
+        if (!(patternsets == null || patternsets.isEmpty())) {
             String name = entryName.replace('/', File.separatorChar)
                 .replace('\\', File.separatorChar);
 
             boolean included = false;
-            Set<String> includePatterns = new HashSet<String>();
-            Set<String> excludePatterns = new HashSet<String>();
-            for (PatternSet p : patternsets) {
+            Set<String> includePatterns = new HashSet<>();
+            Set<String> excludePatterns = new HashSet<>();
+            final int size = patternsets.size();
+            for (int v = 0; v < size; v++) {
+                PatternSet p = patternsets.get(v);
                 String[] incls = p.getIncludePatterns(getProject());
                 if (incls == null || incls.length == 0) {
                     // no include pattern implicitly means includes="**"
-                    incls = new String[]{"**"};
+                    incls = new String[] {"**"};
                 }
 
-                for (String incl : incls) {
-                    String pattern = incl.replace('/', File.separatorChar)
-                            .replace('\\', File.separatorChar);
+                for (int w = 0; w < incls.length; w++) {
+                    String pattern = incls[w].replace('/', File.separatorChar)
+                        .replace('\\', File.separatorChar);
                     if (pattern.endsWith(File.separator)) {
                         pattern += "**";
                     }
@@ -297,9 +295,10 @@ public class Expand extends Task {
 
                 String[] excls = p.getExcludePatterns(getProject());
                 if (excls != null) {
-                    for (String excl : excls) {
-                        String pattern = excl.replace('/', File.separatorChar)
-                                .replace('\\', File.separatorChar);
+                    for (int w = 0; w < excls.length; w++) {
+                        String pattern = excls[w]
+                            .replace('/', File.separatorChar)
+                            .replace('\\', File.separatorChar);
                         if (pattern.endsWith(File.separator)) {
                             pattern += "**";
                         }
@@ -333,12 +332,6 @@ public class Expand extends Task {
             mappedNames = new String[] {entryName};
         }
         File f = fileUtils.resolveFile(dir, mappedNames[0]);
-        if (!allowedOutsideOfDest && !fileUtils.isLeadingPath(dir, f)) {
-            log("skipping " + entryName + " as its target " + f + " is outside of "
-                + dir + ".", Project.MSG_VERBOSE);
-                return;
-        }
-
         try {
             if (!overwrite && f.exists()
                 && f.lastModified() >= entryDate.getTime()) {
@@ -359,20 +352,11 @@ public class Expand extends Task {
                 f.mkdirs();
             } else {
                 byte[] buffer = new byte[BUFFER_SIZE];
-                int length = 0;
-                FileOutputStream fos = null;
-                try {
-                    fos = new FileOutputStream(f);
-
-                    while ((length =
-                            compressedInputStream.read(buffer)) >= 0) {
+                try (OutputStream fos = Files.newOutputStream(f.toPath())) {
+                    int length;
+                    while ((length = compressedInputStream.read(buffer)) >= 0) {
                         fos.write(buffer, 0, length);
                     }
-
-                    fos.close();
-                    fos = null;
-                } finally {
-                    FileUtils.close(fos);
                 }
             }
 
@@ -419,7 +403,7 @@ public class Expand extends Task {
      * @param set a pattern set
      */
     public void addPatternset(PatternSet set) {
-        patternsets.addElement(set);
+        patternsets.add(set);
     }
 
     /**
@@ -540,25 +524,4 @@ public class Expand extends Task {
         return scanForUnicodeExtraFields;
     }
 
-    /**
-     * Whether to allow the extracted file or directory to be outside of the dest directory.
-     *
-     * @param b the flag
-     * @since Ant 1.9.12
-     */
-    public void setAllowFilesToEscapeDest(boolean b) {
-        allowFilesToEscapeDest = b;
-    }
-
-    /**
-     * Whether to allow the extracted file or directory to be outside of the dest directory.
-     *
-     * @return {@code null} if the flag hasn't been set explicitly,
-     * otherwise the value set by the user.
-     * @since Ant 1.9.12
-     */
-    public Boolean getAllowFilesToEscapeDest() {
-        return allowFilesToEscapeDest;
-    }
-
 }
