@@ -18,6 +18,7 @@
 package org.apache.tools.ant.taskdefs;
 
 import java.util.Hashtable;
+import java.util.Iterator;
 import java.util.Map;
 
 import org.apache.tools.ant.BuildEvent;
@@ -67,8 +68,7 @@ public class Recorder extends Task implements SubBuildListener {
     /** Strip task banners if true.  */
     private boolean emacsMode = false;
     /** The list of recorder entries. */
-    private static Hashtable<String, RecorderEntry> recorderEntries
-            = new Hashtable<String, RecorderEntry>();
+    private static Hashtable recorderEntries = new Hashtable();
 
     //////////////////////////////////////////////////////////////////////
     // CONSTRUCTORS / INITIALIZERS
@@ -206,9 +206,10 @@ public class Recorder extends Task implements SubBuildListener {
      */
     protected RecorderEntry getRecorder(String name, Project proj)
          throws BuildException {
-        RecorderEntry entry = recorderEntries.get(name);
+        Object o = recorderEntries.get(name);
+        RecorderEntry entry;
 
-        if (entry == null) {
+        if (o == null) {
             // create a recorder entry
             entry = new RecorderEntry(name);
 
@@ -219,8 +220,9 @@ public class Recorder extends Task implements SubBuildListener {
             }
             entry.setProject(proj);
             recorderEntries.put(name, entry);
+        } else {
+            entry = (RecorderEntry) o;
         }
-
         return entry;
     }
 
@@ -306,12 +308,12 @@ public class Recorder extends Task implements SubBuildListener {
      *
      * @since Ant 1.7
      */
-    @SuppressWarnings("unchecked")
     private void cleanup() {
-        Hashtable<String, RecorderEntry> entries
-                = (Hashtable<String, RecorderEntry>) recorderEntries.clone();
-        for (Map.Entry<String, RecorderEntry> entry : entries.entrySet()) {
-            RecorderEntry re = entry.getValue();
+        Hashtable entries = (Hashtable) recorderEntries.clone();
+        Iterator itEntries = entries.entrySet().iterator();
+        while (itEntries.hasNext()) {
+            Map.Entry entry = (Map.Entry) itEntries.next();
+            RecorderEntry re = (RecorderEntry) entry.getValue();
             if (re.getProject() == getProject()) {
                 recorderEntries.remove(entry.getKey());
             }
