@@ -20,16 +20,21 @@ package org.apache.tools.ant.taskdefs;
 
 import java.io.BufferedOutputStream;
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
-import java.util.Enumeration;
+import java.lang.reflect.Constructor;
+import java.lang.reflect.InvocationTargetException;
+import java.nio.file.Files;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 import java.util.Vector;
 import java.util.zip.GZIPOutputStream;
+
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.DirectoryScanner;
 import org.apache.tools.ant.Project;
@@ -41,8 +46,8 @@ import org.apache.tools.ant.types.ResourceCollection;
 import org.apache.tools.ant.types.resources.ArchiveResource;
 import org.apache.tools.ant.types.resources.FileProvider;
 import org.apache.tools.ant.types.resources.FileResource;
-import org.apache.tools.ant.types.selectors.SelectorUtils;
 import org.apache.tools.ant.types.resources.TarResource;
+import org.apache.tools.ant.types.selectors.SelectorUtils;
 import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.MergingMapper;
 import org.apache.tools.ant.util.ResourceUtils;
@@ -67,30 +72,35 @@ public class Tar extends MatchingTask {
      *             Tar.WARN is deprecated and is replaced with
      *             Tar.TarLongFileMode.WARN
      */
+    @Deprecated
     public static final String WARN = "warn";
     /**
      * @deprecated since 1.5.x.
      *             Tar.FAIL is deprecated and is replaced with
      *             Tar.TarLongFileMode.FAIL
      */
+    @Deprecated
     public static final String FAIL = "fail";
     /**
      * @deprecated since 1.5.x.
      *             Tar.TRUNCATE is deprecated and is replaced with
      *             Tar.TarLongFileMode.TRUNCATE
      */
+    @Deprecated
     public static final String TRUNCATE = "truncate";
     /**
      * @deprecated since 1.5.x.
      *             Tar.GNU is deprecated and is replaced with
      *             Tar.TarLongFileMode.GNU
      */
+    @Deprecated
     public static final String GNU = "gnu";
     /**
      * @deprecated since 1.5.x.
      *             Tar.OMIT is deprecated and is replaced with
      *             Tar.TarLongFileMode.OMIT
      */
+    @Deprecated
     public static final String OMIT = "omit";
 
     // CheckStyle:VisibilityModifier OFF - bc
@@ -100,12 +110,10 @@ public class Tar extends MatchingTask {
     private TarLongFileMode longFileMode = new TarLongFileMode();
 
     // need to keep the package private version for backwards compatibility
-    Vector filesets = new Vector();
+    Vector<TarFileSet> filesets = new Vector<>();
     // we must keep two lists since other classes may modify the
     // filesets Vector (it is package private) without us noticing
-    private Vector resourceCollections = new Vector();
-
-    Vector fileSetFiles = new Vector();
+    private final List<ResourceCollection> resourceCollections = new Vector<>();
 
     // CheckStyle:VisibilityModifier ON
 
@@ -116,12 +124,18 @@ public class Tar extends MatchingTask {
 
     private TarCompressionMethod compression = new TarCompressionMethod();
 
+    /**
+     * Encoding to use for filenames, defaults to the platform's
+     * default encoding.
+     */
+    private String encoding;
+
     /**
      * Add a new fileset with the option to specify permissions
      * @return the tar fileset to be used as the nested element.
      */
     public TarFileSet createTarFileSet() {
-        TarFileSet fs = new TarFileSet();
+        final TarFileSet fs = new TarFileSet();
         fs.setProject(getProject());
         filesets.addElement(fs);
         return fs;
@@ -132,7 +146,7 @@ public class Tar extends MatchingTask {
      * @param res a resource collection to archive.
      * @since Ant 1.7
      */
-    public void add(ResourceCollection res) {
+    public void add(final ResourceCollection res) {
         resourceCollections.add(res);
     }
 
@@ -142,7 +156,8 @@ public class Tar extends MatchingTask {
      * @deprecated since 1.5.x.
      *             For consistency with other tasks, please use setDestFile().
      */
-    public void setTarfile(File tarFile) {
+    @Deprecated
+    public void setTarfile(final File tarFile) {
         this.tarFile = tarFile;
     }
 
@@ -151,7 +166,7 @@ public class Tar extends MatchingTask {
      * @since Ant 1.5
      * @param destFile The output of the tar
      */
-    public void setDestFile(File destFile) {
+    public void setDestFile(final File destFile) {
         this.tarFile = destFile;
     }
 
@@ -159,7 +174,7 @@ public class Tar extends MatchingTask {
      * This is the base directory to look in for things to tar.
      * @param baseDir the base directory.
      */
-    public void setBasedir(File baseDir) {
+    public void setBasedir(final File baseDir) {
         this.baseDir = baseDir;
     }
 
@@ -182,9 +197,9 @@ public class Tar extends MatchingTask {
      *             mechanism do the work and also to encapsulate operations on
      *             the mode in its own class.
      */
-    public void setLongfile(String mode) {
-        log("DEPRECATED - The setLongfile(String) method has been deprecated."
-            + " Use setLongfile(Tar.TarLongFileMode) instead.");
+    @Deprecated
+    public void setLongfile(final String mode) {
+        log("DEPRECATED - The setLongfile(String) method has been deprecated. Use setLongfile(Tar.TarLongFileMode) instead.");
         this.longFileMode = new TarLongFileMode();
         longFileMode.setValue(mode);
     }
@@ -204,7 +219,7 @@ public class Tar extends MatchingTask {
      * </ul>
      * @param mode the mode to handle long file names.
      */
-    public void setLongfile(TarLongFileMode mode) {
+    public void setLongfile(final TarLongFileMode mode) {
         this.longFileMode = mode;
     }
 
@@ -215,17 +230,33 @@ public class Tar extends MatchingTask {
      * <li>  none - no compression
      * <li>  gzip - Gzip compression
      * <li>  bzip2 - Bzip2 compression
+     * <li>xz - XZ compression, requires XZ for Java
      * </ul>
      * @param mode the compression method.
      */
-    public void setCompression(TarCompressionMethod mode) {
+    public void setCompression(final TarCompressionMethod mode) {
         this.compression = mode;
     }
 
+    /**
+     * Encoding to use for filenames, defaults to the platform's
+     * default encoding.
+     *
+     * <p>For a list of possible values see <a
+     * href="http://java.sun.com/j2se/1.5.0/docs/guide/intl/encoding.doc.html">http://java.sun.com/j2se/1.5.0/docs/guide/intl/encoding.doc.html</a>.</p>
+     * @param encoding the encoding name
+     *
+     * @since Ant 1.9.5
+     */
+    public void setEncoding(final String encoding) {
+        this.encoding = encoding;
+    }
+
     /**
      * do the business
      * @throws BuildException on error
      */
+    @Override
     public void execute() throws BuildException {
         if (tarFile == null) {
             throw new BuildException("tarfile attribute must be set!",
@@ -242,7 +273,7 @@ public class Tar extends MatchingTask {
                                      getLocation());
         }
 
-        Vector savedFileSets = (Vector) filesets.clone();
+        final Vector<TarFileSet> savedFileSets = new Vector<>(filesets);
         try {
             if (baseDir != null) {
                 if (!baseDir.exists()) {
@@ -251,27 +282,25 @@ public class Tar extends MatchingTask {
                 }
 
                 // add the main fileset to the list of filesets to process.
-                TarFileSet mainFileSet = new TarFileSet(fileset);
+                final TarFileSet mainFileSet = new TarFileSet(fileset);
                 mainFileSet.setDir(baseDir);
                 filesets.addElement(mainFileSet);
             }
 
-            if (filesets.size() == 0 && resourceCollections.size() == 0) {
-                throw new BuildException("You must supply either a basedir "
-                                         + "attribute or some nested resource"
-                                         + " collections.",
-                                         getLocation());
+            if (filesets.isEmpty() && resourceCollections.isEmpty()) {
+                throw new BuildException(
+                    "You must supply either a basedir attribute or some nested resource collections.",
+                    getLocation());
             }
 
             // check if tar is out of date with respect to each
             // fileset
             boolean upToDate = true;
-            for (Enumeration e = filesets.elements(); e.hasMoreElements();) {
-                upToDate &= check((TarFileSet) e.nextElement());
+            for (final TarFileSet tfs : filesets) {
+                upToDate &= check(tfs);
             }
-            for (Enumeration e = resourceCollections.elements();
-                 e.hasMoreElements();) {
-                upToDate &= check((ResourceCollection) e.nextElement());
+            for (final ResourceCollection rcol : resourceCollections) {
+                upToDate &= check(rcol);
             }
 
             if (upToDate) {
@@ -280,20 +309,20 @@ public class Tar extends MatchingTask {
                 return;
             }
 
-            File parent = tarFile.getParentFile();
-            if (parent != null && !parent.isDirectory() && !parent.mkdirs()) {
-                throw new BuildException("Failed to create missing parent"
-                                         + " directory for " + tarFile);
+            final File parent = tarFile.getParentFile();
+            if (parent != null && !parent.isDirectory()
+                && !(parent.mkdirs() || parent.isDirectory())) {
+                throw new BuildException(
+                    "Failed to create missing parent directory for %s",
+                    tarFile);
             }
 
             log("Building tar: " + tarFile.getAbsolutePath(), Project.MSG_INFO);
 
-            TarOutputStream tOut = null;
-            try {
-                tOut = new TarOutputStream(
-                    compression.compress(
-                        new BufferedOutputStream(
-                            new FileOutputStream(tarFile))));
+            try (TarOutputStream tOut = new TarOutputStream(
+                compression.compress(new BufferedOutputStream(
+                    Files.newOutputStream(tarFile.toPath()))),
+                encoding)) {
                 tOut.setDebug(true);
                 if (longFileMode.isTruncateMode()) {
                     tOut.setLongFileMode(TarOutputStream.LONGFILE_TRUNCATE);
@@ -308,19 +337,15 @@ public class Tar extends MatchingTask {
                 }
 
                 longWarningGiven = false;
-                for (Enumeration e = filesets.elements();
-                     e.hasMoreElements();) {
-                    tar((TarFileSet) e.nextElement(), tOut);
+                for (final TarFileSet tfs : filesets) {
+                    tar(tfs, tOut);
                 }
-                for (Enumeration e = resourceCollections.elements();
-                     e.hasMoreElements();) {
-                    tar((ResourceCollection) e.nextElement(), tOut);
+                for (final ResourceCollection rcol : resourceCollections) {
+                    tar(rcol, tOut);
                 }
-            } catch (IOException ioe) {
-                String msg = "Problem creating TAR: " + ioe.getMessage();
+            } catch (final IOException ioe) {
+                final String msg = "Problem creating TAR: " + ioe.getMessage();
                 throw new BuildException(msg, ioe, getLocation());
-            } finally {
-                FileUtils.close(tOut);
             }
         } finally {
             filesets = savedFileSets;
@@ -335,8 +360,8 @@ public class Tar extends MatchingTask {
      * @param tarFileSet the fileset that the file came from.
      * @throws IOException on error
      */
-    protected void tarFile(File file, TarOutputStream tOut, String vPath,
-                           TarFileSet tarFileSet)
+    protected void tarFile(final File file, final TarOutputStream tOut, final String vPath,
+                           final TarFileSet tarFileSet)
         throws IOException {
         if (file.equals(tarFile)) {
             // If the archive is built for the first time and it is
@@ -362,8 +387,8 @@ public class Tar extends MatchingTask {
      * @throws IOException on error
      * @since Ant 1.7
      */
-    protected void tarResource(Resource r, TarOutputStream tOut, String vPath,
-                               TarFileSet tarFileSet)
+    protected void tarResource(final Resource r, final TarOutputStream tOut, String vPath,
+                               final TarFileSet tarFileSet)
         throws IOException {
 
         if (!r.isExists()) {
@@ -373,7 +398,7 @@ public class Tar extends MatchingTask {
         boolean preserveLeadingSlashes = false;
 
         if (tarFileSet != null) {
-            String fullpath = tarFileSet.getFullpath(this.getProject());
+            final String fullpath = tarFileSet.getFullpath(this.getProject());
             if (fullpath.length() > 0) {
                 vPath = fullpath;
             } else {
@@ -393,7 +418,7 @@ public class Tar extends MatchingTask {
             preserveLeadingSlashes = tarFileSet.getPreserveLeadingSlashes();
 
             if (vPath.startsWith("/") && !preserveLeadingSlashes) {
-                int l = vPath.length();
+                final int l = vPath.length();
                 if (l <= 1) {
                     // we would end up adding "" to the archive
                     return;
@@ -427,14 +452,14 @@ public class Tar extends MatchingTask {
             }
         }
 
-        TarEntry te = new TarEntry(vPath, preserveLeadingSlashes);
+        final TarEntry te = new TarEntry(vPath, preserveLeadingSlashes);
         te.setModTime(r.getLastModified());
         // preserve permissions
         if (r instanceof ArchiveResource) {
-            ArchiveResource ar = (ArchiveResource) r;
+            final ArchiveResource ar = (ArchiveResource) r;
             te.setMode(ar.getMode());
             if (r instanceof TarResource) {
-                TarResource tr = (TarResource) r;
+                final TarResource tr = (TarResource) r;
                 te.setUserName(tr.getUserName());
                 te.setUserId(tr.getUid());
                 te.setGroupName(tr.getGroup());
@@ -481,7 +506,7 @@ public class Tar extends MatchingTask {
             if (!r.isDirectory()) {
                 in = r.getInputStream();
 
-                byte[] buffer = new byte[BUFFER_SIZE];
+                final byte[] buffer = new byte[BUFFER_SIZE];
                 int count = 0;
                 do {
                     tOut.write(buffer, 0, count);
@@ -502,7 +527,8 @@ public class Tar extends MatchingTask {
      * @deprecated since 1.5.x.
      *             use the two-arg version instead.
      */
-    protected boolean archiveIsUpToDate(String[] files) {
+    @Deprecated
+    protected boolean archiveIsUpToDate(final String[] files) {
         return archiveIsUpToDate(files, baseDir);
     }
 
@@ -513,9 +539,9 @@ public class Tar extends MatchingTask {
      * @return true if the archive is up to date.
      * @since Ant 1.5.2
      */
-    protected boolean archiveIsUpToDate(String[] files, File dir) {
-        SourceFileScanner sfs = new SourceFileScanner(this);
-        MergingMapper mm = new MergingMapper();
+    protected boolean archiveIsUpToDate(final String[] files, final File dir) {
+        final SourceFileScanner sfs = new SourceFileScanner(this);
+        final MergingMapper mm = new MergingMapper();
         mm.setTo(tarFile.getAbsolutePath());
         return sfs.restrict(files, dir, null, mm).length == 0;
     }
@@ -526,7 +552,7 @@ public class Tar extends MatchingTask {
      * @return true if the archive is up to date.
      * @since Ant 1.7
      */
-    protected boolean archiveIsUpToDate(Resource r) {
+    protected boolean archiveIsUpToDate(final Resource r) {
         return SelectorUtils.isOutOfDate(new FileResource(tarFile), r,
                                          FileUtils.getFileUtils()
                                          .getFileTimestampGranularity());
@@ -561,27 +587,27 @@ public class Tar extends MatchingTask {
      * @return whether the archive is up-to-date
      * @since Ant 1.7
      */
-    protected boolean check(ResourceCollection rc) {
+    protected boolean check(final ResourceCollection rc) {
         boolean upToDate = true;
         if (isFileFileSet(rc)) {
-            FileSet fs = (FileSet) rc;
+            final FileSet fs = (FileSet) rc;
             upToDate = check(fs.getDir(getProject()), getFileNames(fs));
         } else if (!rc.isFilesystemOnly() && !supportsNonFileResources()) {
             throw new BuildException("only filesystem resources are supported");
         } else if (rc.isFilesystemOnly()) {
-            HashSet basedirs = new HashSet();
-            HashMap basedirToFilesMap = new HashMap();
-            for (Resource res : rc) {
-                FileResource r = ResourceUtils
+            final Set<File> basedirs = new HashSet<>();
+            final Map<File, List<String>> basedirToFilesMap = new HashMap<>();
+            for (final Resource res : rc) {
+                final FileResource r = ResourceUtils
                     .asFileResource(res.as(FileProvider.class));
                 File base = r.getBaseDir();
                 if (base == null) {
                     base = Copy.NULL_FILE_PLACEHOLDER;
                 }
                 basedirs.add(base);
-                Vector files = (Vector) basedirToFilesMap.get(base);
+                List<String> files = basedirToFilesMap.get(base);
                 if (files == null) {
-                    files = new Vector();
+                    files = new Vector<>();
                     basedirToFilesMap.put(base, files);
                 }
                 if (base == Copy.NULL_FILE_PLACEHOLDER) {
@@ -590,19 +616,13 @@ public class Tar extends MatchingTask {
                     files.add(r.getName());
                 }
             }
-            Iterator iter = basedirs.iterator();
-            while (iter.hasNext()) {
-                File base = (File) iter.next();
-                Vector f = (Vector) basedirToFilesMap.get(base);
-                String[] files = (String[]) f.toArray(new String[f.size()]);
-                upToDate &=
-                    check(base == Copy.NULL_FILE_PLACEHOLDER ? null : base,
-                          files);
+            for (final File base : basedirs) {
+                final File tmpBase = base == Copy.NULL_FILE_PLACEHOLDER ? null : base;
+                final List<String> files = basedirToFilesMap.get(base);
+                upToDate &= check(tmpBase, files);
             }
         } else { // non-file resources
-            Iterator<Resource> iter = rc.iterator();
-            while (upToDate && iter.hasNext()) {
-                Resource r = iter.next();
+            for (Resource r : rc) {
                 upToDate = archiveIsUpToDate(r);
             }
         }
@@ -610,7 +630,7 @@ public class Tar extends MatchingTask {
     }
 
     /**
-     * Checks whether the archive is out-of-date with respect to the
+     * <p>Checks whether the archive is out-of-date with respect to the
      * given files, ensures that the archive won't contain itself.</p>
      *
      * @param basedir base directory for file names
@@ -618,21 +638,35 @@ public class Tar extends MatchingTask {
      * @return whether the archive is up-to-date
      * @since Ant 1.7
      */
-    protected boolean check(File basedir, String[] files) {
+    protected boolean check(final File basedir, final String[] files) {
         boolean upToDate = true;
         if (!archiveIsUpToDate(files, basedir)) {
             upToDate = false;
         }
 
-        for (int i = 0; i < files.length; ++i) {
-            if (tarFile.equals(new File(basedir, files[i]))) {
-                throw new BuildException("A tar file cannot include "
-                                         + "itself", getLocation());
+        for (String file : files) {
+            if (tarFile.equals(new File(basedir, file))) {
+                throw new BuildException("A tar file cannot include itself",
+                    getLocation());
             }
         }
         return upToDate;
     }
 
+    /**
+     * <p>Checks whether the archive is out-of-date with respect to the
+     * given files, ensures that the archive won't contain itself.</p>
+     *
+     * @param basedir base directory for file names
+     * @param files array of relative file names
+     * @return whether the archive is up-to-date
+     * @see #check(File, String[])
+     * @since Ant 1.9.5
+     */
+    protected boolean check(final File basedir, final Collection<String> files) {
+        return check(basedir, files.toArray(new String[files.size()]));
+    }
+
     /**
      * Adds the resources contained in this collection to the archive.
      *
@@ -644,36 +678,33 @@ public class Tar extends MatchingTask {
      * @throws IOException on error.
      * @since Ant 1.7
      */
-    protected void tar(ResourceCollection rc, TarOutputStream tOut)
+    protected void tar(final ResourceCollection rc, final TarOutputStream tOut)
         throws IOException {
         ArchiveFileSet afs = null;
         if (rc instanceof ArchiveFileSet) {
             afs = (ArchiveFileSet) rc;
         }
         if (afs != null && afs.size() > 1
-            && afs.getFullpath(this.getProject()).length() > 0) {
-            throw new BuildException("fullpath attribute may only "
-                                     + "be specified for "
-                                     + "filesets that specify a "
-                                     + "single file.");
+            && !afs.getFullpath(this.getProject()).isEmpty()) {
+            throw new BuildException(
+                "fullpath attribute may only be specified for filesets that specify a single file.");
         }
-        TarFileSet tfs = asTarFileSet(afs);
+        final TarFileSet tfs = asTarFileSet(afs);
 
         if (isFileFileSet(rc)) {
-            FileSet fs = (FileSet) rc;
-            String[] files = getFileNames(fs);
-            for (int i = 0; i < files.length; i++) {
-                File f = new File(fs.getDir(getProject()), files[i]);
-                String name = files[i].replace(File.separatorChar, '/');
+            final FileSet fs = (FileSet) rc;
+            for (String file : getFileNames(fs)) {
+                final File f = new File(fs.getDir(getProject()), file);
+                final String name = file.replace(File.separatorChar, '/');
                 tarFile(f, tOut, name, tfs);
             }
         } else if (rc.isFilesystemOnly()) {
-            for (Resource r : rc) {
-                File f = r.as(FileProvider.class).getFile();
+            for (final Resource r : rc) {
+                final File f = r.as(FileProvider.class).getFile();
                 tarFile(f, tOut, f.getName(), tfs);
             }
         } else { // non-file resources
-            for (Resource r : rc) {
+            for (final Resource r : rc) {
                 tarResource(r, tOut, r.getName(), tfs);
             }
         }
@@ -686,7 +717,7 @@ public class Tar extends MatchingTask {
      * @return true if the collection is a fileset.
      * @since Ant 1.7
      */
-    protected static boolean isFileFileSet(ResourceCollection rc) {
+    protected static boolean isFileFileSet(final ResourceCollection rc) {
         return rc instanceof FileSet && rc.isFilesystemOnly();
     }
 
@@ -697,11 +728,11 @@ public class Tar extends MatchingTask {
      * @return a list of the filenames.
      * @since Ant 1.7
      */
-    protected static String[] getFileNames(FileSet fs) {
-        DirectoryScanner ds = fs.getDirectoryScanner(fs.getProject());
-        String[] directories = ds.getIncludedDirectories();
-        String[] filesPerSe = ds.getIncludedFiles();
-        String[] files = new String [directories.length + filesPerSe.length];
+    protected static String[] getFileNames(final FileSet fs) {
+        final DirectoryScanner ds = fs.getDirectoryScanner(fs.getProject());
+        final String[] directories = ds.getIncludedDirectories();
+        final String[] filesPerSe = ds.getIncludedFiles();
+        final String[] files = new String[directories.length + filesPerSe.length];
         System.arraycopy(directories, 0, files, 0, directories.length);
         System.arraycopy(filesPerSe, 0, files, directories.length,
                          filesPerSe.length);
@@ -717,8 +748,8 @@ public class Tar extends MatchingTask {
      * @return a new TarFileSet.
      * @since Ant 1.7
      */
-    protected TarFileSet asTarFileSet(ArchiveFileSet archiveFileSet) {
-        TarFileSet tfs = null;
+    protected TarFileSet asTarFileSet(final ArchiveFileSet archiveFileSet) {
+        TarFileSet tfs;
         if (archiveFileSet != null && archiveFileSet instanceof TarFileSet) {
             tfs = (TarFileSet) archiveFileSet;
         } else {
@@ -738,7 +769,7 @@ public class Tar extends MatchingTask {
 
                 if (archiveFileSet
                     instanceof org.apache.tools.ant.types.TarFileSet) {
-                    org.apache.tools.ant.types.TarFileSet t =
+                    final org.apache.tools.ant.types.TarFileSet t =
                         (org.apache.tools.ant.types.TarFileSet) archiveFileSet;
                     if (t.hasUserNameBeenSet()) {
                         tfs.setUserName(t.getUserName());
@@ -774,7 +805,7 @@ public class Tar extends MatchingTask {
          *
          * @param fileset a <code>FileSet</code> value
          */
-        public TarFileSet(FileSet fileset) {
+        public TarFileSet(final FileSet fileset) {
             super(fileset);
         }
 
@@ -792,11 +823,10 @@ public class Tar extends MatchingTask {
          * @return a list of file and directory names, relative to
          *    the baseDir for the project.
          */
-        public String[] getFiles(Project p) {
+        public String[] getFiles(final Project p) {
             if (files == null) {
                 files = getFileNames(this);
             }
-
             return files;
         }
 
@@ -806,7 +836,7 @@ public class Tar extends MatchingTask {
          * optional, default=0644
          * @param octalString a 3 digit octal string.
          */
-        public void setMode(String octalString) {
+        public void setMode(final String octalString) {
             setFileMode(octalString);
         }
 
@@ -823,7 +853,7 @@ public class Tar extends MatchingTask {
          * Optional, default is <code>false</code>.
          * @param b the leading slashes flag.
          */
-        public void setPreserveLeadingSlashes(boolean b) {
+        public void setPreserveLeadingSlashes(final boolean b) {
             this.preserveLeadingSlashes = b;
         }
 
@@ -850,7 +880,7 @@ public class Tar extends MatchingTask {
             POSIX = "posix",
             OMIT = "omit";
 
-        private final String[] validModes = {
+        private static final String[] VALID_MODES = {
             WARN, FAIL, TRUNCATE, GNU, POSIX, OMIT
         };
 
@@ -863,8 +893,9 @@ public class Tar extends MatchingTask {
         /**
          * @return the possible values for this enumerated type.
          */
+        @Override
         public String[] getValues() {
-            return validModes;
+            return VALID_MODES;
         }
 
         /**
@@ -929,7 +960,11 @@ public class Tar extends MatchingTask {
          *    BZIP2 compression
          */
         private static final String BZIP2 = "bzip2";
-
+        /**
+         *  XZ compression
+         * @since 1.10.1
+         */
+        private static final String XZ = "xz";
 
         /**
          * Default constructor
@@ -943,8 +978,9 @@ public class Tar extends MatchingTask {
          *  Get valid enumeration values.
          *  @return valid enumeration values
          */
+        @Override
         public String[] getValues() {
-            return new String[] {NONE, GZIP, BZIP2 };
+            return new String[] {NONE, GZIP, BZIP2, XZ};
         }
 
         /**
@@ -960,14 +996,39 @@ public class Tar extends MatchingTask {
             final String v = getValue();
             if (GZIP.equals(v)) {
                 return new GZIPOutputStream(ostream);
-            } else {
-                if (BZIP2.equals(v)) {
-                    ostream.write('B');
-                    ostream.write('Z');
-                    return new CBZip2OutputStream(ostream);
-                }
+            }
+            if (XZ.equals(v)) {
+                return newXZOutputStream(ostream);
+            }
+            if (BZIP2.equals(v)) {
+                ostream.write('B');
+                ostream.write('Z');
+                return new CBZip2OutputStream(ostream);
             }
             return ostream;
         }
+
+        private static OutputStream newXZOutputStream(OutputStream ostream)
+            throws BuildException {
+            try {
+                Class<?> fClazz = Class.forName("org.tukaani.xz.FilterOptions");
+                Class<?> oClazz = Class.forName("org.tukaani.xz.LZMA2Options");
+                Class<? extends OutputStream> sClazz =
+                    Class.forName("org.tukaani.xz.XZOutputStream")
+                    .asSubclass(OutputStream.class);
+                Constructor<? extends OutputStream> c =
+                    sClazz.getConstructor(OutputStream.class, fClazz);
+                return c.newInstance(ostream, oClazz.newInstance());
+            } catch (ClassNotFoundException ex) {
+                throw new BuildException("xz compression requires the XZ for Java library",
+                                         ex);
+            } catch (NoSuchMethodException
+                     | InstantiationException
+                     | IllegalAccessException
+                     | InvocationTargetException
+                     ex) {
+                throw new BuildException("failed to create XZOutputStream", ex);
+            }
+        }
     }
 }
