@@ -21,15 +21,18 @@ package org.apache.tools.ant.taskdefs.optional;
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.lang.reflect.Field;
 import java.net.URL;
+import java.nio.file.Files;
+import java.util.ArrayList;
 import java.util.Enumeration;
+import java.util.HashMap;
 import java.util.Hashtable;
+import java.util.List;
+import java.util.Map;
 import java.util.Vector;
 
 import javax.xml.parsers.ParserConfigurationException;
@@ -60,6 +63,7 @@ import org.apache.tools.ant.types.resources.FileResource;
 import org.apache.tools.ant.types.resources.URLProvider;
 import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.JAXPUtils;
+import org.apache.tools.ant.util.JavaEnvUtils;
 import org.xml.sax.EntityResolver;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
@@ -123,7 +127,10 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
     private final Hashtable<String, Object> params = new Hashtable<String, Object>();
 
     /** factory attributes */
-    private final Vector attributes = new Vector();
+    private final List<Object[]> attributes = new ArrayList<Object[]>();
+
+    /** factory features */
+    private final Map<String, Boolean> features = new HashMap<String, Boolean>();
 
     /** whether to suppress warnings */
     private boolean suppressWarnings = false;
@@ -135,7 +142,7 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
      * Constructor for TraXLiaison.
      * @throws Exception never
      */
-    public TraXLiaison() throws Exception {
+    public TraXLiaison() throws Exception { //NOSONAR
     }
 
     /**
@@ -183,8 +190,8 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
         InputStream fis = null;
         OutputStream fos = null;
         try {
-            fis = new BufferedInputStream(new FileInputStream(infile));
-            fos = new BufferedOutputStream(new FileOutputStream(outfile));
+            fis = new BufferedInputStream(Files.newInputStream(infile.toPath()));
+            fos = new BufferedOutputStream(Files.newOutputStream(outfile.toPath()));
             final StreamResult res = new StreamResult(fos);
             // not sure what could be the need of this...
             res.setSystemId(JAXPUtils.getSystemId(outfile));
@@ -293,28 +300,22 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
         // and avoid keeping the handle until the object is garbaged.
         // (always keep control), otherwise you won't be able to delete
         // the file quickly on windows.
-        InputStream xslStream = null;
-        try {
-            xslStream
-                = new BufferedInputStream(stylesheet.getInputStream());
+        try (InputStream xslStream =
+             new BufferedInputStream(stylesheet.getInputStream())) {
             templatesModTime = stylesheet.getLastModified();
             final Source src = getSource(xslStream, stylesheet);
             templates = getFactory().newTemplates(src);
-        } finally {
-            if (xslStream != null) {
-                xslStream.close();
-            }
         }
     }
 
     /**
      * Create a new transformer based on the liaison settings
-     * @throws Exception thrown if there is an error during creation.
      * @see #setStylesheet(java.io.File)
      * @see #addParam(java.lang.String, java.lang.String)
      * @see #setOutputProperty(java.lang.String, java.lang.String)
      */
-    private void createTransformer() throws Exception {
+    private void createTransformer()
+        throws IOException, ParserConfigurationException, SAXException, TransformerException {
         if (templates == null) {
             readTemplates();
         }
@@ -333,7 +334,7 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
         }
 
         if (traceConfiguration != null) {
-            if ("org.apache.xalan.transformer.TransformerImpl"
+            if ("org.apache.xalan.transformer.TransformerImpl" //NOSONAR
                 .equals(transformer.getClass().getName())) {
                 try {
                     final Class traceSupport =
@@ -421,32 +422,31 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
             }
         }
 
-        try { // #51668, #52382
-            final Field _isNotSecureProcessing = tfactory.getClass().getDeclaredField("_isNotSecureProcessing");
-            _isNotSecureProcessing.setAccessible(true);
-            _isNotSecureProcessing.set(tfactory, Boolean.TRUE);
-        } catch (final Exception x) {
-            if (project != null) {
-                project.log(x.toString(), Project.MSG_DEBUG);
-            }
-        }
+        applyReflectionHackForExtensionMethods();
 
         tfactory.setErrorListener(this);
 
         // specific attributes for the transformer
         final int size = attributes.size();
         for (int i = 0; i < size; i++) {
-            final Object[] pair = (Object[]) attributes.elementAt(i);
+            final Object[] pair = attributes.get(i);
             tfactory.setAttribute((String) pair[0], pair[1]);
         }
 
+        for (Map.Entry<String, Boolean> feature : features.entrySet()) {
+            try {
+                tfactory.setFeature(feature.getKey(), feature.getValue());
+            } catch (TransformerConfigurationException ex) {
+                throw new BuildException(ex);
+            }
+        }
+
         if (uriResolver != null) {
             tfactory.setURIResolver(uriResolver);
         }
         return tfactory;
     }
 
-
     /**
      * Set the factory name to use instead of JAXP default lookup.
      * @param name the fully qualified class name of the factory to use
@@ -466,7 +466,17 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
      */
     public void setAttribute(final String name, final Object value) {
         final Object[] pair = new Object[]{name, value};
-        attributes.addElement(pair);
+        attributes.add(pair);
+    }
+
+    /**
+     * Set a custom feature for the JAXP factory implementation.
+     * @param name the feature name.
+     * @param value the value of the feature
+     * @since Ant 1.9.8
+     */
+    public void setFeature(final String name, final boolean value) {
+        features.put(name, value);
     }
 
     /**
@@ -625,6 +635,10 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
                         (XSLTProcess.Factory.Attribute) attrs.nextElement();
                 setAttribute(attr.getName(), attr.getValue());
             }
+            for (final XSLTProcess.Factory.Feature feature
+                     : factory.getFeatures()) {
+                setFeature(feature.getName(), feature.getValue());
+            }
         }
 
         final XMLCatalog xmlCatalog = xsltTask.getXMLCatalog();
@@ -647,4 +661,20 @@ public class TraXLiaison implements XSLTLiaison4, ErrorListener, XSLTLoggerAware
 
         traceConfiguration = xsltTask.getTraceConfiguration();
     }
+
+    private void applyReflectionHackForExtensionMethods() {
+        // Jigsaw doesn't allow reflection to work, so we can stop trying
+        if (!JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9)) {
+            try { // #51668, #52382
+                final Field _isNotSecureProcessing = tfactory.getClass().getDeclaredField("_isNotSecureProcessing");
+                _isNotSecureProcessing.setAccessible(true);
+                _isNotSecureProcessing.set(tfactory, Boolean.TRUE);
+            } catch (final Exception x) {
+                if (project != null) {
+                    project.log(x.toString(), Project.MSG_DEBUG);
+                }
+            }
+        }
+    }
+
 }
