@@ -26,6 +26,7 @@ import junit.framework.AssertionFailedError;
 import junit.framework.Test;
 
 import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.util.FileUtils;
 
 /**
  * Prints short summary output of the test to Ant's logging system.
@@ -50,12 +51,6 @@ public class SummaryJUnitResultFormatter
     private String systemOutput = null;
     private String systemError = null;
 
-    /**
-     * Empty
-     */
-    public SummaryJUnitResultFormatter() {
-    }
-
     /**
      *  Insures that a line of log output is written and flushed as a single
      *  operation, to prevent lines from being spliced into other lines.
@@ -80,9 +75,10 @@ public class SummaryJUnitResultFormatter
      * The testsuite started.
      * @param suite the testsuite.
      */
+    @Override
     public void startTestSuite(JUnitTest suite) {
         String newLine = System.getProperty("line.separator");
-        StringBuffer sb = new StringBuffer("Running ");
+        StringBuilder sb = new StringBuilder("Running ");
         int antThreadID = suite.getThread();
 
         sb.append(suite.getName());
@@ -98,12 +94,14 @@ public class SummaryJUnitResultFormatter
      * Empty
      * @param t not used.
      */
+    @Override
     public void startTest(Test t) {
     }
     /**
      * Empty
      * @param test not used.
      */
+    @Override
     public void endTest(Test test) {
     }
     /**
@@ -120,6 +118,7 @@ public class SummaryJUnitResultFormatter
      * @param test not used.
      * @param t not used.
      */
+    @Override
     public void addFailure(Test test, AssertionFailedError t) {
         addFailure(test, (Throwable) t);
     }
@@ -128,20 +127,24 @@ public class SummaryJUnitResultFormatter
      * @param test not used.
      * @param t not used.
      */
+    @Override
     public void addError(Test test, Throwable t) {
     }
 
     /** {@inheritDoc}. */
+    @Override
     public void setOutput(OutputStream out) {
         this.out = out;
     }
 
     /** {@inheritDoc}. */
+    @Override
     public void setSystemOutput(String out) {
         systemOutput = out;
     }
 
     /** {@inheritDoc}. */
+    @Override
     public void setSystemError(String err) {
         systemError = err;
     }
@@ -151,6 +154,7 @@ public class SummaryJUnitResultFormatter
      * the summary.
      * @param value if true write System.out and System.err to the summary.
      */
+    @Override
     public void setWithOutAndErr(boolean value) {
         withOutAndErr = value;
     }
@@ -160,9 +164,10 @@ public class SummaryJUnitResultFormatter
      * @param suite the testsuite.
      * @throws BuildException if there is an error.
      */
+    @Override
     public void endTestSuite(JUnitTest suite) throws BuildException {
         String newLine = System.getProperty("line.separator");
-        StringBuffer sb = new StringBuffer("Tests run: ");
+        StringBuilder sb = new StringBuilder("Tests run: ");
         sb.append(suite.runCount());
         sb.append(", Failures: ");
         sb.append(suite.failureCount());
@@ -202,11 +207,7 @@ public class SummaryJUnitResultFormatter
             writeOutputLine(sb.toString().getBytes());
         } finally {
             if (out != System.out && out != System.err) {
-                try {
-                    out.close();
-                } catch (IOException e) {
-                    // ignore
-                }
+                FileUtils.close(out);
             }
         }
     }
