@@ -19,10 +19,10 @@
 package org.apache.tools.ant.taskdefs.optional.ssh;
 
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.file.Files;
 import java.util.Iterator;
 import java.util.List;
 
@@ -36,13 +36,13 @@ import com.jcraft.jsch.Session;
 public class ScpToMessage extends AbstractSshMessage {
 
     private static final int HUNDRED_KILOBYTES = 102400;
-    private static final int BUFFER_SIZE = 100*1024;
+    private static final int BUFFER_SIZE = 100 * 1024;
     private static final int DEFAULT_DIR_MODE = 0755;
     private static final int DEFAULT_FILE_MODE = 0644;
 
     private File localFile;
     private String remotePath;
-    private List directoryList;
+    private List<Directory> directoryList;
     private Integer fileMode, dirMode;
     private boolean preserveLastModified;
 
@@ -61,7 +61,18 @@ public class ScpToMessage extends AbstractSshMessage {
      * @since Ant 1.7
      */
     public ScpToMessage(final boolean verbose, final Session session) {
-        super(verbose, session);
+        this(verbose, false, session);
+    }
+
+    /**
+     * Constructor for ScpToMessage
+     * @param verbose if true do verbose logging
+     * @param compressed if true use compression
+     * @param session the ssh session to use
+     * @since Ant 1.9.8
+     */
+    public ScpToMessage(final boolean verbose, boolean compressed, final Session session) {
+        super(verbose, compressed, session);
     }
 
     /**
@@ -78,7 +89,26 @@ public class ScpToMessage extends AbstractSshMessage {
                         final File aLocalFile,
                         final String aRemotePath,
                         final boolean preserveLastModified) {
-        this(verbose, session, aRemotePath);
+        this(verbose, false, session, aLocalFile, aRemotePath, preserveLastModified);
+    }
+
+    /**
+     * Constructor for a local file to remote.
+     * @param verbose if true do verbose logging
+     * @param compressed if true use compression
+     * @param session the scp session to use
+     * @param aLocalFile the local file
+     * @param aRemotePath the remote path
+     * @param preserveLastModified whether to preserve the last modified timestamps
+     * @since Ant 1.9.8
+     */
+    public ScpToMessage(final boolean verbose,
+                        final boolean compressed,
+                        final Session session,
+                        final File aLocalFile,
+                        final String aRemotePath,
+                        final boolean preserveLastModified) {
+        this(verbose, compressed, session, aRemotePath);
         this.localFile = aLocalFile;
         this.preserveLastModified = preserveLastModified;
     }
@@ -94,10 +124,29 @@ public class ScpToMessage extends AbstractSshMessage {
      */
     public ScpToMessage(final boolean verbose,
                         final Session session,
-                        final List aDirectoryList,
+                        final List<Directory> aDirectoryList,
                         final String aRemotePath,
                         final boolean preserveLastModified) {
-        this(verbose, session, aRemotePath);
+        this(verbose, false, session, aDirectoryList, aRemotePath, preserveLastModified);
+    }
+
+    /**
+     * Constructor for a local directories to remote.
+     * @param verbose if true do verbose logging
+     * @param compressed whether to use compression
+     * @param session the scp session to use
+     * @param aDirectoryList a list of directories
+     * @param aRemotePath the remote path
+     * @param preserveLastModified whether to preserve the last modified timestamps
+     * @since Ant 1.9.8
+     */
+    public ScpToMessage(final boolean verbose,
+                        final boolean compressed,
+                        final Session session,
+                        final List<Directory> aDirectoryList,
+                        final String aRemotePath,
+                        final boolean preserveLastModified) {
+        this(verbose, compressed, session, aRemotePath);
         this.directoryList = aDirectoryList;
         this.preserveLastModified = preserveLastModified;
     }
@@ -127,7 +176,7 @@ public class ScpToMessage extends AbstractSshMessage {
      */
     public ScpToMessage(final boolean verbose,
                         final Session session,
-                        final List aDirectoryList,
+                        final List<Directory> aDirectoryList,
                         final String aRemotePath) {
         this(verbose, session, aDirectoryList, aRemotePath, false);
     }
@@ -135,14 +184,16 @@ public class ScpToMessage extends AbstractSshMessage {
     /**
      * Constructor for ScpToMessage.
      * @param verbose if true do verbose logging
+     * @param compressed if true use compression
      * @param session the scp session to use
      * @param aRemotePath the remote path
-     * @since Ant 1.6.2
+     * @since Ant 1.9.8
      */
     private ScpToMessage(final boolean verbose,
+                         final boolean compressed,
                          final Session session,
                          final String aRemotePath) {
-        super(verbose, session);
+        super(verbose, compressed, session);
         this.remotePath = aRemotePath;
     }
 
@@ -165,7 +216,7 @@ public class ScpToMessage extends AbstractSshMessage {
      * @param aRemotePath the remote path
      */
     public ScpToMessage(final Session session,
-                         final List aDirectoryList,
+                         final List<Directory> aDirectoryList,
                          final String aRemotePath) {
         this(false, session, aDirectoryList, aRemotePath);
     }
@@ -187,10 +238,17 @@ public class ScpToMessage extends AbstractSshMessage {
     }
 
     private void doSingleTransfer() throws IOException, JSchException {
-        final String cmd = "scp -t " + (getPreserveLastModified() ? "-p " : "") + remotePath;
+        StringBuilder sb = new StringBuilder("scp -t ");
+        if (getPreserveLastModified()) {
+            sb.append("-p ");
+        }
+        if (getCompressed()) {
+            sb.append("-C ");
+        }
+        sb.append(remotePath);
+        final String cmd = sb.toString();
         final Channel channel = openExecChannel(cmd);
         try {
-
             final OutputStream out = channel.getOutputStream();
             final InputStream in = channel.getInputStream();
 
@@ -206,10 +264,15 @@ public class ScpToMessage extends AbstractSshMessage {
     }
 
     private void doMultipleTransfer() throws IOException, JSchException {
-        final Channel channel =
-            openExecChannel("scp -r -d -t "
-                            + (getPreserveLastModified() ? "-p " : "")
-                            + remotePath);
+        StringBuilder sb = new StringBuilder("scp -r -d -t ");
+        if (getPreserveLastModified()) {
+            sb.append("-p ");
+        }
+        if (getCompressed()) {
+            sb.append("-C ");
+        }
+        sb.append(remotePath);
+        final Channel channel = openExecChannel(sb.toString());
         try {
             final OutputStream out = channel.getOutputStream();
             final InputStream in = channel.getInputStream();
@@ -217,8 +280,7 @@ public class ScpToMessage extends AbstractSshMessage {
             channel.connect();
 
             waitForAck(in);
-            for (final Iterator i = directoryList.iterator(); i.hasNext();) {
-                final Directory current = (Directory) i.next();
+            for (Directory current : directoryList) {
                 sendDirectory(current, in, out);
             }
         } finally {
@@ -231,12 +293,11 @@ public class ScpToMessage extends AbstractSshMessage {
     private void sendDirectory(final Directory current,
                                final InputStream in,
                                final OutputStream out) throws IOException {
-        for (final Iterator fileIt = current.filesIterator(); fileIt.hasNext();) {
-            sendFileToRemote((File) fileIt.next(), in, out);
+        for (final Iterator<File> fileIt = current.filesIterator(); fileIt.hasNext();) {
+            sendFileToRemote(fileIt.next(), in, out);
         }
-        for (final Iterator dirIt = current.directoryIterator(); dirIt.hasNext();) {
-            final Directory dir = (Directory) dirIt.next();
-            sendDirectoryToRemote(dir, in, out);
+        for (final Iterator<Directory> dirIt = current.directoryIterator(); dirIt.hasNext();) {
+            sendDirectoryToRemote(dirIt.next(), in, out);
         }
     }
 
@@ -286,7 +347,7 @@ public class ScpToMessage extends AbstractSshMessage {
         waitForAck(in);
 
         // send a content of lfile
-        final FileInputStream fis = new FileInputStream(localFile);
+        final InputStream fis = Files.newInputStream(localFile.toPath());
         final byte[] buf = new byte[BUFFER_SIZE];
         final long startTime = System.currentTimeMillis();
         long totalLength = 0;
@@ -346,6 +407,7 @@ public class ScpToMessage extends AbstractSshMessage {
 
     /**
      * Set the file mode, defaults to 0644.
+     * @param fileMode int
      * @since Ant 1.9.5
      */
     public void setFileMode(int fileMode) {
@@ -354,6 +416,7 @@ public class ScpToMessage extends AbstractSshMessage {
 
     /**
      * Get the file mode.
+     * @return int
      * @since Ant 1.9.5
      */
     public int getFileMode() {
@@ -362,6 +425,7 @@ public class ScpToMessage extends AbstractSshMessage {
 
     /**
      * Set the dir mode, defaults to 0755.
+     * @param dirMode int
      * @since Ant 1.9.5
      */
     public void setDirMode(int dirMode) {
@@ -370,6 +434,7 @@ public class ScpToMessage extends AbstractSshMessage {
 
     /**
      * Get the dir mode.
+     * @return int
      * @since Ant 1.9.5
      */
     public int getDirMode() {
@@ -378,6 +443,7 @@ public class ScpToMessage extends AbstractSshMessage {
 
     /**
      * Whether to preserve the last modified time.
+     * @return boolean
      * @since Ant 1.9.7
      */
     public boolean getPreserveLastModified() {
