@@ -18,16 +18,16 @@
 
 package org.apache.tools.ant.taskdefs.optional.testing;
 
-import org.apache.tools.ant.Task;
-import org.apache.tools.ant.Project;
 import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.Project;
+import org.apache.tools.ant.Task;
 import org.apache.tools.ant.TaskAdapter;
-import org.apache.tools.ant.util.WorkerAnt;
-import org.apache.tools.ant.taskdefs.condition.Condition;
-import org.apache.tools.ant.taskdefs.condition.ConditionBase;
 import org.apache.tools.ant.taskdefs.Parallel;
 import org.apache.tools.ant.taskdefs.Sequential;
 import org.apache.tools.ant.taskdefs.WaitFor;
+import org.apache.tools.ant.taskdefs.condition.Condition;
+import org.apache.tools.ant.taskdefs.condition.ConditionBase;
+import org.apache.tools.ant.util.WorkerAnt;
 
 /**
  * Task to provide functional testing under Ant, with a fairly complex workflow of:
@@ -58,6 +58,19 @@ import org.apache.tools.ant.taskdefs.WaitFor;
  */
 
 public class Funtest extends Task {
+    /** {@value} */
+    public static final String WARN_OVERRIDING = "Overriding previous definition of ";
+    /** {@value} */
+    public static final String APPLICATION_FORCIBLY_SHUT_DOWN = "Application forcibly shut down";
+    /** {@value} */
+    public static final String SHUTDOWN_INTERRUPTED = "Shutdown interrupted";
+    /** {@value} */
+    public static final String SKIPPING_TESTS
+        = "Condition failed -skipping tests";
+    /** Application exception : {@value} */
+    public static final String APPLICATION_EXCEPTION = "Application Exception";
+    /** Teardown exception : {@value} */
+    public static final String TEARDOWN_EXCEPTION = "Teardown Exception";
 
     /**
      * A condition that must be true before the tests are run. This makes it
@@ -158,20 +171,6 @@ public class Funtest extends Task {
      */
     private BuildException taskException;
 
-    /** {@value} */
-    public static final String WARN_OVERRIDING = "Overriding previous definition of ";
-    /** {@value} */
-    public static final String APPLICATION_FORCIBLY_SHUT_DOWN = "Application forcibly shut down";
-    /** {@value} */
-    public static final String SHUTDOWN_INTERRUPTED = "Shutdown interrupted";
-    /** {@value} */
-    public static final String SKIPPING_TESTS
-        = "Condition failed -skipping tests";
-    /** Application exception : {@value} */
-    public static final String APPLICATION_EXCEPTION = "Application Exception";
-    /** Teardown exception : {@value} */
-    public static final String TEARDOWN_EXCEPTION = "Teardown Exception";
-
     /**
      * Log if the definition is overriding something
      *
@@ -378,20 +377,22 @@ public class Funtest extends Task {
      * @param role role of the task
      */
     private void validateTask(Task task, String role) {
-        if (task!=null && task.getProject() == null) {
-            throw new BuildException(role + " task is not bound to the project" + task);
+        if (task != null && task.getProject() == null) {
+            throw new BuildException("%s task is not bound to the project %s",
+                role, task);
         }
     }
 
     /**
      * Run the functional test sequence.
-     * <p/>
+     * <p>
      * This is a fairly complex workflow -what is going on is that we try to clean up
      * no matter how the run ended, and to retain the innermost exception that got thrown
      * during cleanup. That is, if teardown fails after the tests themselves failed, it is the
      * test failing that is more important.
      * @throws BuildException if something was caught during the run or teardown.
      */
+    @Override
     public void execute() throws BuildException {
 
         //validation
@@ -500,20 +501,15 @@ public class Funtest extends Task {
 
     /**
      * Now faults are analysed.
-     * <p> The priority is
+     * <p>The priority is</p>
      * <ol>
      * <li>testexceptions, except those indicating a build timeout when the application itself
-     failed.<br>
-     (because often it is the application fault that is more interesting than the probe
-     failure, which is usually triggered by the application not starting
-     </li><li>
-     Application exceptions (above test timeout exceptions)
-     </li><li>
-     Teardown exceptions -except when they are being ignored
-     </li><li>
-     Test failures as indicated by the failure property
-     </li></ol>
-
+     * failed. (Because often it is the application fault that is more interesting than the probe
+     * failure, which is usually triggered by the application not starting.)</li>
+     * <li>Application exceptions (above test timeout exceptions)</li>
+     * <li>Teardown exceptions -except when they are being ignored</li>
+     * <li>Test failures as indicated by the failure property</li>
+     * </ol>
      */
     protected void processExceptions() {
         taskException = testException;
@@ -566,12 +562,13 @@ public class Funtest extends Task {
     }
 
     private static class NestedCondition extends ConditionBase implements Condition {
+        @Override
         public boolean eval() {
             if (countConditions() != 1) {
                 throw new BuildException(
                     "A single nested condition is required.");
             }
-            return ((Condition) (getConditions().nextElement())).eval();
+            return getConditions().nextElement().eval();
         }
     }
 }
