@@ -18,22 +18,24 @@
 
 package org.apache.tools.ant.types;
 
-import java.lang.reflect.Method;
-
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.lang.reflect.Method;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.net.URLConnection;
+import java.nio.file.Files;
 import java.util.Stack;
 import java.util.Vector;
+
 import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.parsers.SAXParserFactory;
 import javax.xml.transform.Source;
 import javax.xml.transform.TransformerException;
 import javax.xml.transform.URIResolver;
 import javax.xml.transform.sax.SAXSource;
+
 import org.apache.tools.ant.AntClassLoader;
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Project;
@@ -45,11 +47,10 @@ import org.xml.sax.SAXException;
 import org.xml.sax.XMLReader;
 
 
-
 /**
  * <p>This data type provides a catalog of resource locations (such as
  * DTDs and XML entities), based on the <a
- * href="http://oasis-open.org/committees/entity/spec-2001-08-06.html">
+ * href="https://oasis-open.org/committees/entity/spec-2001-08-06.html">
  * OASIS "Open Catalog" standard</a>.  The catalog entries are used
  * both for Entity resolution and URI resolution, in accordance with
  * the {@link org.xml.sax.EntityResolver EntityResolver} and {@link
@@ -61,9 +62,9 @@ import org.xml.sax.XMLReader;
  * external catalog file(s), or both.  In order to use an external
  * catalog file, the xml-commons resolver library ("resolver.jar")
  * must be in your classpath.  External catalog files may be either <a
- * href="http://oasis-open.org/committees/entity/background/9401.html">
+ * href="https://oasis-open.org/committees/entity/background/9401.html">
  * plain text format</a> or <a
- * href="http://www.oasis-open.org/committees/entity/spec-2001-08-06.html">
+ * href="https://www.oasis-open.org/committees/entity/spec-2001-08-06.html">
  * XML format</a>.  If the xml-commons resolver library is not found
  * in the classpath, external catalog files, specified in
  * <code>&lt;catalogpath&gt;</code> paths, will be ignored and a warning will
@@ -76,19 +77,18 @@ import org.xml.sax.XMLReader;
  * <code>URI</code> respectively.</p>
  *
  * <p>The following is a usage example:</p>
- *
- * <code>
- * &lt;xmlcatalog&gt;<br>
- * &nbsp;&nbsp;&lt;dtd publicId="" location="/path/to/file.jar" /&gt;<br>
- * &nbsp;&nbsp;&lt;dtd publicId="" location="/path/to/file2.jar" /&gt;<br>
- * &nbsp;&nbsp;&lt;entity publicId="" location="/path/to/file3.jar" /&gt;<br>
- * &nbsp;&nbsp;&lt;entity publicId="" location="/path/to/file4.jar" /&gt;<br>
- * &nbsp;&nbsp;&lt;catalogpath&gt;<br>
- * &nbsp;&nbsp;&nbsp;&nbsp;&lt;pathelement location="/etc/sgml/catalog"/&gt;<br>
- * &nbsp;&nbsp;&lt;/catalogpath&gt;<br>
- * &nbsp;&nbsp;&lt;catalogfiles dir="/opt/catalogs/" includes="**\catalog.xml" /&gt;<br>
- * &lt;/xmlcatalog&gt;<br>
- * </code>
+ * <pre>
+ * &lt;xmlcatalog&gt;
+ *   &lt;dtd publicId="" location="/path/to/file.jar"/&gt;
+ *   &lt;dtd publicId="" location="/path/to/file2.jar"/&gt;
+ *   &lt;entity publicId="" location="/path/to/file3.jar"/&gt;
+ *   &lt;entity publicId="" location="/path/to/file4.jar"/&gt;
+ *   &lt;catalogpath&gt;
+ *     &lt;pathelement location="/etc/sgml/catalog"/&gt;
+ *   &lt;/catalogpath&gt;
+ *   &lt;catalogfiles dir="/opt/catalogs/" includes="**\catalog.xml"/&gt;
+ * &lt;/xmlcatalog&gt;
+ * </pre>
  * <p>
  * Tasks wishing to use <code>&lt;xmlcatalog&gt;</code> must provide a method called
  * <code>createXMLCatalog</code> which returns an instance of
@@ -98,14 +98,13 @@ import org.xml.sax.XMLReader;
  *
  * <p>The following is a description of the resolution algorithm:
  * entities/URIs/dtds are looked up in each of the following contexts,
- * stopping when a valid and readable resource is found:
+ * stopping when a valid and readable resource is found:</p>
  * <ol>
  * <li>In the local filesystem</li>
  * <li>In the classpath</li>
  * <li>Using the Apache xml-commons resolver (if it is available)</li>
  * <li>In URL-space</li>
  * </ol>
- * </p>
  *
  * <p>See {@link
  * org.apache.tools.ant.taskdefs.optional.XMLValidateTask
@@ -117,7 +116,7 @@ import org.xml.sax.XMLReader;
  *
  */
 public class XMLCatalog extends DataType
-    implements Cloneable, EntityResolver, URIResolver {
+    implements EntityResolver, URIResolver {
 
     /** helper for some File.toURL connversions */
     private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
@@ -354,6 +353,7 @@ public class XMLCatalog extends DataType
      * @param r the reference to which this catalog instance is associated
      * @exception BuildException if this instance already has been configured.
      */
+    @Override
     public void setRefid(Reference r) throws BuildException {
         if (!elements.isEmpty()) {
             throw tooManyAttributes();
@@ -370,6 +370,7 @@ public class XMLCatalog extends DataType
      * @return the resolved entity.
      * @see org.xml.sax.EntityResolver#resolveEntity
      */
+    @Override
     public InputSource resolveEntity(String publicId, String systemId)
         throws SAXException, IOException {
 
@@ -401,6 +402,7 @@ public class XMLCatalog extends DataType
      * @throws TransformerException if an error occurs.
      * @see javax.xml.transform.URIResolver#resolve
      */
+    @Override
     public Source resolve(String href, String base)
         throws TransformerException {
 
@@ -426,7 +428,7 @@ public class XMLCatalog extends DataType
             // setEntityResolver (see setEntityResolver javadoc comment)
             //
             source = new SAXSource();
-            URL baseURL = null;
+            URL baseURL;
             try {
                 if (base == null) {
                     baseURL = FILE_UTILS.getFileURL(getProject().getBaseDir());
@@ -446,6 +448,7 @@ public class XMLCatalog extends DataType
         return source;
     }
 
+    @Override
     protected synchronized void dieOnCircularReference(Stack<Object> stk, Project p)
         throws BuildException {
         if (isChecked()) {
@@ -482,7 +485,7 @@ public class XMLCatalog extends DataType
     /**
      * Factory method for creating the appropriate CatalogResolver
      * strategy implementation.
-     * <p> Until we query the classpath, we don't know whether the Apache
+     * <p>Until we query the classpath, we don't know whether the Apache
      * resolver (Norm Walsh's library from xml-commons) is available or not.
      * This method determines whether the library is available and creates the
      * appropriate implementation of CatalogResolver based on the answer.</p>
@@ -493,7 +496,7 @@ public class XMLCatalog extends DataType
 
         if (catalogResolver == null) {
 
-            AntClassLoader loader = null;
+            AntClassLoader loader;
             // Memory-Leak in line below
             loader = getProject().createClassLoader(Path.systemClasspath);
 
@@ -588,12 +591,9 @@ public class XMLCatalog extends DataType
      *         of the Resource or null if no such information is available.
      */
     private ResourceLocation findMatchingEntry(String publicId) {
-        for (ResourceLocation element : getElements()) {
-            if (element.getPublicId().equals(publicId)) {
-                return element;
-            }
-        }
-        return null;
+        return getElements().stream()
+            .filter(e -> e.getPublicId().equals(publicId)).findFirst()
+            .orElse(null);
     }
 
     /**
@@ -626,7 +626,7 @@ public class XMLCatalog extends DataType
         String uri = matchingEntry.getLocation();
         // the following line seems to be necessary on Windows under JDK 1.2
         uri = uri.replace(File.separatorChar, '/');
-        URL baseURL = null;
+        URL baseURL;
 
         //
         // The ResourceLocation may specify a relative path for its
@@ -643,7 +643,6 @@ public class XMLCatalog extends DataType
             }
         }
 
-        InputSource source = null;
         URL url = null;
         try {
             url = new URL(baseURL, uri);
@@ -668,14 +667,15 @@ public class XMLCatalog extends DataType
             }
         }
 
-        if (url != null && url.getProtocol().equals("file")) {
+        InputSource source = null;
+        if (url != null && "file".equals(url.getProtocol())) {
             String fileName = FILE_UTILS.fromURI(url.toString());
             if (fileName != null) {
                 log("fileName " + fileName, Project.MSG_DEBUG);
                 File resFile = new File(fileName);
                 if (resFile.exists() && resFile.canRead()) {
                     try {
-                        source = new InputSource(new FileInputStream(resFile));
+                        source = new InputSource(Files.newInputStream(resFile.toPath()));
                         String sysid = JAXPUtils.getSystemId(resFile);
                         source.setSystemId(sysid);
                         log("catalog entry matched a readable file: '"
@@ -699,14 +699,13 @@ public class XMLCatalog extends DataType
 
         InputSource source = null;
 
-        AntClassLoader loader = null;
         Path cp = classpath;
         if (cp != null) {
             cp = classpath.concatSystemClasspath("ignore");
         } else {
             cp = (new Path(getProject())).concatSystemClasspath("last");
         }
-        loader = getProject().createClassLoader(cp);
+        AntClassLoader loader = getProject().createClassLoader(cp);
 
         //
         // for classpath lookup we ignore the base directory
@@ -735,7 +734,7 @@ public class XMLCatalog extends DataType
     private InputSource urlLookup(ResourceLocation matchingEntry) {
 
         String uri = matchingEntry.getLocation();
-        URL baseURL = null;
+        URL baseURL;
 
         //
         // The ResourceLocation may specify a relative url for its
@@ -752,18 +751,23 @@ public class XMLCatalog extends DataType
             }
         }
 
-        InputSource source = null;
-        URL url = null;
+        URL url;
 
         try {
             url = new URL(baseURL, uri);
         } catch (MalformedURLException ex) {
-            // ignore
+            url = null;
         }
 
+        InputSource source = null;
         if (url != null) {
             try {
-                InputStream is = url.openStream();
+                InputStream is = null;
+                URLConnection conn = url.openConnection();
+                if (conn != null) {
+                    conn.setUseCaches(false);
+                    is = conn.getInputStream();
+                }
                 if (is != null) {
                     source = new InputSource(is);
                     String sysid = url.toExternalForm();
@@ -785,10 +789,8 @@ public class XMLCatalog extends DataType
      * the ExternalResolver strategy.
      */
     private interface CatalogResolver extends URIResolver, EntityResolver {
-
+        @Override
         InputSource resolveEntity(String publicId, String systemId);
-
-        Source resolve(String href, String base) throws TransformerException;
     }
 
     /**
@@ -805,6 +807,7 @@ public class XMLCatalog extends DataType
                 Project.MSG_VERBOSE);
         }
 
+        @Override
         public InputSource resolveEntity(String publicId,
                                          String systemId) {
             InputSource result = null;
@@ -830,6 +833,7 @@ public class XMLCatalog extends DataType
             return result;
         }
 
+        @Override
         public Source resolve(String href, String base)
             throws TransformerException {
 
@@ -941,14 +945,15 @@ public class XMLCatalog extends DataType
                 Project.MSG_VERBOSE);
         }
 
+        @Override
         public InputSource resolveEntity(String publicId,
                                          String systemId) {
-            InputSource result = null;
 
             processExternalCatalogs();
 
             ResourceLocation matchingEntry = findMatchingEntry(publicId);
 
+            InputSource result;
             if (matchingEntry != null) {
 
                 log("Matching catalog entry found for publicId: '"
@@ -992,11 +997,12 @@ public class XMLCatalog extends DataType
             return result;
         }
 
+        @Override
         public Source resolve(String href, String base)
             throws TransformerException {
 
-            SAXSource result = null;
-            InputSource source = null;
+            SAXSource result;
+            InputSource source;
 
             processExternalCatalogs();
 
@@ -1118,4 +1124,4 @@ public class XMLCatalog extends DataType
             externalCatalogsProcessed = true;
         }
     }
-} //-- XMLCatalog
+}
