@@ -19,10 +19,11 @@ package org.apache.tools.ant.types.resources;
 
 import java.io.IOException;
 import java.io.InputStreamReader;
-import java.io.UnsupportedEncodingException;
+import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.List;
 import java.util.Stack;
 
 import org.apache.tools.ant.BuildException;
@@ -31,7 +32,6 @@ import org.apache.tools.ant.types.DataType;
 import org.apache.tools.ant.types.Resource;
 import org.apache.tools.ant.types.ResourceCollection;
 import org.apache.tools.ant.util.ConcatResourceInputStream;
-import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.LineTokenizer;
 import org.apache.tools.ant.util.Tokenizer;
 
@@ -51,37 +51,31 @@ public class Tokens extends BaseResourceCollectionWrapper {
      */
     protected synchronized Collection<Resource> getCollection() {
         ResourceCollection rc = getResourceCollection();
-        if (rc.size() == 0) {
+        if (rc.isEmpty()) {
             return Collections.emptySet();
         }
         if (tokenizer == null) {
             tokenizer = new LineTokenizer();
         }
-        ConcatResourceInputStream cat = new ConcatResourceInputStream(rc);
-        cat.setManagingComponent(this);
-
-        try {
-            InputStreamReader rdr = null;
-            if (encoding == null) {
-                rdr = new InputStreamReader(cat);
-            } else {
-                try {
-                    rdr = new InputStreamReader(cat, encoding);
-                } catch (UnsupportedEncodingException e) {
-                    throw new BuildException(e);
-                }
-            }
-            ArrayList<Resource> result = new ArrayList<Resource>();
-            for (String s = tokenizer.getToken(rdr); s != null; s = tokenizer.getToken(rdr)) {
-                StringResource resource = new StringResource(s);
+        try (ConcatResourceInputStream cat = new ConcatResourceInputStream(rc);
+                InputStreamReader rdr = new InputStreamReader(cat,
+                    encoding == null ? Charset.defaultCharset()
+                        : Charset.forName(encoding))) {
+            cat.setManagingComponent(this);
+            List<Resource> result = new ArrayList<>();
+            for (String s = tokenizer.getToken(rdr); s != null; s =
+                tokenizer.getToken(rdr)) {
+                // do not send the Project to the constructor of StringResource, since
+                // the semantics of that constructor clearly state that property value
+                // replacement takes place on the passed string value. We don't want
+                // that to happen.
+                final StringResource resource = new StringResource(s);
                 resource.setProject(getProject());
                 result.add(resource);
             }
             return result;
         } catch (IOException e) {
             throw new BuildException("Error reading tokens", e);
-        } finally {
-            FileUtils.close(cat);
         }
     }
 
@@ -116,6 +110,7 @@ public class Tokens extends BaseResourceCollectionWrapper {
      * @param p   the project to use to dereference the references.
      * @throws BuildException on error.
      */
+    @Override
     protected synchronized void dieOnCircularReference(Stack<Object> stk, Project p)
         throws BuildException {
         if (isChecked()) {
