@@ -20,7 +20,6 @@ package org.apache.tools.ant.util;
 import java.io.BufferedReader;
 import java.io.ByteArrayInputStream;
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
@@ -28,9 +27,12 @@ import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.PrintStream;
 import java.io.PushbackReader;
+import java.io.Serializable;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
 import java.util.Properties;
 
 /**
@@ -40,7 +42,7 @@ import java.util.Properties;
  * class to there, but it also keeps track of the contents of the
  * input stream from which it was loaded (if applicable), so that it can
  * write out the properties in as close a form as possible to the input.</p>
- * If no changes occur to property values, the output should be the same
+ * <p>If no changes occur to property values, the output should be the same
  * as the input, except for the leading date stamp, as normal for a
  * properties file. Properties added are appended to the file. Properties
  * whose values are changed are changed in place. Properties that are
@@ -63,7 +65,7 @@ import java.util.Properties;
  *
  * # and finally
  * gamma=rays</pre>
- * </p>The resulting collection sequence of logical lines depends on whether
+ * <p>The resulting collection sequence of logical lines depends on whether
  * or not <code>removeComments</code> was set at the time the second stream
  * is loaded. If it is set, then the resulting list of lines is</p>
  * <pre> # the first line
@@ -78,6 +80,8 @@ import java.util.Properties;
  * although the key-value pair <code>beta=two</code> is removed.</p>
  */
 public class LayoutPreservingProperties extends Properties {
+    private static final long serialVersionUID = 1L;
+
     private String LS = StringUtils.LINE_SEP;
 
     /**
@@ -85,12 +89,12 @@ public class LayoutPreservingProperties extends Properties {
      * of. Comments and blank lines are logical lines; they are not
      * removed.
      */
-    private ArrayList logicalLines = new ArrayList();
+    private List<LogicalLine> logicalLines = new ArrayList<>();
 
     /**
      * Position in the <code>logicalLines</code> list, keyed by property name.
      */
-    private HashMap keyedPairLines = new HashMap();
+    private Map<String, Integer> keyedPairLines = new HashMap<>();
 
     /**
      * Flag to indicate that, when we remove a property from the file, we
@@ -109,7 +113,7 @@ public class LayoutPreservingProperties extends Properties {
      * Create a new, empty, Properties collection, with the specified defaults.
      * @param defaults the default property values
      */
-    public LayoutPreservingProperties(Properties defaults) {
+    public LayoutPreservingProperties(final Properties defaults) {
         super(defaults);
     }
 
@@ -134,27 +138,30 @@ public class LayoutPreservingProperties extends Properties {
      * removed when a property is removed; <code>false</code>
      * otherwise
      */
-    public void setRemoveComments(boolean val) {
+    public void setRemoveComments(final boolean val) {
         removeComments = val;
     }
 
-    public void load(InputStream inStream) throws IOException {
-        String s = readLines(inStream);
-        byte[] ba = s.getBytes(ResourceUtils.ISO_8859_1);
-        ByteArrayInputStream bais = new ByteArrayInputStream(ba);
+    @Override
+    public void load(final InputStream inStream) throws IOException {
+        final String s = readLines(inStream);
+        final byte[] ba = s.getBytes(ResourceUtils.ISO_8859_1);
+        final ByteArrayInputStream bais = new ByteArrayInputStream(ba);
         super.load(bais);
     }
 
-    public Object put(Object key, Object value) throws NullPointerException {
-        Object obj = super.put(key, value);
+    @Override
+    public Object put(final Object key, final Object value) throws NullPointerException {
+        final Object obj = super.put(key, value);
         // the above call will have failed if key or value are null
         innerSetProperty(key.toString(), value.toString());
         return obj;
     }
 
-    public Object setProperty(String key, String value)
+    @Override
+    public Object setProperty(final String key, final String value)
         throws NullPointerException {
-        Object obj = super.setProperty(key, value);
+        final Object obj = super.setProperty(key, value);
         // the above call will have failed if key or value are null
         innerSetProperty(key, value);
         return obj;
@@ -172,27 +179,29 @@ public class LayoutPreservingProperties extends Properties {
         value = escapeValue(value);
 
         if (keyedPairLines.containsKey(key)) {
-            Integer i = (Integer) keyedPairLines.get(key);
-            Pair p = (Pair) logicalLines.get(i.intValue());
+            final Integer i = keyedPairLines.get(key);
+            final Pair p = (Pair) logicalLines.get(i.intValue());
             p.setValue(value);
         } else {
             key = escapeName(key);
-            Pair p = new Pair(key, value);
+            final Pair p = new Pair(key, value);
             p.setNew(true);
-            keyedPairLines.put(key, new Integer(logicalLines.size()));
+            keyedPairLines.put(key, Integer.valueOf(logicalLines.size()));
             logicalLines.add(p);
         }
     }
 
+    @Override
     public void clear() {
         super.clear();
         keyedPairLines.clear();
         logicalLines.clear();
     }
 
-    public Object remove(Object key) {
-        Object obj = super.remove(key);
-        Integer i = (Integer) keyedPairLines.remove(key);
+    @Override
+    public Object remove(final Object key) {
+        final Object obj = super.remove(key);
+        final Integer i = keyedPairLines.remove(key);
         if (null != i) {
             if (removeComments) {
                 removeCommentsEndingAt(i.intValue());
@@ -202,17 +211,18 @@ public class LayoutPreservingProperties extends Properties {
         return obj;
     }
 
+    @Override
     public Object clone() {
-        LayoutPreservingProperties dolly =
+        final LayoutPreservingProperties dolly =
             (LayoutPreservingProperties) super.clone();
-        dolly.keyedPairLines = (HashMap) this.keyedPairLines.clone();
-        dolly.logicalLines = (ArrayList) this.logicalLines.clone();
+        dolly.keyedPairLines = new HashMap<>(this.keyedPairLines);
+        dolly.logicalLines = new ArrayList<>(this.logicalLines);
         final int size = dolly.logicalLines.size();
         for (int j = 0; j < size; j++) {
-            LogicalLine line = (LogicalLine) dolly.logicalLines.get(j);
+            final LogicalLine line = dolly.logicalLines.get(j);
             if (line instanceof Pair) {
-                Pair p = (Pair) line;
-                dolly.logicalLines.set(j, p.clone());
+                final Pair p = (Pair) line;
+                dolly.logicalLines.set(j, (Pair) p.clone());
             }
             // no reason to clone other lines are they are immutable
         }
@@ -224,18 +234,14 @@ public class LayoutPreservingProperties extends Properties {
      * stream.
      * @param out the stream to write to
      */
-    public void listLines(PrintStream out) {
+    public void listLines(final PrintStream out) {
         out.println("-- logical lines --");
-        Iterator i = logicalLines.iterator();
-        while (i.hasNext()) {
-            LogicalLine line = (LogicalLine) i.next();
+        for (LogicalLine line : logicalLines) {
             if (line instanceof Blank) {
                 out.println("blank:   \"" + line + "\"");
-            }
-            else if (line instanceof Comment) {
+            } else if (line instanceof Comment) {
                 out.println("comment: \"" + line + "\"");
-            }
-            else if (line instanceof Pair) {
+            } else if (line instanceof Pair) {
                 out.println("pair:    \"" + line + "\"");
             }
         }
@@ -244,18 +250,20 @@ public class LayoutPreservingProperties extends Properties {
     /**
      * Save the properties to a file.
      * @param dest the file to write to
+     * @throws IOException if save fails
      */
-    public void saveAs(File dest) throws IOException {
-        FileOutputStream fos = new FileOutputStream(dest);
+    public void saveAs(final File dest) throws IOException {
+        final OutputStream fos = Files.newOutputStream(dest.toPath());
         store(fos, null);
         fos.close();
     }
 
-    public void store(OutputStream out, String header) throws IOException {
-        OutputStreamWriter osw = new OutputStreamWriter(out, ResourceUtils.ISO_8859_1);
+    @Override
+    public void store(final OutputStream out, final String header) throws IOException {
+        final OutputStreamWriter osw = new OutputStreamWriter(out, ResourceUtils.ISO_8859_1);
 
         int skipLines = 0;
-        int totalLines = logicalLines.size();
+        final int totalLines = logicalLines.size();
 
         if (header != null) {
             osw.write("#" + header + LS);
@@ -266,7 +274,7 @@ public class LayoutPreservingProperties extends Properties {
             }
         }
 
-        // we may be updatiung a file written by this class, replace
+        // we may be updating a file written by this class, replace
         // the date comment instead of adding a new one and preserving
         // the one written last time
         if (totalLines > skipLines
@@ -276,26 +284,23 @@ public class LayoutPreservingProperties extends Properties {
                                               .get(skipLines)
                                               .toString().substring(1));
                 skipLines++;
-            } catch (java.text.ParseException pe) {
+            } catch (final java.text.ParseException pe) {
                 // not an existing date comment
             }
         }
         osw.write("#" + DateUtils.getDateForHeader() + LS);
 
         boolean writtenSep = false;
-        for (Iterator i = logicalLines.subList(skipLines, totalLines).iterator();
-             i.hasNext(); ) {
-            LogicalLine line = (LogicalLine) i.next();
+        for (LogicalLine line : logicalLines.subList(skipLines, totalLines)) {
             if (line instanceof Pair) {
-                if (((Pair)line).isNew()) {
+                if (((Pair) line).isNew()) {
                     if (!writtenSep) {
                         osw.write(LS);
                         writtenSep = true;
                     }
                 }
                 osw.write(line.toString() + LS);
-            }
-            else if (line != null) {
+            } else if (line != null) {
                 osw.write(line.toString() + LS);
             }
         }
@@ -304,27 +309,27 @@ public class LayoutPreservingProperties extends Properties {
 
     /**
      * Reads a properties file into an internally maintained
-     * collection of logical lines (possibly spanning physcial lines),
+     * collection of logical lines (possibly spanning physical lines),
      * which make up the comments, blank lines and properties of the
      * file.
      * @param is the stream from which to read the data
      */
-    private String readLines(InputStream is) throws IOException {
-        InputStreamReader isr = new InputStreamReader(is, ResourceUtils.ISO_8859_1);
-        PushbackReader pbr = new PushbackReader(isr, 1);
+    private String readLines(final InputStream is) throws IOException {
+        final InputStreamReader isr = new InputStreamReader(is, ResourceUtils.ISO_8859_1);
+        final PushbackReader pbr = new PushbackReader(isr, 1);
 
-        if (logicalLines.size() > 0) {
+        if (!logicalLines.isEmpty()) {
             // we add a blank line for spacing
             logicalLines.add(new Blank());
         }
 
         String s = readFirstLine(pbr);
-        BufferedReader br = new BufferedReader(pbr);
+        final BufferedReader br = new BufferedReader(pbr);
 
         boolean continuation = false;
         boolean comment = false;
-        StringBuffer fileBuffer = new StringBuffer();
-        StringBuffer logicalLineBuffer = new StringBuffer();
+        final StringBuilder fileBuffer = new StringBuilder();
+        final StringBuilder logicalLineBuffer = new StringBuilder();
         while (s != null) {
             fileBuffer.append(s).append(LS);
 
@@ -345,20 +350,20 @@ public class LayoutPreservingProperties extends Properties {
             logicalLineBuffer.append(s);
 
             if (!continuation) {
-                LogicalLine line = null;
+                LogicalLine line;
                 if (comment) {
                     line = new Comment(logicalLineBuffer.toString());
                 } else if (logicalLineBuffer.toString().trim().length() == 0) {
                     line = new Blank();
                 } else {
                     line = new Pair(logicalLineBuffer.toString());
-                    String key = unescape(((Pair)line).getName());
+                    final String key = unescape(((Pair) line).getName());
                     if (keyedPairLines.containsKey(key)) {
                         // this key is already present, so we remove it and add
                         // the new one
                         remove(key);
                     }
-                    keyedPairLines.put(key, new Integer(logicalLines.size()));
+                    keyedPairLines.put(key, Integer.valueOf(logicalLines.size()));
                 }
                 logicalLines.add(line);
                 logicalLineBuffer.setLength(0);
@@ -379,8 +384,8 @@ public class LayoutPreservingProperties extends Properties {
      *
      * @since Ant 1.8.2
      */
-    private String readFirstLine(PushbackReader r) throws IOException {
-        StringBuffer sb = new StringBuffer(80);
+    private String readFirstLine(final PushbackReader r) throws IOException {
+        final StringBuilder sb = new StringBuilder(80);
         int ch = r.read();
         boolean hasCR = false;
         // when reaching EOF before the first EOL, assume native line
@@ -416,29 +421,29 @@ public class LayoutPreservingProperties extends Properties {
      * @return <code>true</code> if the line is to be continued,
      * <code>false</code> otherwise
      */
-    private boolean requiresContinuation(String s) {
-        char[] ca = s.toCharArray();
+    private boolean requiresContinuation(final String s) {
+        final char[] ca = s.toCharArray();
         int i = ca.length - 1;
         while (i > 0 && ca[i] == '\\') {
             i--;
         }
         // trailing backslashes
-        int tb = ca.length - i - 1;
+        final int tb = ca.length - i - 1;
         return tb % 2 == 1;
     }
 
     /**
-     * Unescape the string according to the rules for a Properites
+     * Unescape the string according to the rules for a Properties
      * file, as laid out in the docs for <a
      * href="http://java.sun.com/j2se/1.3/docs/api/java/util/Properties.html">java.util.Properties</a>.
      * @param s the string to unescape (coming from the source file)
      * @return the unescaped string
      */
-    private String unescape(String s) {
+    private String unescape(final String s) {
         /*
          * The following combinations are converted:
          * \n  newline
-         * \r  carraige return
+         * \r  carriage return
          * \f  form feed
          * \t  tab
          * \\  backslash
@@ -447,37 +452,36 @@ public class LayoutPreservingProperties extends Properties {
          * \b  becomes 'b'.
          */
 
-        char[] ch = new char[s.length() + 1];
+        final char[] ch = new char[s.length() + 1];
         s.getChars(0, s.length(), ch, 0);
         ch[s.length()] = '\n';
-        StringBuffer buffy = new StringBuffer(s.length());
+        final StringBuilder buffy = new StringBuilder(s.length());
         for (int i = 0; i < ch.length; i++) {
             char c = ch[i];
             if (c == '\n') {
                 // we have hit out end-of-string marker
                 break;
             }
-            else if (c == '\\') {
+            if (c == '\\') {
                 // possibly an escape sequence
                 c = ch[++i];
-                if (c == 'n')
+                if (c == 'n') {
                     buffy.append('\n');
-                else if (c == 'r')
+                } else if (c == 'r') {
                     buffy.append('\r');
-                else if (c == 'f')
+                } else if (c == 'f') {
                     buffy.append('\f');
-                else if (c == 't')
+                } else if (c == 't') {
                     buffy.append('\t');
-                else if (c == 'u') {
+                } else if (c == 'u') {
                     // handle unicode escapes
-                    c = unescapeUnicode(ch, i+1);
+                    c = unescapeUnicode(ch, i + 1);
                     i += 4;
                     buffy.append(c);
-                }
-                else
+                } else {
                     buffy.append(c);
-            }
-            else {
+                }
+            } else {
                 buffy.append(c);
             }
         }
@@ -490,8 +494,8 @@ public class LayoutPreservingProperties extends Properties {
      * @param ch the character array containing the unicode character code
      * @return the character extracted
      */
-    private char unescapeUnicode(char[] ch, int i) {
-        String s = new String(ch, i, 4);
+    private char unescapeUnicode(final char[] ch, final int i) {
+        final String s = new String(ch, i, 4);
         return (char) Integer.parseInt(s, 16);
     }
 
@@ -502,7 +506,7 @@ public class LayoutPreservingProperties extends Properties {
      * @param s the string to escape
      * @return the escaped string
      */
-    private String escapeValue(String s) {
+    private String escapeValue(final String s) {
         return escape(s, false);
     }
 
@@ -515,7 +519,7 @@ public class LayoutPreservingProperties extends Properties {
      * @param s the string to escape
      * @return the escaped string
      */
-    private String escapeName(String s) {
+    private String escapeName(final String s) {
         return escape(s, true);
     }
 
@@ -529,19 +533,19 @@ public class LayoutPreservingProperties extends Properties {
      * leading whitespace
      * @return the escaped string
      */
-    private String escape(String s, boolean escapeAllSpaces) {
+    private String escape(final String s, final boolean escapeAllSpaces) {
         if (s == null) {
             return null;
         }
 
-        char[] ch = new char[s.length()];
+        final char[] ch = new char[s.length()];
         s.getChars(0, s.length(), ch, 0);
-        String forEscaping = "\t\f\r\n\\:=#!";
-        String escaped = "tfrn\\:=#!";
-        StringBuffer buffy = new StringBuffer(s.length());
+        final String forEscaping = "\t\f\r\n\\:=#!";
+        final String escaped = "tfrn\\:=#!";
+        final StringBuilder buffy = new StringBuilder(s.length());
         boolean leadingSpace = true;
         for (int i = 0; i < ch.length; i++) {
-            char c = ch[i];
+            final char c = ch[i];
             if (c == ' ') {
                 if (escapeAllSpaces || leadingSpace) {
                     buffy.append("\\");
@@ -549,9 +553,9 @@ public class LayoutPreservingProperties extends Properties {
             } else {
                 leadingSpace = false;
             }
-            int p = forEscaping.indexOf(c);
+            final int p = forEscaping.indexOf(c);
             if (p != -1) {
-                buffy.append("\\").append(escaped.substring(p,p+1));
+                buffy.append("\\").append(escaped.substring(p, p + 1));
             } else if (c < 0x0020 || c > 0x007e) {
                 buffy.append(escapeUnicode(c));
             } else {
@@ -567,12 +571,12 @@ public class LayoutPreservingProperties extends Properties {
      * @param ch the character to encode
      * @return the unicode escape sequence
      */
-    private String escapeUnicode(char ch) {
+    private String escapeUnicode(final char ch) {
         return "\\" + UnicodeUtil.EscapeUnicode(ch);
-        }
+    }
 
     /**
-     * Remove the comments in the leading up the {@link logicalLines}
+     * Remove the comments in the leading up the {@link #logicalLines}
      * list leading up to line <code>pos</code>.
      * @param pos the line number to which the comments lead
      */
@@ -585,7 +589,7 @@ public class LayoutPreservingProperties extends Properties {
          * B1.
          */
 
-        int end = pos - 1;
+        final int end = pos - 1;
 
         // step pos back until it hits something non-blank
         for (pos = end; pos > 0; pos--) {
@@ -608,7 +612,7 @@ public class LayoutPreservingProperties extends Properties {
         }
 
         // now we want to delete from pos+1 to end
-        for (pos++ ;pos <= end; pos++) {
+        for (pos++; pos <= end; pos++) {
             logicalLines.set(pos, null);
         }
     }
@@ -616,17 +620,20 @@ public class LayoutPreservingProperties extends Properties {
     /**
      * A logical line of the properties input stream.
      */
-    private static abstract class LogicalLine {
+    private abstract static class LogicalLine implements Serializable {
+        private static final long serialVersionUID = 1L;
+
         private String text;
 
-        public LogicalLine(String text) {
+        public LogicalLine(final String text) {
             this.text = text;
         }
 
-        public void setText(String text) {
+        public void setText(final String text) {
             this.text = text;
         }
 
+        @Override
         public String toString() {
             return text;
         }
@@ -636,6 +643,8 @@ public class LayoutPreservingProperties extends Properties {
      * A blank line of the input stream.
      */
     private static class Blank extends LogicalLine {
+        private static final long serialVersionUID = 1L;
+
         public Blank() {
             super("");
         }
@@ -645,27 +654,31 @@ public class LayoutPreservingProperties extends Properties {
      * A comment line of the input stream.
      */
     private class Comment extends LogicalLine {
-        public Comment(String text) {
+        private static final long serialVersionUID = 1L;
+
+        public Comment(final String text) {
             super(text);
         }
     }
 
     /**
      * A key-value pair from the input stream. This may span more than
-     * one physical line, but it is constitutes as a single logical
+     * one physical line, but it is constitues as a single logical
      * line.
      */
     private static class Pair extends LogicalLine implements Cloneable {
+        private static final long serialVersionUID = 1L;
+
         private String name;
         private String value;
         private boolean added;
 
-        public Pair(String text) {
+        public Pair(final String text) {
             super(text);
             parsePair(text);
         }
 
-        public Pair(String name, String value) {
+        public Pair(final String name, final String value) {
             this(name + "=" + value);
         }
 
@@ -673,11 +686,12 @@ public class LayoutPreservingProperties extends Properties {
             return name;
         }
 
+        @SuppressWarnings("unused")
         public String getValue() {
             return value;
         }
 
-        public void setValue(String value) {
+        public void setValue(final String value) {
             this.value = value;
             setText(name + "=" + value);
         }
@@ -686,45 +700,44 @@ public class LayoutPreservingProperties extends Properties {
             return added;
         }
 
-        public void setNew(boolean val) {
+        public void setNew(final boolean val) {
             added = val;
         }
 
+        @Override
         public Object clone() {
             Object dolly = null;
             try {
                 dolly = super.clone();
-            }
-            catch (CloneNotSupportedException e) {
+            } catch (final CloneNotSupportedException e) {
                 // should be fine
-                e.printStackTrace();
+                e.printStackTrace(); //NOSONAR
             }
             return dolly;
         }
 
-        private void parsePair(String text) {
+        private void parsePair(final String text) {
             // need to find first non-escaped '=', ':', '\t' or ' '.
-            int pos = findFirstSeparator(text);
+            final int pos = findFirstSeparator(text);
             if (pos == -1) {
                 // trim leading whitespace only
                 name = text;
-                value = null;
-            }
-            else {
+                setValue(null);
+            } else {
                 name = text.substring(0, pos);
-                value = text.substring(pos+1, text.length());
+                setValue(text.substring(pos + 1, text.length()));
             }
             // trim leading whitespace only
             name = stripStart(name, " \t\f");
         }
 
-        private String stripStart(String s, String chars) {
+        private String stripStart(final String s, final String chars) {
             if (s == null) {
                 return null;
             }
 
             int i = 0;
-            for (;i < s.length(); i++) {
+            for (; i < s.length(); i++) {
                 if (chars.indexOf(s.charAt(i)) == -1) {
                     break;
                 }
@@ -752,14 +765,14 @@ public class LayoutPreservingProperties extends Properties {
             return indexOfAny(s, " :=\t");
         }
 
-        private int indexOfAny(String s, String chars) {
+        private int indexOfAny(final String s, final String chars) {
             if (s == null || chars == null) {
                 return -1;
             }
 
             int p = s.length() + 1;
             for (int i = 0; i < chars.length(); i++) {
-                int x = s.indexOf(chars.charAt(i));
+                final int x = s.indexOf(chars.charAt(i));
                 if (x != -1 && x < p) {
                     p = x;
                 }
