@@ -65,7 +65,8 @@ public class TarUtils {
                 final int length = buffer.length;
                 final StringBuilder result = new StringBuilder(length);
 
-                for (final byte b : buffer) {
+                for (int i = 0; i < length; ++i) {
+                    final byte b = buffer[i];
                     if (b == 0) { // Trailing null
                         break;
                     }
