@@ -24,6 +24,7 @@ import static org.apache.tools.zip.ZipConstants.WORD;
 import static org.apache.tools.zip.ZipConstants.ZIP64_MAGIC;
 import static org.apache.tools.zip.ZipConstants.ZIP64_MAGIC_SHORT;
 
+import java.io.Closeable;
 import java.io.EOFException;
 import java.io.File;
 import java.io.IOException;
@@ -34,10 +35,10 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.Enumeration;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.stream.Collectors;
 import java.util.zip.Inflater;
 import java.util.zip.InflaterInputStream;
 import java.util.zip.ZipException;
@@ -72,7 +73,7 @@ import java.util.zip.ZipException;
  * </ul>
  *
  */
-public class ZipFile {
+public class ZipFile implements Closeable {
     private static final int HASH_SIZE = 509;
     static final int NIBLET_MASK = 0x0f;
     static final int BYTE_SHIFT = 8;
@@ -85,13 +86,13 @@ public class ZipFile {
      * List of entries in the order they appear inside the central
      * directory.
      */
-    private final List<ZipEntry> entries = new LinkedList<ZipEntry>();
+    private final List<ZipEntry> entries = new LinkedList<>();
 
     /**
      * Maps String to list of ZipEntrys, name -> actual entries.
      */
     private final Map<String, LinkedList<ZipEntry>> nameMap =
-        new HashMap<String, LinkedList<ZipEntry>>(HASH_SIZE);
+        new HashMap<>(HASH_SIZE);
 
     private static final class OffsetEntry {
         private long headerOffset = -1;
@@ -240,6 +241,7 @@ public class ZipFile {
      * Closes the archive.
      * @throws IOException if an error occurs closing the archive.
      */
+    @Override
     public void close() throws IOException {
         // this flag is only written here and read in finalize() which
         // can never be run in parallel.
@@ -287,9 +289,8 @@ public class ZipFile {
      * @since Ant 1.9.0
      */
     public Enumeration<ZipEntry> getEntriesInPhysicalOrder() {
-        final ZipEntry[] allEntries = entries.toArray(new ZipEntry[0]);
-        Arrays.sort(allEntries, OFFSET_COMPARATOR);
-        return Collections.enumeration(Arrays.asList(allEntries));
+        return entries.stream().sorted(OFFSET_COMPARATOR).collect(Collectors
+            .collectingAndThen(Collectors.toList(), Collections::enumeration));
     }
 
     /**
@@ -314,14 +315,14 @@ public class ZipFile {
      * the archive's central directory.
      *
      * @param name name of the entry.
-     * @return the Iterable<ZipEntry> corresponding to the
+     * @return the Iterable&lt;ZipEntry&gt; corresponding to the
      * given name
      * @since 1.9.2
      */
     public Iterable<ZipEntry> getEntries(final String name) {
         final List<ZipEntry> entriesOfThatName = nameMap.get(name);
         return entriesOfThatName != null ? entriesOfThatName
-            : Collections.<ZipEntry>emptyList();
+            : Collections.emptyList();
     }
 
     /**
@@ -329,17 +330,16 @@ public class ZipFile {
      * appear within the archive.
      *
      * @param name name of the entry.
-     * @return the Iterable<ZipEntry> corresponding to the
+     * @return the Iterable&lt;ZipEntry&gt; corresponding to the
      * given name
      * @since 1.9.2
      */
     public Iterable<ZipEntry> getEntriesInPhysicalOrder(final String name) {
-        ZipEntry[] entriesOfThatName = new ZipEntry[0];
         if (nameMap.containsKey(name)) {
-            entriesOfThatName = nameMap.get(name).toArray(entriesOfThatName);
-            Arrays.sort(entriesOfThatName, OFFSET_COMPARATOR);
+            return nameMap.get(name).stream().sorted(OFFSET_COMPARATOR)
+                .collect(Collectors.toList());
         }
-        return Arrays.asList(entriesOfThatName);
+        return Collections.emptyList();
     }
 
     /**
@@ -347,6 +347,9 @@ public class ZipFile {
      *
      * <p>May return false if it is set up to use encryption or a
      * compression method that hasn't been implemented yet.</p>
+     *
+     * @param ze ZipEntry
+     * @return boolean
      */
     public boolean canReadEntryData(final ZipEntry ze) {
         return ZipUtil.canHandleEntryData(ze);
@@ -365,12 +368,14 @@ public class ZipFile {
         if (!(ze instanceof Entry)) {
             return null;
         }
-        // cast valididty is checked just above
+        // cast validity is checked just above
         final OffsetEntry offsetEntry = ((Entry) ze).getOffsetEntry();
         ZipUtil.checkRequestedFeatures(ze);
         final long start = offsetEntry.dataOffset;
+        // doesn't get closed if the method is not supported, but
+        // doesn't hold any resources either
         final BoundedInputStream bis =
-            new BoundedInputStream(start, ze.getCompressedSize());
+            new BoundedInputStream(start, ze.getCompressedSize()); //NOSONAR
         switch (ze.getMethod()) {
             case ZipEntry.STORED:
                 return bis;
@@ -399,8 +404,8 @@ public class ZipFile {
     protected void finalize() throws Throwable {
         try {
             if (!closed) {
-                System.err.println("Cleaning up unclosed ZipFile for archive "
-                                   + archiveName);
+                System.err.printf("Cleaning up unclosed %s for archive %s%n",
+                    getClass().getSimpleName(), archiveName);
                 close();
             }
         } finally {
@@ -446,8 +451,7 @@ public class ZipFile {
      */
     private Map<ZipEntry, NameAndComment> populateFromCentralDirectory()
         throws IOException {
-        final HashMap<ZipEntry, NameAndComment> noUTF8Flag =
-            new HashMap<ZipEntry, NameAndComment>();
+        final Map<ZipEntry, NameAndComment> noUTF8Flag = new HashMap<>();
 
         positionAtCentralDirectory();
 
@@ -455,8 +459,8 @@ public class ZipFile {
         long sig = ZipLong.getValue(WORD_BUF);
 
         if (sig != CFH_SIG && startsWithLocalFileHeader()) {
-            throw new IOException("central directory is empty, can't expand"
-                                  + " corrupt archive.");
+            throw new IOException(
+                "central directory is empty, can't expand corrupt archive.");
         }
 
         while (sig == CFH_SIG) {
@@ -738,8 +742,8 @@ public class ZipFile {
         archive.seek(ZipEightByteInteger.getLongValue(DWORD_BUF));
         archive.readFully(WORD_BUF);
         if (!Arrays.equals(WORD_BUF, ZipOutputStream.ZIP64_EOCD_SIG)) {
-            throw new ZipException("archive's ZIP64 end of central "
-                                   + "directory locator is corrupt.");
+            throw new ZipException(
+                "archive's ZIP64 end of central directory locator is corrupt.");
         }
         skipBytes(ZIP64_EOCD_CFD_LOCATOR_OFFSET
                   - WORD /* signature has already been read */);
@@ -852,10 +856,10 @@ public class ZipFile {
     private void resolveLocalFileHeaderData(final Map<ZipEntry, NameAndComment>
                                             entriesWithoutUTF8Flag)
         throws IOException {
-        for (final Iterator<ZipEntry> it = entries.iterator(); it.hasNext();) {
+        for (ZipEntry zipEntry : entries) {
             // entries is filled in populateFromCentralDirectory and
             // never modified
-            final Entry ze = (Entry) it.next();
+            final Entry ze = (Entry) zipEntry;
             final OffsetEntry offsetEntry = ze.getOffsetEntry();
             final long offset = offsetEntry.headerOffset;
             archive.seek(offset + LFH_OFFSET_FOR_FILENAME_LENGTH);
@@ -867,8 +871,8 @@ public class ZipFile {
             while (lenToSkip > 0) {
                 final int skipped = archive.skipBytes(lenToSkip);
                 if (skipped <= 0) {
-                    throw new IOException("failed to skip file name in"
-                                          + " local file header");
+                    throw new IOException(
+                        "failed to skip file name in local file header");
                 }
                 lenToSkip -= skipped;
             }
@@ -887,7 +891,7 @@ public class ZipFile {
             final String name = ze.getName();
             LinkedList<ZipEntry> entriesOfThatName = nameMap.get(name);
             if (entriesOfThatName == null) {
-                entriesOfThatName = new LinkedList<ZipEntry>();
+                entriesOfThatName = new LinkedList<>();
                 nameMap.put(name, entriesOfThatName);
             }
             entriesOfThatName.addLast(ze);
@@ -952,7 +956,7 @@ public class ZipFile {
             if (len > remaining) {
                 len = (int) remaining;
             }
-            int ret = -1;
+            int ret;
             synchronized (archive) {
                 archive.seek(loc);
                 ret = archive.read(b, off, len);
@@ -990,25 +994,22 @@ public class ZipFile {
      *
      * @since Ant 1.9.0
      */
-    private final Comparator<ZipEntry> OFFSET_COMPARATOR =
-        new Comparator<ZipEntry>() {
-        public int compare(final ZipEntry e1, final ZipEntry e2) {
-            if (e1 == e2) {
-                return 0;
-            }
-
-            final Entry ent1 = e1 instanceof Entry ? (Entry) e1 : null;
-            final Entry ent2 = e2 instanceof Entry ? (Entry) e2 : null;
-            if (ent1 == null) {
-                return 1;
-            }
-            if (ent2 == null) {
-                return -1;
-            }
-            final long val = (ent1.getOffsetEntry().headerOffset
-                        - ent2.getOffsetEntry().headerOffset);
-            return val == 0 ? 0 : val < 0 ? -1 : +1;
+    private final Comparator<ZipEntry> OFFSET_COMPARATOR = (e1, e2) -> {
+        if (e1 == e2) {
+            return 0;
         }
+
+        final Entry ent1 = e1 instanceof Entry ? (Entry) e1 : null;
+        final Entry ent2 = e2 instanceof Entry ? (Entry) e2 : null;
+        if (ent1 == null) {
+            return 1;
+        }
+        if (ent2 == null) {
+            return -1;
+        }
+        final long val = (ent1.getOffsetEntry().headerOffset
+                    - ent2.getOffsetEntry().headerOffset);
+        return val == 0 ? 0 : val < 0 ? -1 : +1;
     };
 
     /**
@@ -1035,12 +1036,12 @@ public class ZipFile {
         @Override
         public boolean equals(final Object other) {
             if (super.equals(other)) {
-                // super.equals would return false if other were not an Entry
+                // super.equals would return false if other were null or not an Entry
                 final Entry otherEntry = (Entry) other;
                 return offsetEntry.headerOffset
-                        == otherEntry.offsetEntry.headerOffset
+                        == otherEntry.offsetEntry.headerOffset //NOSONAR
                     && offsetEntry.dataOffset
-                        == otherEntry.offsetEntry.dataOffset;
+                        == otherEntry.offsetEntry.dataOffset; //NOSONAR
             }
             return false;
         }
