@@ -122,7 +122,7 @@ public abstract class BuildFileTest extends TestCase {
         String realLog = getLog();
         assertTrue("expecting log to contain \"" + substring + "\" log was \""
                    + realLog + "\"",
-                realLog.contains(substring));
+                   realLog.indexOf(substring) >= 0);
     }
 
     /**
@@ -134,7 +134,7 @@ public abstract class BuildFileTest extends TestCase {
         String realLog = getLog();
         assertFalse("didn't expect log to contain \"" + substring + "\" log was \""
                     + realLog + "\"",
-                realLog.contains(substring));
+                    realLog.indexOf(substring) >= 0);
     }
 
     /**
@@ -160,7 +160,7 @@ public abstract class BuildFileTest extends TestCase {
         String realMessage = (message != null)
             ? message
             : "expecting output to contain \"" + substring + "\" output was \"" + realOutput + "\"";
-        assertTrue(realMessage, realOutput.contains(substring));
+        assertTrue(realMessage, realOutput.indexOf(substring) >= 0);
     }
 
     /**
@@ -176,7 +176,7 @@ public abstract class BuildFileTest extends TestCase {
         String realMessage = (message != null)
             ? message
             : "expecting output to not contain \"" + substring + "\" output was \"" + realOutput + "\"";
-        assertFalse(realMessage, realOutput.contains(substring));
+        assertFalse(realMessage, realOutput.indexOf(substring) >= 0);
     }
 
     /**
@@ -237,7 +237,7 @@ public abstract class BuildFileTest extends TestCase {
         assertTrue("expecting debug log to contain \"" + substring
                    + "\" log was \""
                    + realLog + "\"",
-                realLog.contains(substring));
+                   realLog.indexOf(substring) >= 0);
     }
 
     /**
@@ -425,9 +425,8 @@ public abstract class BuildFileTest extends TestCase {
             executeTarget(target);
         } catch (org.apache.tools.ant.BuildException ex) {
             buildException = ex;
-            if (null != contains && !ex.getMessage().contains(contains)) {
-                fail("Should throw BuildException because '" + cause + "' with message containing '"
-                        + contains + "' (actual message '" + ex.getMessage() + "' instead)");
+            if ((null != contains) && (ex.getMessage().indexOf(contains) == -1)) {
+                fail("Should throw BuildException because '" + cause + "' with message containing '" + contains + "' (actual message '" + ex.getMessage() + "' instead)");
             }
             return;
         }
