@@ -110,7 +110,7 @@ public class CopyTest {
     @Test
     public void testFilterTest() {
         buildRule.executeTarget("filtertest");
-        assertTrue(!buildRule.getLog().contains("loop in tokens"));
+        assertTrue(buildRule.getLog().indexOf("loop in tokens") == -1);
     }
 
     @Test
@@ -222,15 +222,13 @@ public class CopyTest {
         buildRule.executeTarget("testFileResourceWithFilter");
         File file1 = new File(buildRule.getProject().getProperty("to.dir") + "/fileNR.txt");
         assertTrue(file1.exists());
-        FileReader f = null;
         try {
-            f = new FileReader(file1);
-            String file1Content = FileUtils.readFully(f);
-            assertEquals("This is file 42", file1Content);
+            try (FileReader f = new FileReader(file1)) {
+                String file1Content = FileUtils.readFully(f);
+                assertEquals("This is file 42", file1Content);
+            }
         } catch (IOException e) {
             // no-op: not a real business error
-        } finally {
-            FileUtils.close(f);
         }
     }
 
