@@ -17,6 +17,8 @@
  */
 package org.apache.tools.ant.taskdefs;
 
+import java.io.IOException;
+
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.FileUtilities;
@@ -64,28 +66,28 @@ public class GUnzipTest {
     }
 
     @Test
-    public void testRealTest() throws java.io.IOException {
+    public void testRealTest() throws IOException {
         testRealTest("realTest");
     }
 
     @Test
-    public void testRealTestWithResource() throws java.io.IOException {
+    public void testRealTestWithResource() throws IOException {
         testRealTest("realTestWithResource");
     }
 
-    private void testRealTest(String target) throws java.io.IOException {
+    private void testRealTest(String target) throws IOException {
         buildRule.executeTarget(target);
         assertEquals(FileUtilities.getFileContents(buildRule.getProject().resolveFile("../asf-logo.gif")),
                 FileUtilities.getFileContents(buildRule.getProject().resolveFile("asf-logo.gif")));
     }
 
     @Test
-    public void testTestGzipTask() throws java.io.IOException {
+    public void testTestGzipTask() throws IOException {
         testRealTest("testGzipTask");
     }
 
     @Test
-    public void testDocumentationClaimsOnCopy() throws java.io.IOException {
+    public void testDocumentationClaimsOnCopy() throws IOException {
         testRealTest("testDocumentationClaimsOnCopy");
     }
 }
