@@ -24,12 +24,15 @@ import org.apache.tools.ant.BuildFileRule;
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.taskdefs.rmic.RmicAdapterFactory;
 import org.apache.tools.ant.taskdefs.rmic.DefaultRmicAdapter;
+import org.apache.tools.ant.util.JavaEnvUtils;
 import org.junit.Before;
 import org.junit.Ignore;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.ExpectedException;
 
-import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeFalse;
+import static org.junit.Assume.assumeTrue;
 
 /**
  * Date: 04-Aug-2004
@@ -37,11 +40,14 @@ import static org.junit.Assert.fail;
  */
 public class RmicAdvancedTest {
 
-    private final static String TASKDEFS_DIR = "src/etc/testcases/taskdefs/rmic/";
+    private static final String TASKDEFS_DIR = "src/etc/testcases/taskdefs/rmic/";
 
     @Rule
     public BuildFileRule buildRule = new BuildFileRule();
 
+    @Rule
+    public ExpectedException tried = ExpectedException.none();
+
     /**
      * The JUnit setup method
      */
@@ -137,7 +143,7 @@ public class RmicAdvancedTest {
      * test weblogic
      */
     @Test
-    @Ignore("WLRmin tests don't work")
+    @Ignore("WLRmic tests don't work")
     public void XtestWlrmic() throws Exception {
         buildRule.executeTarget("testWlrmic");
     }
@@ -146,7 +152,7 @@ public class RmicAdvancedTest {
      *  test weblogic's stripping of -J args
      */
     @Test
-    @Ignore("WLRmin tests don't work")
+    @Ignore("WLRmic tests don't work")
     public void XtestWlrmicJArg() throws Exception {
         buildRule.executeTarget("testWlrmicJArg");
     }
@@ -155,8 +161,7 @@ public class RmicAdvancedTest {
      * test the forking compiler
      */
     @Test
-    @Ignore("WLRmin tests don't work")
-    public void NotestForking() throws Exception {
+    public void testForking() throws Exception {
         buildRule.executeTarget("testForking");
     }
 
@@ -197,12 +202,9 @@ public class RmicAdvancedTest {
      */
     @Test
     public void testBadName() throws Exception {
-        try {
-            buildRule.executeTarget("testBadName");
-            fail("Compile not known");
-        } catch (BuildException ex) {
-            AntAssert.assertContains(RmicAdapterFactory.ERROR_UNKNOWN_COMPILER, ex.getMessage());
-        }
+        tried.expect(BuildException.class);
+        tried.expectMessage(RmicAdapterFactory.ERROR_UNKNOWN_COMPILER);
+        buildRule.executeTarget("testBadName");
     }
 
     /**
@@ -218,42 +220,34 @@ public class RmicAdvancedTest {
      */
     @Test
     public void testWrongClass() throws Exception {
-        try {
-            buildRule.executeTarget("testWrongClass");
-            fail("Class not an RMIC adapter");
-        } catch (BuildException ex) {
-            AntAssert.assertContains(RmicAdapterFactory.ERROR_NOT_RMIC_ADAPTER, ex.getMessage());
-        }
+        tried.expect(BuildException.class);
+        tried.expectMessage(RmicAdapterFactory.ERROR_NOT_RMIC_ADAPTER);
+        buildRule.executeTarget("testWrongClass");
     }
 
-
     /**
      * A unit test for JUnit
      */
     @Test
     public void testDefaultBadClass() throws Exception {
+        tried.expect(BuildException.class);
+        tried.expectMessage(Rmic.ERROR_RMIC_FAILED);
         try {
             buildRule.executeTarget("testDefaultBadClass");
-            fail("expected the class to fail");
-        } catch(BuildException ex) {
-            AntAssert.assertContains(Rmic.ERROR_RMIC_FAILED, ex.getMessage());
+        } finally {
+            // don't look for much text here as it is vendor and version dependent
+            AntAssert.assertContains("unimplemented.class", buildRule.getLog());
         }
-        //dont look for much text here as it is vendor and version dependent
-        AntAssert.assertContains("unimplemented.class", buildRule.getLog());
     }
 
-
     /**
      * A unit test for JUnit
      */
     @Test
     public void testMagicProperty() throws Exception {
-        try {
-            buildRule.executeTarget("testMagicProperty");
-            fail("Magic property not working");
-        } catch (BuildException ex) {
-            AntAssert.assertContains(RmicAdapterFactory.ERROR_UNKNOWN_COMPILER, ex.getMessage());
-        }
+        tried.expect(BuildException.class);
+        tried.expectMessage(RmicAdapterFactory.ERROR_UNKNOWN_COMPILER);
+        buildRule.executeTarget("testMagicProperty");
     }
 
     /**
@@ -261,36 +255,27 @@ public class RmicAdvancedTest {
      */
     @Test
     public void testMagicPropertyOverridesEmptyString() throws Exception {
-        try {
-            buildRule.executeTarget("testMagicPropertyOverridesEmptyString");
-            fail("Magic property not working");
-        } catch (BuildException ex) {
-            AntAssert.assertContains(RmicAdapterFactory.ERROR_UNKNOWN_COMPILER, ex.getMessage());
-        }
+        tried.expect(BuildException.class);
+        tried.expectMessage(RmicAdapterFactory.ERROR_UNKNOWN_COMPILER);
+        buildRule.executeTarget("testMagicPropertyOverridesEmptyString");
     }
 
-
     @Test
     public void testMagicPropertyIsEmptyString() throws Exception {
         buildRule.executeTarget("testMagicPropertyIsEmptyString");
     }
 
-
     @Test
     @Ignore("Previously named to prevent execution")
     public void NotestFailingAdapter() throws Exception {
-        try {
-            buildRule.executeTarget("testFailingAdapter");
-            fail("Expected failures to propogate");
-        } catch (BuildException ex) {
-            AntAssert.assertContains(Rmic.ERROR_RMIC_FAILED, ex.getMessage());
-        }
+        tried.expect(BuildException.class);
+        tried.expectMessage(Rmic.ERROR_RMIC_FAILED);
+        buildRule.executeTarget("testFailingAdapter");
     }
 
-
     /**
      * test that version 1.1 stubs are good
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testVersion11() throws Exception {
@@ -299,7 +284,7 @@ public class RmicAdvancedTest {
 
     /**
      * test that version 1.1 stubs are good
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testVersion11Dest() throws Exception {
@@ -309,7 +294,7 @@ public class RmicAdvancedTest {
     /**
      * test that version 1.2 stubs are good
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testVersion12() throws Exception {
@@ -319,7 +304,7 @@ public class RmicAdvancedTest {
     /**
      * test that version 1.2 stubs are good
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testVersion12Dest() throws Exception {
@@ -329,7 +314,7 @@ public class RmicAdvancedTest {
     /**
      * test that version compat stubs are good
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testVersionCompat() throws Exception {
@@ -339,113 +324,165 @@ public class RmicAdvancedTest {
     /**
      * test that version compat stubs are good
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testVersionCompatDest() throws Exception {
         buildRule.executeTarget("testVersionCompatDest");
     }
 
-    /**
-     * test that passes -Xnew to sun's rmic.
-     *
-     * @throws Exception
-     */
-    @Test
-    public void testXnew() throws Exception {
-        buildRule.executeTarget("testXnew");
-    }
-
-    /**
-     * test that passes -Xnew to sun's rmic.
-     *
-     * @throws Exception
-     */
-    @Test
-    public void testXnewDest() throws Exception {
-        buildRule.executeTarget("testXnewDest");
-    }
-
     /**
      * test that passes -Xnew to sun's rmic running in a different VM.
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testXnewForked() throws Exception {
+        assumeFalse("Current system is Java 9 or newer", JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9));
+        buildRule.executeTarget("testXnewForked");
+    }
+
+    @Test
+    public void testXnewForkedJava9plus() throws Exception {
+        assumeTrue("Current system is Java 8 or older", JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9));
+        tried.expect(BuildException.class);
+        tried.expectMessage("JDK9 has removed support for -Xnew");
         buildRule.executeTarget("testXnewForked");
     }
 
     /**
      * test that passes -Xnew to sun's rmic running in a different VM.
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testXnewForkedDest() throws Exception {
+        assumeFalse("Current system is Java 9 or newer", JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9));
+        buildRule.executeTarget("testXnewForkedDest");
+    }
+
+    @Test
+    public void testXnewForkedDestJava9plus() throws Exception {
+        assumeTrue("Current system is Java 8 or older", JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9));
+        tried.expect(BuildException.class);
+        tried.expectMessage("JDK9 has removed support for -Xnew");
         buildRule.executeTarget("testXnewForkedDest");
     }
 
     /**
      * test that runs the new xnew compiler adapter.
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testXnewCompiler() throws Exception {
+        assumeFalse("Current system is Java 9 or newer", JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9));
+        buildRule.executeTarget("testXnewCompiler");
+    }
+
+    @Test
+    public void testXnewCompilerJava9plus() throws Exception {
+        assumeTrue("Current system is Java 8 or older", JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9));
+        tried.expect(BuildException.class);
+        tried.expectMessage("JDK9 has removed support for -Xnew");
         buildRule.executeTarget("testXnewCompiler");
     }
 
     /**
      * test that runs the new xnew compiler adapter.
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testXnewCompilerDest() throws Exception {
+        assumeFalse("Current system is Java 9 or newer", JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9));
+        buildRule.executeTarget("testXnewCompilerDest");
+    }
+
+    @Test
+    public void testXnewCompilerDestJava9plus() throws Exception {
+        assumeTrue("Current system is Java 8 or older", JavaEnvUtils.isAtLeastJavaVersion(JavaEnvUtils.JAVA_9));
+        tried.expect(BuildException.class);
+        tried.expectMessage("JDK9 has removed support for -Xnew");
         buildRule.executeTarget("testXnewCompilerDest");
     }
 
     /**
      * test that verifies that IDL compiles.
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testIDL() throws Exception {
+        assumeFalse("Current system is Java 11 or newer", JavaEnvUtils.isAtLeastJavaVersion("11"));
+        buildRule.executeTarget("testIDL");
+    }
+
+    @Test
+    public void testIDLJava11plus() throws Exception {
+        assumeTrue("Current system is Java 10 or older", JavaEnvUtils.isAtLeastJavaVersion("11"));
+        tried.expect(BuildException.class);
+        tried.expectMessage("this rmic implementation doesn't support the -idl switch");
         buildRule.executeTarget("testIDL");
     }
 
     /**
      * test that verifies that IDL compiles.
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testIDLDest() throws Exception {
+        assumeFalse("Current system is Java 11 or newer", JavaEnvUtils.isAtLeastJavaVersion("11"));
         buildRule.executeTarget("testIDLDest");
     }
 
+    @Test
+    public void testIDLDestJava11plus() throws Exception {
+        assumeTrue("Current system is Java 10 or older", JavaEnvUtils.isAtLeastJavaVersion("11"));
+        tried.expect(BuildException.class);
+        tried.expectMessage("this rmic implementation doesn't support the -idl switch");
+        buildRule.executeTarget("testIDL");
+   }
+
     /**
      * test that verifies that IIOP compiles.
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testIIOP() throws Exception {
+        assumeFalse("Current system is Java 11 or newer", JavaEnvUtils.isAtLeastJavaVersion("11"));
+        buildRule.executeTarget("testIIOP");
+    }
+
+    @Test
+    public void testIIOPJava11plus() throws Exception {
+        assumeTrue("Current system is Java 10 or older", JavaEnvUtils.isAtLeastJavaVersion("11"));
+        tried.expect(BuildException.class);
+        tried.expectMessage("this rmic implementation doesn't support the -iiop switch");
         buildRule.executeTarget("testIIOP");
     }
 
     /**
      * test that verifies that IIOP compiles.
      *
-     * @throws Exception
+     * @throws Exception if something goes wrong
      */
     @Test
     public void testIIOPDest() throws Exception {
+        assumeFalse("Current system is Java 11 or newer", JavaEnvUtils.isAtLeastJavaVersion("11"));
         buildRule.executeTarget("testIIOPDest");
     }
 
+    @Test
+    public void testIIOPDestJava11plus() throws Exception {
+        assumeTrue("Current system is Java 10 or older", JavaEnvUtils.isAtLeastJavaVersion("11"));
+        tried.expect(BuildException.class);
+        tried.expectMessage("this rmic implementation doesn't support the -iiop switch");
+        buildRule.executeTarget("testIIOP");
+    }
+
     /**
      * this little bunny verifies that we can load stuff, and that
      * a failure to execute is turned into a fault
