@@ -32,10 +32,9 @@ public class SleepTest {
     @Rule
     public final BuildFileRule buildRule = new BuildFileRule();
 
-    private final static String TASKDEFS_DIR = "src/etc/testcases/taskdefs/";
-	private final static int ERROR_RANGE=1000;
-	
-    
+    private static final String TASKDEFS_DIR = "src/etc/testcases/taskdefs/";
+    private static final int ERROR_RANGE = 1000;
+
     @Before
     public void setUp() {
         buildRule.configureProject(TASKDEFS_DIR + "sleep.xml");
@@ -43,34 +42,34 @@ public class SleepTest {
 
     @Test
     public void test1() {
-       Timer timer=new Timer();
+       Timer timer = new Timer();
         buildRule.executeTarget("test1");
         timer.stop();
-        assertTrue(timer.time()>=0);
+        assertTrue(timer.time() >= 0);
     }
 
     @Test
     public void test2() {
-        Timer timer=new Timer();
+        Timer timer = new Timer();
         buildRule.executeTarget("test2");
         timer.stop();
-        assertTrue(timer.time()>=0);
+        assertTrue(timer.time() >= 0);
     }
 
     @Test
     public void test3() {
-        Timer timer=new Timer();
+        Timer timer = new Timer();
         buildRule.executeTarget("test3");
         timer.stop();
-        assertTrue(timer.time()>=(2000-ERROR_RANGE));
+        assertTrue(timer.time() >= (2000 - ERROR_RANGE));
     }
 
     @Test
     public void test4() {
-        Timer timer=new Timer();
+        Timer timer = new Timer();
         buildRule.executeTarget("test3");
         timer.stop();
-        assertTrue(timer.time()>=(2000-ERROR_RANGE) && timer.time()<60000);
+        assertTrue(timer.time() >= (2000 - ERROR_RANGE) && timer.time() < 60000);
     }
 
     @Test
@@ -85,10 +84,10 @@ public class SleepTest {
 
     @Test
     public void test6() {
-        Timer timer=new Timer();
+        Timer timer = new Timer();
         buildRule.executeTarget("test6");
         timer.stop();
-        assertTrue(timer.time()<2000);
+        assertTrue(timer.time() < 2000);
     }
 
 
@@ -96,25 +95,24 @@ public class SleepTest {
     * inner timer class
     */
     private static class Timer {
-        long start=0;
-        long stop=0;
+        long start = 0;
+        long stop = 0;
 
         public Timer() {
             start();
         }
 
         public void start() {
-            start=System.currentTimeMillis();
+            start = System.currentTimeMillis();
         }
 
         public void stop() {
-            stop=System.currentTimeMillis();
+            stop = System.currentTimeMillis();
         }
 
         public long time() {
-            return stop-start;
+            return stop - start;
         }
     }
 
 }
-
