@@ -48,7 +48,7 @@ public class SubAntTest {
     @Test
     public void testnodirs() {
         buildRule.executeTarget("testnodirs");
-        assertEquals("No sub-builds to iterate on",buildRule.getLog());
+        assertEquals("No sub-builds to iterate on", buildRule.getLog());
     }
 
     // target must be specified
@@ -59,11 +59,9 @@ public class SubAntTest {
         File dir3 = buildRule.getProject().resolveFile("subant/subant-test2");
 
         testBaseDirs("testgenericantfile",
-                     new String[] { dir1.getAbsolutePath(),
-                         dir2.getAbsolutePath(),
-                         dir3.getAbsolutePath()
-
-                     });
+                new String[] {dir1.getAbsolutePath(),
+                        dir2.getAbsolutePath(),
+                        dir3.getAbsolutePath()});
     }
 
     @Test
@@ -77,14 +75,12 @@ public class SubAntTest {
         File dir3 = buildRule.getProject().resolveFile("subant");
 
         testBaseDirs("testantfile",
-                     new String[] { dir1.getAbsolutePath(),
-                         dir2.getAbsolutePath(),
-                         dir3.getAbsolutePath()
-
-                     });
+                new String[] {dir1.getAbsolutePath(),
+                        dir2.getAbsolutePath(),
+                        dir3.getAbsolutePath()});
 
     }
-    
+
     @Test
     public void testMultipleTargets() {
         buildRule.executeTarget("multipleTargets");
@@ -93,13 +89,13 @@ public class SubAntTest {
         assertContains("test2-one", buildRule.getLog());
         assertContains("test2-two", buildRule.getLog());
     }
-    
+
     @Test
     public void testMultipleTargetsOneDoesntExist_FOEfalse() {
         buildRule.executeTarget("multipleTargetsOneDoesntExist_FOEfalse");
         assertContains("Target \"three\" does not exist in the project \"subant\"", buildRule.getLog());
     }
-    
+
     @Test
     public void testMultipleTargetsOneDoesntExist_FOEtrue() {
         try {
@@ -130,12 +126,23 @@ public class SubAntTest {
             expectedBasedirs = dirs;
         }
 
-        public void buildStarted(BuildEvent event) {}
-        public void buildFinished(BuildEvent event) {}
-        public void targetFinished(BuildEvent event){}
-        public void taskStarted(BuildEvent event) {}
-        public void taskFinished(BuildEvent event) {}
-        public void messageLogged(BuildEvent event) {}
+        public void buildStarted(BuildEvent event) {
+        }
+
+        public void buildFinished(BuildEvent event) {
+        }
+
+        public void targetFinished(BuildEvent event) {
+        }
+
+        public void taskStarted(BuildEvent event) {
+        }
+
+        public void taskFinished(BuildEvent event) {
+        }
+
+        public void messageLogged(BuildEvent event) {
+        }
 
         public void targetStarted(BuildEvent event) {
             if (event.getTarget().getName().equals("")) {
