@@ -24,23 +24,17 @@ import org.junit.internal.AssumptionViolatedException;
  * Interactive Testcase for Processdestroyer.
  *
  */
-public class TestProcess
-    implements Runnable
-{
+public class TestProcess implements Runnable {
     private boolean run = true;
     private boolean done = false;
 
-    public void shutdown()
-    {
-        if (!done)
-        {
+    public void shutdown() {
+        if (!done) {
             System.out.println("shutting down TestProcess");
             run = false;
 
-            synchronized(this)
-            {
-                while (!done)
-                {
+            synchronized (this) {
+                while (!done) {
                     try {
                         wait();
                     } catch (InterruptedException ie) {
@@ -53,10 +47,8 @@ public class TestProcess
         }
     }
 
-    public void run()
-    {
-        for (int i = 0; i < 5 && run; i++)
-        {
+    public void run() {
+        for (int i = 0; i < 5 && run; i++) {
             System.out.println(Thread.currentThread().getName());
 
             try {
@@ -66,29 +58,23 @@ public class TestProcess
             }
         }
 
-        synchronized(this)
-        {
+        synchronized (this) {
             done = true;
             notifyAll();
         }
     }
 
-    public Thread getShutdownHook()
-    {
+    public Thread getShutdownHook() {
         return new TestProcessShutdownHook();
     }
 
-    private class TestProcessShutdownHook
-        extends Thread
-    {
-        public void run()
-        {
+    private class TestProcessShutdownHook extends Thread {
+        public void run() {
             shutdown();
         }
     }
 
-    public static void main(String[] args)
-    {
+    public static void main(String[] args) {
         TestProcess tp = new TestProcess();
         new Thread(tp, "TestProcess thread").start();
         Runtime.getRuntime().addShutdownHook(tp.getShutdownHook());
