@@ -35,7 +35,7 @@ public class XsltTest {
     /**
      * where tasks run
      */
-    private final static String TASKDEFS_DIR = "src/etc/testcases/taskdefs/optional/";
+    private static final String TASKDEFS_DIR = "src/etc/testcases/taskdefs/optional/";
 
     @Rule
     public BuildFileRule buildRule = new BuildFileRule();
@@ -45,7 +45,6 @@ public class XsltTest {
         buildRule.configureProject(TASKDEFS_DIR + "xslt.xml");
     }
 
-
     @Test
     public void testCatchNoDtd() {
         try {
@@ -83,4 +82,3 @@ public class XsltTest {
         }
     }
 }
-
