@@ -26,10 +26,10 @@ import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 
-public class JUnitTestListenerTest{
-	
-	@Rule
-	public BuildFileRule buildRule = new BuildFileRule();
+public class JUnitTestListenerTest {
+
+    @Rule
+    public BuildFileRule buildRule = new BuildFileRule();
 
     // The captureToSummary test writes to stdout and stderr, good for
     // verifying that the TestListener support doesn't break anything.
@@ -48,64 +48,64 @@ public class JUnitTestListenerTest{
     public void testFullLogOutput() {
         buildRule.getProject().setProperty("enableEvents", "true");
         buildRule.executeTarget(PASS_TEST_TARGET);
-        assertContains("expecting full log to have BuildListener events", 
-        		JUnitTask.TESTLISTENER_PREFIX, buildRule.getFullLog());
+        assertContains("expecting full log to have BuildListener events",
+                JUnitTask.TESTLISTENER_PREFIX, buildRule.getFullLog());
     }
-    
+
     @Test
     public void testNoLogOutput() {
         buildRule.getProject().setProperty("enableEvents", "true");
         buildRule.executeTarget(PASS_TEST_TARGET);
-        assertNotContains("expecting log to not have BuildListener events", 
-        		JUnitTask.TESTLISTENER_PREFIX, buildRule.getLog());
+        assertNotContains("expecting log to not have BuildListener events",
+                JUnitTask.TESTLISTENER_PREFIX, buildRule.getLog());
     }
 
     @Test
     public void testTestCountFired() {
         buildRule.getProject().setProperty("enableEvents", "true");
         buildRule.executeTarget(PASS_TEST_TARGET);
-	    assertContains("expecting test count message", JUnitTask.TESTLISTENER_PREFIX + 
-				   "tests to run: ", buildRule.getFullLog());
+        assertContains("expecting test count message", JUnitTask.TESTLISTENER_PREFIX
+                + "tests to run: ", buildRule.getFullLog());
     }
-    
+
     @Test
     public void testStartTestFired() {
         buildRule.getProject().setProperty("enableEvents", "true");
         buildRule.executeTarget(PASS_TEST_TARGET);
-        assertContains("expecting test started message", JUnitTask.TESTLISTENER_PREFIX + 
-				   "startTest(" + PASS_TEST + ")", buildRule.getFullLog());
+        assertContains("expecting test started message", JUnitTask.TESTLISTENER_PREFIX
+                + "startTest(" + PASS_TEST + ")", buildRule.getFullLog());
     }
-    
+
     @Test
     public void testEndTestFired() {
         buildRule.getProject().setProperty("enableEvents", "true");
         buildRule.executeTarget(PASS_TEST_TARGET);
-        assertContains("expecting test ended message", JUnitTask.TESTLISTENER_PREFIX + 
-				   "endTest(" + PASS_TEST + ")", buildRule.getFullLog());
+        assertContains("expecting test ended message", JUnitTask.TESTLISTENER_PREFIX
+                + "endTest(" + PASS_TEST + ")", buildRule.getFullLog());
     }
-    
+
     @Test
     public void testNoFullLogOutputByDefault() {
         buildRule.executeTarget(PASS_TEST_TARGET);
-        assertNotContains("expecting full log to not have BuildListener events", 
-        		JUnitTask.TESTLISTENER_PREFIX, buildRule.getFullLog());
+        assertNotContains("expecting full log to not have BuildListener events",
+                JUnitTask.TESTLISTENER_PREFIX, buildRule.getFullLog());
     }
-    
+
     @Test
     public void testFullLogOutputMagicProperty() {
         buildRule.getProject().setProperty(JUnitTask.ENABLE_TESTLISTENER_EVENTS, "true");
         buildRule.executeTarget(PASS_TEST_TARGET);
-        assertContains("expecting full log to have BuildListener events", 
-        		JUnitTask.TESTLISTENER_PREFIX, buildRule.getFullLog());
+        assertContains("expecting full log to have BuildListener events",
+                JUnitTask.TESTLISTENER_PREFIX, buildRule.getFullLog());
     }
-    
+
     @Test
     public void testNoFullLogOutputMagicPropertyWins() {
         buildRule.getProject().setProperty(JUnitTask.ENABLE_TESTLISTENER_EVENTS, "false");
         buildRule.getProject().setProperty("enableEvents", "true");
         buildRule.executeTarget(PASS_TEST_TARGET);
-        assertNotContains("expecting full log to not have BuildListener events", 
-        		JUnitTask.TESTLISTENER_PREFIX, buildRule.getFullLog());
+        assertNotContains("expecting full log to not have BuildListener events",
+                JUnitTask.TESTLISTENER_PREFIX, buildRule.getFullLog());
     }
-    
+
 }
