@@ -17,10 +17,11 @@
  */
 package org.apache.tools.ant.taskdefs.optional.junit;
 
-import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
+import java.io.OutputStream;
 import java.io.PrintWriter;
 import java.io.StringWriter;
 
@@ -36,31 +37,29 @@ import org.junit.Test;
  * They must be enhanced with time.
  *
  */
-public class JUnitTestRunnerTest{
-
-  
+public class JUnitTestRunnerTest {
 
     // check that a valid method name generates no errors
     @Test
-    public void testValidMethod(){
-        TestRunner runner = createRunnerForTestMethod(ValidMethodTestCase.class,"testA");
+    public void testValidMethod() {
+        TestRunner runner = createRunnerForTestMethod(ValidMethodTestCase.class, "testA");
         runner.run();
         assertEquals(runner.getFormatter().getError(), JUnitTestRunner.SUCCESS, runner.getRetCode());
     }
 
     // check that having an invalid method name generates an error
     @Test
-    public void testInvalidMethod(){
-        TestRunner runner = createRunnerForTestMethod(InvalidMethodTestCase.class,"testInvalid");
+    public void testInvalidMethod() {
+        TestRunner runner = createRunnerForTestMethod(InvalidMethodTestCase.class, "testInvalid");
         runner.run();
         String error = runner.getFormatter().getError();
         // might be FAILURES or ERRORS depending on JUnit version?
         assertTrue(error, runner.getRetCode() != JUnitTestRunner.SUCCESS);
-    }    
-    
+    }
+
     // check that having no suite generates no errors
     @Test
-    public void testNoSuite(){
+    public void testNoSuite() {
         TestRunner runner = createRunner(NoSuiteTestCase.class);
         runner.run();
         assertEquals(runner.getFormatter().getError(), JUnitTestRunner.SUCCESS, runner.getRetCode());
@@ -68,7 +67,7 @@ public class JUnitTestRunnerTest{
 
     // check that a suite generates no errors
     @Test
-    public void testSuite(){
+    public void testSuite() {
         TestRunner runner = createRunner(SuiteTestCase.class);
         runner.run();
         assertEquals(runner.getFormatter().getError(), JUnitTestRunner.SUCCESS, runner.getRetCode());
@@ -76,7 +75,7 @@ public class JUnitTestRunnerTest{
 
     // check that an invalid suite generates an error.
     @Test
-    public void testInvalidSuite(){
+    public void testInvalidSuite() {
         TestRunner runner = createRunner(InvalidSuiteTestCase.class);
         runner.run();
         String error = runner.getFormatter().getError();
@@ -87,12 +86,12 @@ public class JUnitTestRunnerTest{
     // check that something which is not a testcase generates no errors
     // at first even though this is incorrect.
     @Test
-    public void testNoTestCase(){
+    public void testNoTestCase() {
         TestRunner runner = createRunner(NoTestCase.class);
         runner.run();
         // On junit3 this is a FAILURE, on junit4 this is an ERROR
         int ret = runner.getRetCode();
-        
+
         if (ret != JUnitTestRunner.FAILURES && ret != JUnitTestRunner.ERRORS) {
             fail("Unexpected result " + ret + " from junit runner");
         }
@@ -102,7 +101,7 @@ public class JUnitTestRunnerTest{
 
     // check that an exception in the constructor is noticed
     @Test
-    public void testInvalidTestCase(){
+    public void testInvalidTestCase() {
         TestRunner runner = createRunner(InvalidTestCase.class);
         runner.run();
         // On junit3 this is a FAILURE, on junit4 this is an ERROR
@@ -116,49 +115,76 @@ public class JUnitTestRunnerTest{
         //assertTrue(error, error.indexOf("thrown on purpose") != -1);
     }
 
-    protected TestRunner createRunner(Class<?> clazz){
-        return new TestRunner(new JUnitTest(clazz.getName()), null, 
+    // check that JUnit 4 synthetic AssertionFailedError gets message and cause from AssertionError
+    @Test
+    public void testJUnit4AssertionError() {
+        TestRunner runner = createRunnerForTestMethod(AssertionErrorTest.class, "throwsAssertionError");
+        runner.run();
+
+        AssertionFailedError failure = runner.getFormatter().getFailure();
+        assertEquals("failure message", failure.getMessage());
+
+        Throwable cause = failure.getCause();
+        assertEquals(RuntimeException.class, cause.getClass());
+        assertEquals("cause message", cause.getMessage());
+    }
+
+    protected TestRunner createRunner(Class<?> clazz) {
+        return new TestRunner(new JUnitTest(clazz.getName()), null,
                                             true, true, true);
     }
 
-    protected TestRunner createRunnerForTestMethod(Class<?> clazz, String method){
+    protected TestRunner createRunnerForTestMethod(Class<?> clazz, String method) {
         return new TestRunner(new JUnitTest(clazz.getName()), new String[] {method},
                                             true, true, true);
-    }    
-    
+    }
+
     // the test runner that wrap the dummy formatter that interests us
-    private final static class TestRunner extends JUnitTestRunner {
+    private static final class TestRunner extends JUnitTestRunner {
         private ResultFormatter formatter = new ResultFormatter();
         TestRunner(JUnitTest test, String[] methods, boolean haltonerror,
-                   boolean filtertrace, boolean haltonfailure){
-            super(test, methods, haltonerror, filtertrace,  haltonfailure, 
+                   boolean filtertrace, boolean haltonfailure) {
+            super(test, methods, haltonerror, filtertrace,  haltonfailure,
                   false, false, TestRunner.class.getClassLoader());
             // use the classloader that loaded this class otherwise
             // it will not be able to run inner classes if this test
             // is ran in non-forked mode.
             addFormatter(formatter);
         }
-        ResultFormatter getFormatter(){
+        ResultFormatter getFormatter() {
             return formatter;
         }
     }
 
     // dummy formatter just to catch the error
-    private final static class ResultFormatter implements JUnitResultFormatter {
+    private static final class ResultFormatter implements JUnitResultFormatter {
+        private AssertionFailedError failure;
         private Throwable error;
-        public void setSystemOutput(String output){}
-        public void setSystemError(String output){}
-        public void startTestSuite(JUnitTest suite) throws BuildException{}
-        public void endTestSuite(JUnitTest suite) throws BuildException{}
-        public void setOutput(java.io.OutputStream out){}
-        public void startTest(junit.framework.Test t) {}
-        public void endTest(junit.framework.Test test) {}
-        public void addFailure(junit.framework.Test test, AssertionFailedError t) { }
+        public void setSystemOutput(String output) {
+        }
+        public void setSystemError(String output) {
+        }
+        public void startTestSuite(JUnitTest suite) throws BuildException {
+        }
+        public void endTestSuite(JUnitTest suite) throws BuildException {
+        }
+        public void setOutput(OutputStream out) {
+        }
+        public void startTest(junit.framework.Test t) {
+        }
+        public void endTest(junit.framework.Test test) {
+        }
+        public void addFailure(junit.framework.Test test, AssertionFailedError t) {
+            failure = t;
+        }
+        AssertionFailedError getFailure() {
+            return failure;
+        }
         public void addError(junit.framework.Test test, Throwable t) {
             error = t;
         }
-        String getError(){
-            if (error == null){
+        String getError() {
+            if (error == null) {
                 return "";
             }
             StringWriter sw = new StringWriter();
@@ -171,47 +197,64 @@ public class JUnitTestRunnerTest{
     }
 
     public static class InvalidMethodTestCase extends TestCase {
-        public InvalidMethodTestCase(String name){ super(name); }
-        public void testA(){
+        public InvalidMethodTestCase(String name) {
+            super(name);
+        }
+        public void testA() {
             throw new NullPointerException("thrown on purpose");
         }
     }
 
     public static class ValidMethodTestCase extends TestCase {
-        public ValidMethodTestCase(String name){ super(name); }
-        public void testA(){
+        public ValidMethodTestCase(String name) {
+            super(name);
+        }
+        public void testA() {
             // expected to be executed
         }
-        public void testB(){
+        public void testB() {
             // should not be executed
             throw new NullPointerException("thrown on purpose");
         }
-    }    
-    
+    }
+
     public static class InvalidTestCase extends TestCase {
-        public InvalidTestCase(String name){
+        public InvalidTestCase(String name) {
             super(name);
             throw new NullPointerException("thrown on purpose");
         }
     }
 
     public static class NoSuiteTestCase extends TestCase {
-        public NoSuiteTestCase(String name){ super(name); }
-        public void testA(){}
+        public NoSuiteTestCase(String name) {
+            super(name);
+        }
+        public void testA() {
+        }
     }
 
     public static class SuiteTestCase extends NoSuiteTestCase {
-        public SuiteTestCase(String name){ super(name); }
-        public static junit.framework.Test suite(){
+        public SuiteTestCase(String name) {
+            super(name);
+        }
+        public static junit.framework.Test suite() {
             return new TestSuite(SuiteTestCase.class);
         }
     }
 
     public static class InvalidSuiteTestCase extends NoSuiteTestCase {
-        public InvalidSuiteTestCase(String name){ super(name); }
-        public static junit.framework.Test suite(){
+        public InvalidSuiteTestCase(String name) {
+            super(name);
+        }
+        public static junit.framework.Test suite() {
             throw new NullPointerException("thrown on purpose");
         }
     }
-}
 
+    public static class AssertionErrorTest {
+        @Test
+        public void throwsAssertionError() {
+            throw new AssertionError("failure message", new RuntimeException("cause message"));
+        }
+    }
+}
