@@ -39,11 +39,11 @@ public abstract class BaseSelectorTest extends BuildFileTest {
     protected File basedir;
     protected File beddir;
     protected File mirrordir;
-    protected String[] filenames = {".","asf-logo.gif.md5","asf-logo.gif.bz2",
-            "asf-logo.gif.gz","copy.filterset.filtered","zip/asf-logo.gif.zip",
-            "tar/asf-logo.gif.tar","tar/asf-logo-huge.tar.gz",
-            "tar/gz/asf-logo.gif.tar.gz","tar/bz2/asf-logo.gif.tar.bz2",
-            "tar/bz2/asf-logo-huge.tar.bz2","tar/bz2"};
+    protected String[] filenames = {".", "asf-logo.gif.md5", "asf-logo.gif.bz2",
+            "asf-logo.gif.gz", "copy.filterset.filtered", "zip/asf-logo.gif.zip",
+            "tar/asf-logo.gif.tar", "tar/asf-logo-huge.tar.gz",
+            "tar/gz/asf-logo.gif.tar.gz", "tar/bz2/asf-logo.gif.tar.bz2",
+            "tar/bz2/asf-logo-huge.tar.bz2", "tar/bz2"};
     protected File[] files = new File[filenames.length];
     protected File[] mirrorfiles = new File[filenames.length];
 
@@ -61,8 +61,8 @@ public abstract class BaseSelectorTest extends BuildFileTest {
         project.init();
         project.setBaseDir(basedir);
         for (int x = 0; x < files.length; x++) {
-            files[x] = new File(beddir,filenames[x]);
-            mirrorfiles[x] = new File(mirrordir,filenames[x]);
+            files[x] = new File(beddir, filenames[x]);
+            mirrorfiles[x] = new File(mirrordir, filenames[x]);
         }
     }
 
@@ -79,7 +79,7 @@ public abstract class BaseSelectorTest extends BuildFileTest {
      */
     public BaseSelector getSelector() {
         BaseSelector selector = getInstance();
-        selector.setProject( getProject() );
+        selector.setProject(getProject());
         return selector;
     }
 
@@ -100,7 +100,7 @@ public abstract class BaseSelectorTest extends BuildFileTest {
         }
         s.setError("test error");
         try {
-            s.isSelected(beddir,filenames[0],files[0]);
+            s.isSelected(beddir, filenames[0], files[0]);
             fail("Cannot cause BuildException when setError() is called");
         } catch (BuildException be) {
             assertEquals("test error",
@@ -113,9 +113,11 @@ public abstract class BaseSelectorTest extends BuildFileTest {
      * This is a helper method that takes a selector and calls its
      * isSelected() method on each file in the testbed. It returns
      * a string of "T"s amd "F"s
+     *
+     * @param selector FileSelector
      */
     public String selectionString(FileSelector selector) {
-        return selectionString(beddir,files,selector);
+        return selectionString(beddir, files, selector);
     }
 
     /**
@@ -124,23 +126,28 @@ public abstract class BaseSelectorTest extends BuildFileTest {
      * variation is used for dependency checks and to get around the
      * limitations in the touch task when running JDK 1.1. It returns
      * a string of "T"s amd "F"s.
+     *
+     * @param selector FileSelector
      */
     public String mirrorSelectionString(FileSelector selector) {
-        return selectionString(mirrordir,mirrorfiles,selector);
+        return selectionString(mirrordir, mirrorfiles, selector);
     }
 
     /**
      * Worker method for the two convenience methods above. Applies a
      * selector on a set of files passed in and returns a string of
      * "T"s amd "F"s from applying the selector to each file.
+     *
+     * @param basedir File
+     * @param files File[]
+     * @param selector FileSelector
      */
     public String selectionString(File basedir, File[] files, FileSelector selector) {
-        StringBuffer buf = new StringBuffer();
+        StringBuilder buf = new StringBuilder();
         for (int x = 0; x < files.length; x++) {
-            if (selector.isSelected(basedir,filenames[x],files[x])) {
+            if (selector.isSelected(basedir, filenames[x], files[x])) {
                 buf.append('T');
-            }
-            else {
+            } else {
                 buf.append('F');
             }
         }
@@ -151,6 +158,7 @@ public abstract class BaseSelectorTest extends BuildFileTest {
      * Does the selection test for a given selector and prints the
      * filenames of the differing files (selected but shouldn't,
      * not selected but should).
+     *
      * @param selector  The selector to test
      * @param expected  The expected result
      */
@@ -162,24 +170,22 @@ public abstract class BaseSelectorTest extends BuildFileTest {
     }
 
     /**
-     *  Checks which files are selected and shouldn't be or which
-     *  are not selected but should.
-     *  @param expected    String containing 'F's and 'T's
-     *  @param result      String containing 'F's and 'T's
-     *  @return Difference as String containing '-' (equal) and
-     *          'X' (difference).
+     * Checks which files are selected and shouldn't be or which
+     * are not selected but should.
+     *
+     * @param expected    String containing 'F's and 'T's
+     * @param result      String containing 'F's and 'T's
+     * @return Difference as String containing '-' (equal) and
+     *         'X' (difference).
      */
     public String diff(String expected, String result) {
         int length1 = expected.length();
         int length2 = result.length();
         int min = (length1 > length2) ? length2 : length1;
-        StringBuffer sb = new StringBuffer();
-        for (int i=0; i<min; i++) {
-            sb.append(
-                  (expected.charAt(i) == result.charAt(i))
-                ? "-"
-                : "X"
-            );
+        StringBuilder sb = new StringBuilder();
+        for (int i = 0; i < min; i++) {
+            sb.append((expected.charAt(i) == result.charAt(i))
+                    ? "-" : "X");
         }
         return sb.toString();
     }
@@ -188,17 +194,18 @@ public abstract class BaseSelectorTest extends BuildFileTest {
     /**
      * Resolves a diff-String (@see diff()) against the (inherited) filenames-
      * and files arrays.
+     *
      * @param filelist    Diff-String
      * @return String containing the filenames for all differing files,
      *         separated with semicolons ';'
      */
     public String resolve(String filelist) {
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         int min = (filenames.length > filelist.length())
                 ? filelist.length()
                 : filenames.length;
-        for (int i=0; i<min; i++) {
-            if ('X'==filelist.charAt(i)) {
+        for (int i = 0; i < min; i++) {
+            if ('X' == filelist.charAt(i)) {
                 sb.append(filenames[i]);
                 sb.append(";");
             }
@@ -208,10 +215,10 @@ public abstract class BaseSelectorTest extends BuildFileTest {
 
 
     /**
-     * <p>Creates a testbed. We avoid the dreaded "test" word so that we
+     * Creates a testbed. We avoid the dreaded "test" word so that we
      * don't falsely identify this as a test to be run. The actual
      * setting up of the testbed is done in the
-     * <code>src/etc/testcases/types/selectors.xml</code> build file.</p>
+     * <code>src/etc/testcases/types/selectors.xml</code> build file.
      *
      * <p>Note that the right way to call this is within a try block,
      * with a finally clause that calls cleanupBed(). You place tests of
@@ -236,7 +243,7 @@ public abstract class BaseSelectorTest extends BuildFileTest {
 
 
     /**
-     * <p>Creates a mirror of the testbed for use in dependency checks.</p>
+     * Creates a mirror of the testbed for use in dependency checks.
      *
      * <p>Note that the right way to call this is within a try block,
      * with a finally clause that calls cleanupMirror(). You place tests of
