@@ -19,8 +19,8 @@
 package org.apache.tools.ant.types.selectors;
 
 
-// Java
 import java.io.File;
+import java.io.FileWriter;
 import java.text.RuleBasedCollator;
 import java.util.Comparator;
 import java.util.Iterator;
@@ -42,6 +42,7 @@ import org.apache.tools.ant.types.selectors.modifiedselector.HashvalueAlgorithm;
 import org.apache.tools.ant.types.selectors.modifiedselector.ModifiedSelector;
 import org.apache.tools.ant.types.selectors.modifiedselector.PropertiesfileCache;
 import org.apache.tools.ant.util.FileUtils;
+import org.apache.tools.ant.util.StringUtils;
 import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Ignore;
@@ -61,7 +62,7 @@ import static org.junit.Assert.fail;
  * @since  Ant 1.6
  */
 public class ModifiedSelectorTest {
-    
+
     @Rule
     public final BaseSelectorRule selectorRule = new BaseSelectorRule();
 
@@ -70,13 +71,9 @@ public class ModifiedSelectorTest {
 
     //  =====================  attributes  =====================
 
-
     /** Path where the testclasses are. */
     private Path testclasses = null;
 
-
-
-
     //  =====================  JUnit stuff  =====================
 
 
@@ -87,11 +84,9 @@ public class ModifiedSelectorTest {
         testclasses = new Path(prj, prj.getProperty("build.tests.value"));
     }
 
-
     // =======  testcases for the attributes and nested elements of the selector  =====
 
-
-    /** Test right use of cache names. */
+    /** Test correct use of cache names. */
     @Test
     public void testValidateWrongCache() {
         String name = "this-is-not-a-valid-cache-name";
@@ -105,8 +100,7 @@ public class ModifiedSelectorTest {
         }
     }
 
-
-    /** Test right use of cache names. */
+    /** Test correct use of cache names. */
     @Test
     public void testValidateWrongAlgorithm() {
         String name = "this-is-not-a-valid-algorithm-name";
@@ -121,8 +115,7 @@ public class ModifiedSelectorTest {
         }
     }
 
-
-    /** Test right use of comparator names. */
+    /** Test correct use of comparator names. */
     @Test
     public void testValidateWrongComparator() {
         String name = "this-is-not-a-valid-comparator-name";
@@ -137,7 +130,7 @@ public class ModifiedSelectorTest {
         }
     }
 
-
+    /** Test correct use of algorithm names. */
     @Test
     public void testIllegalCustomAlgorithm() {
         try {
@@ -151,7 +144,7 @@ public class ModifiedSelectorTest {
         }
     }
 
-
+    /** Test correct use of algorithm names. */
     @Test
     public void testNonExistentCustomAlgorithm() {
          try {
@@ -168,21 +161,21 @@ public class ModifiedSelectorTest {
     @Test
     public void testCustomAlgorithm() {
         String algo = getAlgoName("org.apache.tools.ant.types.selectors.modifiedselector.HashvalueAlgorithm");
-        assertTrue("Wrong algorithm used: "+algo, algo.startsWith("HashvalueAlgorithm"));
+        assertTrue("Wrong algorithm used: " + algo, algo.startsWith("HashvalueAlgorithm"));
     }
 
     @Test
     public void testCustomAlgorithm2() {
         String algo = getAlgoName("org.apache.tools.ant.types.selectors.MockAlgorithm");
-        assertTrue("Wrong algorithm used: "+algo, algo.startsWith("MockAlgorithm"));
+        assertTrue("Wrong algorithm used: " + algo, algo.startsWith("MockAlgorithm"));
     }
 
-
     @Test
     public void testCustomClasses() {
-        Assume.assumeNotNull("Ant home not set", selectorRule.getProject().getProperty("ant.home") );
+        Assume.assumeNotNull("Ant home not set", selectorRule.getProject().getProperty("ant.home"));
         BFT bft = new BFT();
         bft.setUp();
+        // don't catch the JUnit exceptions
         try {
             // do the actions
             bft.doTarget("modifiedselectortest-customClasses");
@@ -197,7 +190,6 @@ public class ModifiedSelectorTest {
             assertNotNull("'fs.mod.value' must be set.", fsModValue);
             // must be empty according to the Mock* implementations
             assertTrue("'fs.mod.value' must be empty.", "".equals(fsModValue));
-        // don't catch the JUnit exceptions
         } finally {
             bft.doTarget("modifiedselectortest-scenario-clean");
             bft.deletePropertiesfile();
@@ -205,25 +197,21 @@ public class ModifiedSelectorTest {
         }
     }
 
-
     @Test
     public void testDelayUpdateTaskFinished() {
         doDelayUpdateTest(1);
     }
 
-
     @Test
     public void testDelayUpdateTargetFinished() {
         doDelayUpdateTest(2);
     }
 
-
     @Test
     public void testDelayUpdateBuildFinished() {
         doDelayUpdateTest(3);
     }
 
-
     public void doDelayUpdateTest(int kind) {
         // no check for 1<=kind<=3 - only internal use therefore check it
         // while development
@@ -252,7 +240,7 @@ public class ModifiedSelectorTest {
         sel.configure();
 
         // get the cache, so we can check our things
-        MockCache cache = (MockCache)sel.getCache();
+        MockCache cache = (MockCache) sel.getCache();
 
         // the test
         assertFalse("Cache must not be saved before 1st selection.", cache.saved);
@@ -261,16 +249,20 @@ public class ModifiedSelectorTest {
         sel.isSelected(base, "file2", file2);
         assertFalse("Cache must not be saved after 2nd selection.", cache.saved);
         switch (kind) {
-            case 1 : project.fireTaskFinished();   break;
-            case 2 : project.fireTargetFinished(); break;
-            case 3 : project.fireBuildFinished();  break;
+            case 1 :
+                project.fireTaskFinished();
+                break;
+            case 2 :
+                project.fireTargetFinished();
+                break;
+            case 3 :
+                project.fireBuildFinished();
+                break;
         }
-        assertTrue("Cache must be saved after " + kinds[kind-1] + "Finished-Event.", cache.saved);
-
-        // MockCache doesnt create a file - therefore no cleanup needed
+        assertTrue("Cache must be saved after " + kinds[kind - 1] + "Finished-Event.", cache.saved);
+        // MockCache doesn't create a file - therefore no cleanup needed
     }
 
-
     /**
      * Extracts the real used algorithm name from the ModifiedSelector using
      * its toString() method.
@@ -291,16 +283,18 @@ public class ModifiedSelectorTest {
         int posEnd   = s1.indexOf(" comparator=");
         String algo  = s1.substring(posStart, posEnd);
         // '<' and '>' are only used if the algorithm has properties
-        if (algo.startsWith("<")) algo = algo.substring(1);
-        if (algo.endsWith(">"))   algo = algo.substring(0, algo.length()-1);
+        if (algo.startsWith("<")) {
+            algo = algo.substring(1);
+        }
+        if (algo.endsWith(">")) {
+            algo = algo.substring(0, algo.length() - 1);
+        }
         // return the clean value
         return algo;
     }
 
-
     // ================  testcases for the cache implementations  ================
 
-
     /**
      * Propertycache must have a set 'cachefile' attribute.
      * The default in ModifiedSelector "cache.properties" is set by the selector.
@@ -312,7 +306,6 @@ public class ModifiedSelectorTest {
             fail("PropertyfilesCache does not check its configuration.");
     }
 
-
     @Test
     public void testPropertyfileCache() {
         PropertiesfileCache cache = new PropertiesfileCache();
@@ -322,7 +315,6 @@ public class ModifiedSelectorTest {
         assertFalse("Cache file not deleted.", cachefile.exists());
     }
 
-
     /** Checks whether a cache file is created. */
     @Test
     public void testCreatePropertiesCacheDirect() {
@@ -340,12 +332,11 @@ public class ModifiedSelectorTest {
         assertFalse("Cachefile not deleted.", cachefile.exists());
     }
 
-
     /** Checks whether a cache file is created. */
     @Test
     public void testCreatePropertiesCacheViaModifiedSelector() {
         File cachefile = new File(selectorRule.getProject().getBaseDir(), "cachefile.properties");
-    
+
         // Configure the selector
         ModifiedSelector s = new ModifiedSelector();
         s.setDelayUpdate(false);
@@ -362,10 +353,8 @@ public class ModifiedSelectorTest {
         // evaluate correctness
         assertTrue("Cache file is not created.", cachefile.exists());
         cachefile.delete();
-        
     }
 
-
     /**
      * In earlier implementations there were problems with the <i>order</i>
      * of the <param>s. The scenario was <pre>
@@ -394,17 +383,14 @@ public class ModifiedSelectorTest {
         // evaluate correctness
         assertTrue("Cache file is not created.", cachefile.exists());
         cachefile.delete();
-
     }
 
-
     @Test
     @Ignore("same logic as on algorithm, no testcases created")
     public void testCustomCache() {
         // same logic as on algorithm, no testcases created
     }
 
-
     /**
      * Test the interface semantic of Caches.
      * This method does some common test for cache implementations.
@@ -436,10 +422,10 @@ public class ModifiedSelectorTest {
         Object   returned = it2.next();
         boolean ok = (key1.equals(returned) || key2.equals(returned));
         String msg = "Iterator returned unexpected value."
-                   + "  key1.equals(returned)="+key1.equals(returned)
-                   + "  key2.equals(returned)="+key2.equals(returned)
-                   + "  returned="+returned
-                   + "  ok="+ok;
+                   + "  key1.equals(returned)=" + key1.equals(returned)
+                   + "  key2.equals(returned)=" + key2.equals(returned)
+                   + "  returned=" + returned
+                   + "  ok=" + ok;
         assertTrue(msg, ok);
 
         // clear the cache
@@ -448,17 +434,14 @@ public class ModifiedSelectorTest {
         assertFalse("Cache is not empty", it3.hasNext());
     }
 
-
     // ==============  testcases for the algorithm implementations  ==============
 
-
     @Test
     public void testHashvalueAlgorithm() {
         HashvalueAlgorithm algo = new HashvalueAlgorithm();
         doTest(algo);
     }
 
-
     @Test
     public void testDigestAlgorithmMD5() {
         DigestAlgorithm algo = new DigestAlgorithm();
@@ -466,7 +449,6 @@ public class ModifiedSelectorTest {
         doTest(algo);
     }
 
-
     @Test
     public void testDigestAlgorithmSHA() {
         DigestAlgorithm algo = new DigestAlgorithm();
@@ -474,14 +456,12 @@ public class ModifiedSelectorTest {
         doTest(algo);
     }
 
-
     @Test
     public void testChecksumAlgorithm() {
         ChecksumAlgorithm algo = new ChecksumAlgorithm();
         doTest(algo);
     }
 
-
     @Test
     public void testChecksumAlgorithmCRC() {
         ChecksumAlgorithm algo = new ChecksumAlgorithm();
@@ -489,7 +469,6 @@ public class ModifiedSelectorTest {
         doTest(algo);
     }
 
-
     @Test
     public void testChecksumAlgorithmAdler() {
         ChecksumAlgorithm algo = new ChecksumAlgorithm();
@@ -497,7 +476,6 @@ public class ModifiedSelectorTest {
         doTest(algo);
     }
 
-
     /**
      * Test the interface semantic of Algorithms.
      * This method does some common test for algorithm implementations.
@@ -533,25 +511,20 @@ public class ModifiedSelectorTest {
 
     }
 
-
-
     // ==============  testcases for the comparator implementations  ==============
 
-
     @Test
     public void testEqualComparator() {
         EqualComparator comp = new EqualComparator();
         doTest(comp);
     }
 
-
     @Test
     public void testRuleComparator() {
-        RuleBasedCollator comp = (RuleBasedCollator)RuleBasedCollator.getInstance();
+        RuleBasedCollator comp = (RuleBasedCollator) RuleBasedCollator.getInstance();
         doTest(comp);
     }
 
-
     @Test
     public void testEqualComparatorViaSelector() {
         ModifiedSelector s = new ModifiedSelector();
@@ -565,7 +538,6 @@ public class ModifiedSelectorTest {
         }
     }
 
-
     @Test
     @Ignore("not yet supported see note in selector")
     public void testRuleComparatorViaSelector() {
@@ -580,14 +552,12 @@ public class ModifiedSelectorTest {
         }
     }
 
-
     @Test
     @Ignore("same logic as on algorithm, no testcases created")
     public void testCustomComparator() {
         // same logic as on algorithm, no testcases created
     }
 
-
     @Test
     public void testResourceSelectorSimple() {
         BFT bft = new BFT();
@@ -637,20 +607,18 @@ public class ModifiedSelectorTest {
         assertTrue("Comparator gave wrong value.", comp.compare(o2, o3) == 0);
     }
 
-
     // =====================  scenario tests  =====================
 
-
     /**
      * Tests whether the seldirs attribute is used.
      */
     @Test
     public void testSeldirs() {
         ModifiedSelector s = new ModifiedSelector();
-        StringBuffer sbTrue  = new StringBuffer();
-        StringBuffer sbFalse = new StringBuffer();
-        for (int i=0; i<selectorRule.getFiles().length; i++) {
-            if (selectorRule.getFiles()[i].isDirectory()) {
+        StringBuilder sbTrue  = new StringBuilder();
+        StringBuilder sbFalse = new StringBuilder();
+        for (File file : selectorRule.getFiles()) {
+            if (file.isDirectory()) {
                 sbTrue.append("T");
                 sbFalse.append("F");
             } else {
@@ -670,16 +638,15 @@ public class ModifiedSelectorTest {
         s.getCache().delete();
     }
 
-
     /**
      * Complex test scenario using default values (DigestAlgorithm with MD5,
      * PropertiesfileCache with file=cache.properties, EqualComparator
-     * and update=true). <ol>
-     * <li> try fist time --> should select all </li>
-     * <li> try second time --> should select no files (only directories) </li>
-     * <li> modify timestamp of one file and content of a nother one </li>
-     * <li> try third time --> should select only the file with modified
-     *      content </li>
+     * and update=true).
+     * <ol><li>try fist time --&gt; should select all</li>
+     * <li>try second time --&gt; should select no files (only directories)</li>
+     * <li>modify timestamp of one file and content of another one</li>
+     * <li>try third time --&gt; should select only the file with modified
+     *      content</li></ol>
      */
     @Test
     public void testScenario1() {
@@ -718,9 +685,9 @@ public class ModifiedSelectorTest {
             // AccessObject to the test-Ant-environment
             bft = new BFT();
             // give some values (via property file) to that environment
-            bft.writeProperties("f2name="+f2name);
-            bft.writeProperties("f3name="+f3name);
-            bft.writeProperties("f4name="+f4name);
+            bft.writeProperties("f2name=" + f2name);
+            bft.writeProperties("f3name=" + f3name);
+            bft.writeProperties("f4name=" + f4name);
             // call the target for making the files dirty
             bft.doTarget("modifiedselectortest-makeDirty");
 
@@ -737,13 +704,19 @@ public class ModifiedSelectorTest {
             // Mark all files which should be selected as (T)rue and all others
             // as (F)alse. Directories are always selected so they always are
             // (T)rue.
-            StringBuffer expected = new StringBuffer();
-            for (int i=0; i<selectorRule.getFiles().length; i++) {
+            StringBuilder expected = new StringBuilder();
+            for (int i = 0; i < selectorRule.getFiles().length; i++) {
                 String ch = "F";
-                if (selectorRule.getFiles()[i].isDirectory()) ch = "T";
                 // f2name shouldn't be selected: only timestamp has changed!
-                if (selectorRule.getFilenames()[i].equalsIgnoreCase(f3name)) ch = "T";
-                if (selectorRule.getFilenames()[i].equalsIgnoreCase(f4name)) ch = "T";
+                if (selectorRule.getFiles()[i].isDirectory()) {
+                    ch = "T";
+                }
+                if (selectorRule.getFilenames()[i].equalsIgnoreCase(f3name)) {
+                    ch = "T";
+                }
+                if (selectorRule.getFilenames()[i].equalsIgnoreCase(f4name)) {
+                    ch = "T";
+                }
                 expected.append(ch);
             }
 
@@ -751,44 +724,44 @@ public class ModifiedSelectorTest {
                 "Wrong files selected. Differing files: "       // info text
                 + resolve(diff(expected.toString(), results)),  // list of files
                 expected.toString(),                            // expected result
-                results                                         // result
-            );
-
+                results);                                       // result
         } finally {
             // cleanup the environment
-            if (s!=null) s.getCache().delete();
-            if (bft!=null) bft.deletePropertiesfile();
+            if (s != null) {
+                s.getCache().delete();
+            }
+            if (bft != null) {
+                bft.deletePropertiesfile();
+            }
         }
     }
 
-
     /**
      * This scenario is based on scenario 1, but does not use any
-     * default value and its based on <custom> selector. Used values are:<ul>
-     * <li><b>Cache: </b> Propertyfile,
-     *                    cachefile={java.io.tmpdir}/mycache.txt </li>
-     * <li><b>Algorithm: </b> Digest
-     *                    algorithm=SHA, Provider=null </li>
-     * <li><b>Comparator: </b> java.text.RuleBasedCollator
-     * <li><b>Update: </b> true </li>
+     * default value and its based on &lt;custom&gt; selector. Used values are:
+     * <ul><li><b>Cache:</b> Propertyfile,
+     *                    cachefile={java.io.tmpdir}/mycache.txt</li>
+     * <li><b>Algorithm:</b> Digest
+     *                    algorithm=SHA, Provider=null</li>
+     * <li><b>Comparator:</b> java.text.RuleBasedCollator</li>
+     * <li><b>Update:</b> true</li></ul>
      */
     @Test
     @Ignore("RuleBasedCollator not yet supported - see Selector:375 note")
     public void testScenario2() {
         ExtendSelector s = new ExtendSelector();
         BFT bft = new BFT();
-        String cachefile = System.getProperty("java.io.tmpdir")+"/mycache.txt";
+        String cachefile = System.getProperty("java.io.tmpdir") + "/mycache.txt";
         try {
-
             s.setClassname("org.apache.tools.ant.types.selectors.modifiedselector.ModifiedSelector");
 
             s.addParam(createParam("cache.cachefile", cachefile));
             //s.addParam(createParam("algorithm.provider","---")); // i don't know any valid
-            s.addParam(createParam("cache","propertyfile"));
-            s.addParam(createParam("update","true"));
-            s.addParam(createParam("comparator","rule"));
-            s.addParam(createParam("algorithm.name","sha"));
-            s.addParam(createParam("algorithm","digest"));
+            s.addParam(createParam("cache", "propertyfile"));
+            s.addParam(createParam("update", "true"));
+            s.addParam(createParam("comparator", "rule"));
+            s.addParam(createParam("algorithm.name", "sha"));
+            s.addParam(createParam("algorithm", "digest"));
 
             // first and second run
             performTests(s, "TTTTTTTTTTTT");
@@ -797,55 +770,56 @@ public class ModifiedSelectorTest {
             String f2name = "tar/bz2/asf-logo-huge.tar.bz2";
             String f3name = "asf-logo.gif.md5";
             String f4name = "copy.filterset.filtered";
-            bft.writeProperties("f2name="+f2name);
-            bft.writeProperties("f3name="+f3name);
-            bft.writeProperties("f4name="+f4name);
+            bft.writeProperties("f2name=" + f2name);
+            bft.writeProperties("f3name=" + f3name);
+            bft.writeProperties("f4name=" + f4name);
             bft.doTarget("modifiedselectortest-makeDirty");
             // third run
             String results = selectorRule.selectionString(s);
-            StringBuffer expected = new StringBuffer();
-            for (int i=0; i<selectorRule.getFilenames().length; i++) {
+            StringBuilder expected = new StringBuilder();
+            for (int i = 0; i < selectorRule.getFilenames().length; i++) {
                 String ch = "F";
-                if (selectorRule.getFiles()[i].isDirectory()) ch = "T";
-                if (selectorRule.getFilenames()[i].equalsIgnoreCase(f3name)) ch = "T";
-                if (selectorRule.getFilenames()[i].equalsIgnoreCase(f4name)) ch = "T";
+                if (selectorRule.getFiles()[i].isDirectory()) {
+                    ch = "T";
+                }
+                if (selectorRule.getFilenames()[i].equalsIgnoreCase(f3name)) {
+                    ch = "T";
+                }
+                if (selectorRule.getFilenames()[i].equalsIgnoreCase(f4name)) {
+                    ch = "T";
+                }
                 expected.append(ch);
             }
             assertEquals(
-                "Wrong files selected. Differing files: "       // info text
+                "Wrong files selected. Differing files: " // info text
                 + resolve(diff(expected.toString(), results)),  // list of files
                 expected.toString(),                            // expected result
-                results                                         // result
-            );
+                results);                                       // result
         } finally {
             // cleanup the environment
-            (new java.io.File(cachefile)).delete();
+            (new File(cachefile)).delete();
             bft.deletePropertiesfile();
         }
     }
 
-
     @Test
     public void testScenarioCoreSelectorDefaults() {
-        Assume.assumeNotNull("Ant home not set", selectorRule.getProject().getProperty("ant.home") );
+        Assume.assumeNotNull("Ant home not set", selectorRule.getProject().getProperty("ant.home"));
         doScenarioTest("modifiedselectortest-scenario-coreselector-defaults", "cache.properties");
     }
 
-
     @Test
     public void testScenarioCoreSelectorSettings() {
-        Assume.assumeNotNull("Ant home not set", selectorRule.getProject().getProperty("ant.home") );
+        Assume.assumeNotNull("Ant home not set", selectorRule.getProject().getProperty("ant.home"));
         doScenarioTest("modifiedselectortest-scenario-coreselector-settings", "core.cache.properties");
     }
 
-
     @Test
     public void testScenarioCustomSelectorSettings() {
-        Assume.assumeNotNull("Ant home not set", selectorRule.getProject().getProperty("ant.home") );
+        Assume.assumeNotNull("Ant home not set", selectorRule.getProject().getProperty("ant.home"));
         doScenarioTest("modifiedselectortest-scenario-customselector-settings", "core.cache.properties");
     }
 
-
     public void doScenarioTest(String target, String cachefilename) {
         BFT bft = new BFT();
         bft.setUp();
@@ -862,9 +836,9 @@ public class ModifiedSelectorTest {
 
             // do the checks
             assertTrue("Cache file not created.", cachefile.exists());
-            assertTrue("Not enough files copied on first time.", to1.list().length>5);
-            assertTrue("Too much files copied on second time.", to2.list().length==0);
-            assertTrue("Too much files copied on third time.", to3.list().length==2);
+            assertTrue("Not enough files copied on first time.", to1.list().length > 5);
+            assertTrue("Too much files copied on second time.", to2.list().length == 0);
+            assertTrue("Too much files copied on third time.", to3.list().length == 2);
         // don't catch the JUnit exceptions
         } finally {
             bft.doTarget("modifiedselectortest-scenario-clean");
@@ -874,10 +848,8 @@ public class ModifiedSelectorTest {
         }
     }
 
-
     //  =====================  helper methods and classes  ====================
 
-
     /**
      * Creates a configured parameter object.
      * @param name   name of the parameter
@@ -891,7 +863,6 @@ public class ModifiedSelectorTest {
         return p;
     }
 
-
     /**
      * The BFT class wrapps the selector test-builfile inside an
      * ant project. It supports target execution
@@ -904,24 +875,23 @@ public class ModifiedSelectorTest {
 
         boolean isConfigured = false;
 
-
         public void setUp() {
             super.configureProject(buildfile);
             isConfigured = true;
         }
 
-
         /**
          * This stub teardown is here because the outer class needs to call the
          * tearDown method, and in the superclass it is protected.
          */
         public void tearDown() {
             super.after();
-
         }
 
         public void doTarget(String target) {
-            if (!isConfigured) setUp();
+            if (!isConfigured) {
+                setUp();
+            }
             executeTarget(target);
         }
 
@@ -930,14 +900,15 @@ public class ModifiedSelectorTest {
         }
 
         public void writeProperties(String line) {
-            if (!isConfigured) setUp();
+            if (!isConfigured) {
+                setUp();
+            }
             File dir = getProject().getBaseDir();
             File file = new File(dir, propfile);
             try {
-                java.io.FileWriter out =
-                    new java.io.FileWriter(file.getAbsolutePath(), true);
+                FileWriter out = new FileWriter(file.getAbsolutePath(), true);
                 out.write(line);
-                out.write(System.getProperty("line.separator"));
+                out.write(StringUtils.LINE_SEP);
                 out.flush();
                 out.close();
             } catch (Exception e) {
@@ -946,7 +917,9 @@ public class ModifiedSelectorTest {
         }
 
         public void deletePropertiesfile() {
-            if (!isConfigured) setUp();
+            if (!isConfigured) {
+                setUp();
+            }
             new File(getProject().getBaseDir(), propfile).delete();
         }
 
@@ -956,8 +929,7 @@ public class ModifiedSelectorTest {
             cacheFile.delete();
         }
 
-    }//class-BFT
-
+    }
 
     /**
      * MockProject wrappes a very small ant project (one target, one task)
@@ -968,7 +940,7 @@ public class ModifiedSelectorTest {
         private Target target;
 
         public MockProject() {
-            task = new Task(){
+            task = new Task() {
                 public void execute() {
                 }
             };
@@ -983,22 +955,25 @@ public class ModifiedSelectorTest {
         public void fireBuildFinished() {
             super.fireBuildFinished(null);
         }
+        @SuppressWarnings("unused")
         public void fireSubBuildFinished() {
             super.fireSubBuildFinished(null);
         }
+        @SuppressWarnings("unused")
         public void fireTargetStarted() {
             super.fireTargetStarted(target);
         }
         public void fireTargetFinished() {
             super.fireTargetFinished(target, null);
         }
+        @SuppressWarnings("unused")
         public void fireTaskStarted() {
             super.fireTaskStarted(task);
         }
         public void fireTaskFinished() {
             super.fireTaskFinished(task, null);
         }
-    }//class-MockProject
+    }
 
 
     /**
@@ -1026,13 +1001,9 @@ public class ModifiedSelectorTest {
         int length1 = expected.length();
         int length2 = result.length();
         int min = (length1 > length2) ? length2 : length1;
-        StringBuffer sb = new StringBuffer();
-        for (int i=0; i<min; i++) {
-            sb.append(
-                    (expected.charAt(i) == result.charAt(i))
-                            ? "-"
-                            : "X"
-            );
+        StringBuilder sb = new StringBuilder();
+        for (int i = 0; i < min; i++) {
+            sb.append((expected.charAt(i) == result.charAt(i)) ? "-" : "X");
         }
         return sb.toString();
     }
@@ -1045,18 +1016,15 @@ public class ModifiedSelectorTest {
      *         separated with semicolons ';'
      */
     private String resolve(String filelist) {
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         int min = (selectorRule.getFilenames().length > filelist.length())
-                ? filelist.length()
-                : selectorRule.getFilenames().length;
-        for (int i=0; i<min; i++) {
-            if ('X'==filelist.charAt(i)) {
-                sb.append(selectorRule.getFilenames()[i]);
-                sb.append(";");
+                ? filelist.length() : selectorRule.getFilenames().length;
+        for (int i = 0; i < min; i++) {
+            if ('X' == filelist.charAt(i)) {
+                sb.append(selectorRule.getFilenames()[i]).append(";");
             }
         }
         return sb.toString();
     }
 
-
-}//class-ModifiedSelectorTest
+}
