@@ -24,22 +24,28 @@ import org.apache.tools.ant.Task;
 public class TaskdefTestSimpleTask extends Task {
 
     public class Echo {
-        Echo() {}
+        Echo() {
+        }
+
         private String message = null;
-        public void setMessage(String s) {message = s;}
+
+        public void setMessage(String s) {
+            message = s;
+        }
     }
 
-    public TaskdefTestSimpleTask() {}
+    public TaskdefTestSimpleTask() {
+    }
 
     private Echo echo;
+
     public Echo createEcho() {
         echo = new Echo();
         return echo;
     }
 
     public void execute() {
-        log("simpletask: "+echo.message, Project.MSG_INFO);
+        log("simpletask: " + echo.message, Project.MSG_INFO);
     }
 
 }
-
